################################################################################
################################################################################
# Setup options for IQR Tools
# ===========================
# Certain  things  can be customized  and different  tools  can be interfaced by
# editing the information in here. Please use the currently provided information
# as a guide for your own setup. When in doubt, contact info@intiquan.com.
################################################################################
################################################################################

# ==============================================================================
# PATH to folder in which IQR Tools license file is stored as licenseIQR.txt
# ==============================================================================
.PATH_LICENSE_FILE <- "~"


# ==============================================================================
# Compliance mode
# ==============================================================================
# If TRUE then  exported PDFs, text files, etc. will have an associated log file
# that  records  time, data, file  location,   and  user. If FALSE,  then  these
# additional log files are not generated. The activated compliance mode requires
# the user to call IQRinitCompliance("ScriptName") at the start of each script.
.COMPLIANCE_MODE <- FALSE


# ==============================================================================
# Username
# ==============================================================================
# For some installations it might be useful to allow chnaging the username
# used by the log file generation. If "NA" then the systems user name is used.
# If a name is provided that will be used!
.USER_NAME <- NA


# ==============================================================================
# RDS mode
# ==============================================================================
# If TRUE then each figure and table object that is exported with IQRoutput* functions
# also is exported as *.rds file along with the figure - allowing potential
# post-processing.
.RDS_FILES_OUTPUT <- FALSE


# ==============================================================================
# .LIBPATHS_FIRSTONLY mode
# ==============================================================================
# If TRUE then IQR Tools during compilation of IQRmodels will only search the
# first entry in .libPaths() for include files. Only change this to TRUE when you
# know exactly what you are doing :-) Default is FALSE.
.LIBPATHS_FIRSTONLY <- FALSE


# ==============================================================================
# Paths to NONMEM executables
# ==============================================================================
if (IQRtools:::aux_getOS()=="unix") {
  # UNIX setup
  # ----------
  # Name of the NONMEM executable or shell script. Required calling syntax:
  #    "command controlfile outputfile"
  # NONMEM Version 7.2/7.3/7.4 have been tested with IQR Tools.
  .PATH_SYSTEM_NONMEM <- list(
    # First entry is used as default version
    NM743 = 'nmfe743',
    NM750 = 'nmfe750'
  )
  # Name of the NONMEM executable or shell script for parallel NONMEM runs.
  # Required calling syntax:
  #    "command NRCORES controlfile outputfile"
  # NONMEM Version 7.2/7.3/7.4 have been tested with IQR Tools.
  # During NONMEM  execution the scope  should not be given back to the  command
  # line.
  .PATH_SYSTEM_NONMEM_PARALLEL <- list(
    NM743 = 'nmfe743par',
    NM750 = 'nmfe750par'
  )
}

if (IQRtools:::aux_getOS()=="mac") {
  # MacOS setup
  # -----------
  # Name of the NONMEM executable or shell script. Required calling syntax:
  #    "command controlfile outputfile"
  # NONMEM Version 7.2/7.3/7.4 have been tested with IQR Tools.
  .PATH_SYSTEM_NONMEM <- list(
    NM74 = "nmfe74"
  )
  # Name of the NONMEM executable or shell script for parallel NONMEM runs.
  # Required calling syntax:
  #    "command NRCORES controlfile outputfile"
  # NONMEM Version 7.2/7.3/7.4 have been tested with IQR Tools.
  # During NONMEM  execution the scope  should not be given back to the  command
  # line.
  .PATH_SYSTEM_NONMEM_PARALLEL <- list(
    NM74 = "nmfe74par"
  )
}

if (IQRtools:::aux_getOS()=="windows") {
  # WINDOWS setup
  # -------------
  # Path to NONMEM (Version 7.2/7.3/7.4  have been tested) batch files. The info
  # is provided as a list. By default  the first entry is  used but the user can
  # switch when calling the IQRnlmeProject function.
  .PATH_SYSTEM_NONMEM <- list(
    NM74 = "C:/nm74g64/run/nmfe74.bat"
  )
  # Path  to parallel  version  of  NONMEM. The info is  provided  as a list. By
  # default  the first  entry is  used but the user  can switch when calling the
  # IQRnlmeProject function. Instead of a path a command can  be  provided  that
  # has been made available on the command line by the system administrator.
  # The command has to provide the following  calling syntax to parallel NONMEM:
  #         "nonmemparallelcommand NRCORES controlFile outputFile"
  # During NONMEM  execution the scope  should not be given back to the  command
  .PATH_SYSTEM_NONMEM_PARALLEL <- list(
    NM74 = "C:/nm74g64/run/nmfe74par.bat"
  )
  # Fix NONMEM 7.4 issue  on Windows    (will not hurt previous NONMEM versions)
  # Source discussion to be found here:
  #            https://www.mail-archive.com/nmusers@globomaxnm.com/msg06885.html
  Sys.unsetenv("GFORTRAN_STDOUT_UNIT")
}

# ==============================================================================
# Paths to MONOLIX executables
# ==============================================================================
# IQRtools works with MONOLIX 2018R1 and 2018R2.
if (IQRtools:::aux_getOS()=="unix") {
  # UNIX setup
  # ----------
  # Info Provided as list. By  default  the first entry is used but the user can
  # switch when calling  the  IQRnlmeProject function.  Each list element should
  # have the following MONOLIX version dependent information:
  #   MONOLIX >=2018R1: Absolute path to the MONOLIX installation folder
  # In order to  identify the version of MONOLIX,  when needed in IQRtools it is
  # important to use the  version name  (e.g., 2018R1 or 2018R2) as part  of the
  # names in the lists below.
  .PATH_SYSTEM_MONOLIX <- list(
    MLX2019R1 = '/opt/Lixoft/MonolixSuite2019R1',
    MLX2020R1 = '/opt/Lixoft/MonolixSuite2020R1'
  )
}

if (IQRtools:::aux_getOS()=="mac") {
  # MacOS setup
  # -----------
  # Info Provided as list. By  default  the first entry is used but the user can
  # switch when calling  the  IQRnlmeProject function.  Each list element should
  # have the following MONOLIX version dependent information:
  #   MONOLIX >=2018R1: Absolute path to the MONOLIX installation folder
  # In order to  identify the version of MONOLIX,  when needed in IQRtools it is
  # important to use the  version name  (e.g., 2018R1 or 2018R2) as part  of the
  # names in the lists below.
  .PATH_SYSTEM_MONOLIX <- list(
    MLX2019R1 = "/Applications/MonolixSuite2019R1.app/Contents/Resources/mlxsuite/",
    MLX2020R1 = "/Applications/MonolixSuite2020R1.app/Contents/Resources/mlxsuite/"
  )
}

if (IQRtools:::aux_getOS()=="windows") {
  # WINDOWS setup
  # -------------
  .PATH_SYSTEM_MONOLIX <- list(
    MLX2019R1 = "C:/ProgramData/Lixoft/MonolixSuite2019R1",
    MLX2020R1 = "C:/ProgramData/Lixoft/MonolixSuite2020R1"
  )
}

# ==============================================================================
# Currently supported version of NLMIXR
# ==============================================================================
.VERSION_SUPPORTED_NLMIXR <- c("1.1.1.2")

# ==============================================================================
# Path to IQReport for integrated reporting in Microsoft Word
# ==============================================================================
# The IQReport software can be obtained from http://iqreport.intiquan.com.
# Installation  needs  to be handled separately from IQRtools but here the paths
# to the executables need to be provided (for Windows and Linux separately):
if (IQRtools:::aux_getOS()=="unix" | IQRtools:::aux_getOS()=="mac") {
  .PATH_IQRreport <- "/opt/IQReport/IQReport.sh"
} else {
  .PATH_IQRreport <- "C:/LOCAL/IQReport/IQReport.exe"
}

# ==============================================================================
# Output Path for Slide Output ----
# ==============================================================================
.OUTPUTFOLDER_SLIDES <- "../Output/Slides"
.TEMPLATEFILE_SLIDES <- "TemplateDefault.pptx"


# ==============================================================================
# IQRsbml and IQRsbmlOut executable paths
# ==============================================================================
# IQRsbml can be obtained from here: http://www.intiquan.com/iqrsbml/
# Only a Windows version is provided.
# On IQdesktop also a Linux version is available (https://iqdesktop.intiquan.com)
# IQRsbmlOut is currently only available on IQdesktop (https://iqdesktop.intiquan.com)
if (IQRtools:::aux_getOS()=="windows") {
  .PATH_IQRsbml <- "C:/LOCAL/IQRsbml/IQRsbml.exe"
  .PATH_IQRsbmlOut <- "C:/LOCAL/IQRsbmlOut/IQRsbmlOut.exe"
}

if (IQRtools:::aux_getOS()=="unix") {
  .PATH_IQRsbml <- "/opt/IQRsbml/IQRsbml.sh"
  .PATH_IQRsbmlOut <- "/opt/IQRsbmlOut/IQRsbmlOut.sh"
}


# ==============================================================================
# Additional Settings
# ==============================================================================

# Flag to allow spaces in the path (bad for NONMEM)
.ALLOW_SPACES_IN_PATH <- FALSE

# Preferred ordering criterion for tables of NLME estimates
# Only impacts display (ordering) in output tables.
.NLME_ORDER_CRITERION <- "BIC" # Alternative: "AIC", "BIC", or "OBJ", or NULL

# Define accepted lengths of state, parameter, variable, and reaction names
# If longer then there will be a warning
.MODEL_MAX_DESIRED_STATENAME_LENGTH      <- 30
.MODEL_MAX_DESIRED_PARAMETERNAME_LENGTH  <- 30
.MODEL_MAX_DESIRED_VARIABLENAME_LENGTH   <- 30
.MODEL_MAX_DESIRED_REACTIONNAME_LENGTH   <- 30

# Define reserved word in IQRmodels that should not appear as element names
# (case insensitive) ... due to many reasons, including NONMEM and MONOLIX
.RESERVED_WORD_IQRMODELS                 <- c(
  "T","F","PK","G","H","gt","ge","lt","le","mod","and","or","min","max",
  "piecewise","interp0","interp1","interpcs", "default", "F1", "F2",
  "Tlag", "eps", "eta", "theta", "sigma","a","b","b1","b2","b3","d",
  "alpha", "Intercept", "time", "y", "ydot", "RPAR", "IPAR","ID","USUBJID"
)

# Define if underscores should be allowed as part of parameter names.
# This should not be allowed if you regularly use IQRtools for NLME modeling, as
# an underscore is used by MONOLIX for covariate/category separation and other things.
.ALLOW_UNDERSCORES_IN_PARAMETER_NAMES    <- TRUE

# Define maximum number of IQRmodels that can be loaded as DLLs at the same time.
# If this number is exceeded then before the generation of a new DLL the oldest
# loaded IQRmodel is unloaded from the memory. In practical applications this
# will not matter much but for testing purposes it is annoying if R reports an
# error just because of to many DLLs loaded. The check is done in the
# compile_IQRmodel function. If you really want to load a LOT of IQRmodels at
# the same time, you might need to increase the number below.
.MAX_NUMBER_IQRMODEL_DLLS_LOADED         <- 20

# Define if the user is allowed to override the options in  this file.  If it is
# allowed then the user can place a setup_options_IQRtools.R file  in his or her
# home folder and define the variables that should be overriden  (with exception
# of the following variable):
.ALLOW_USER_SETTINGS_FILE <- TRUE
# In a production  environment with a global  installation of  IQRtools it makes
# sense to set this variable to FALSE.

# Define if more column name check for GDF results in warning or error when not
# according to usual FDA requirements. These strict requirements are:
#  - First character needs to be a-z or A-Z
#  - Only contains letters and numbers but no other characters
#  - Has a max number of 8 characters
# If below flag is set to TRUE an error is thrown when column names are
# not following rules. If it is set to FALSE only a warning is thrown.
.ENFORCE_STRICT_COLNAME_GDF_RULES <- TRUE
