% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_param_sampling.R
\name{GPF}
\alias{GPF}
\title{Create a GPF object}
\usage{
GPF(filename, estimates, uncertainty_correlation = data.frame())
}
\arguments{
\item{filename}{Missing, \code{NULL} or a character string denoting a path to a GPF-file. This
argument is only considered if \code{estimates} is missing or set to \code{NULL}.}

\item{estimates}{a data.frame with parameter estimates as specified in
\href{https://iqrtools.intiquan.com/doc/book/GPF.html}{General Parameter Format}.}

\item{uncertainty_correlation}{a data.frame with parameter uncertainty correlation estimates, as
specified in \href{https://iqrtools.intiquan.com/doc/book/GPF.html}{General Parameter Format}.}
}
\value{
A GPF object or the function stops with an error message, if no such object could be
created.
}
\description{
It depends on the arguments how the GPF object will be created:
\itemize{
\item if \code{estimates} is missing or set to \code{NULL} and if \code{filename} is a character string
pointing to an existing file, an attempt is made to load the GPF object from the file via
\code{\link{load_GPF}(filename)}. In this case, the argument \code{uncertainty_correlation} is neglected.
\item if \code{estimates} is specified and not \code{NULL}, then the GPF object is created from
the \code{estimates} and \code{uncertainty_correlation} arguments, and the argument \code{filename}
is neglected.
}
}
\details{
This function does not generate a GPF from a project estimates directory - please,
check \code{\link{generate_GPFFromIQRnlmeProject}} for that purpose.

In the estimates-sheet, the following columns are required:
\itemize{
\item PARAMETER: Names of parameters. \code{c("ka", "beta_ka(WT0)", "corr(ka, CL)")}
\item TYPE: Use of paramter. Not used internally but useful for the overview.
\code{c("MODEL PARAMETER", "COVARIATE")}
\item VALUE: Value of parameter in \emph{linear scale}
\item VALUE.RSE.PERCENT: \verb{sigma/VALUE \\* 100}
\item IIV: \code{Omega} (standard deviation) of random effects in \emph{"linear scale"}.
See details for some practical examples.
\item IIV.RSE.PERCENT
\item TRANSFORMATION: One of c("N", "L", "G", NA).
Can be NA only for corr, beta and error parameters
\item UNIT: Not used for sampling but highly recommended
\item COV.FORMULA: Formula for covariate transformation
\item NAME: Verbose description of the parameter
\item COV.REFERENCE: Reference value of the covariate
\item COMMENT: Ad libitum
}

Some practical examples you might encounter
\enumerate{
\item You have parameter c(ka = 2) with transformation "L" and the corresponding diagonal
entry in your random effects vcov matrix is 0.4.
\itemize{
\item What do you put in IIV?
Answer: IIV = sqrt(0.4).
\item How does the final value of an indparam look?
Answer: The final indparam = exp(log(2) + rnorm(1,0,sqrt(0.4)))
}
}
}
\examples{
\dontrun{
m <- IQRmodel(system.file("examples/GPFExamples/model_1cpt_linear_abs1.txt", package = "IQRtools"))
xls <- generate_GPFfromIQRmodel(m)
est <- xls$estimates
uc <- xls$uncertainty_correlation

# Create a GPF without uncertainty correlation matrix
gpf1 <- GPF(estimates = est)
}

}
\seealso{
\href{https://iqrtools.intiquan.com/doc/book/GPF.html}{General Parameter Format}

Other GPF: 
\code{\link{addIIVCov_toGPF}()},
\code{\link{combineGPF}()},
\code{\link{export_GPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{generate_GPFFromProjectInfo}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{load_GPF}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sample_GPF}()},
\code{\link{select_FromGPF}()}
}
\author{
Daniel Lill (IntiQuan), Venelin Mitov (IntiQuan)
}
\concept{GPF}
