% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/survival_tools_Cox.R
\name{IQRcoxRegression}
\alias{IQRcoxRegression}
\title{Proportional Hazard Cox regression with a multiple predictors}
\usage{
IQRcoxRegression(
  data,
  TIMEcol,
  CENScol,
  PREDcol = NULL,
  IDcol = "ID",
  PREDinteraction = NULL,
  PREDval = NULL,
  RHSformula = NULL,
  ci.level = 0.95,
  xlab = NULL,
  ylab = NULL,
  pathname = NULL,
  FLAGreport = TRUE,
  SIGNIF = 4
)
}
\arguments{
\item{data}{A data frame containing the columns that are defined in the following.}

\item{TIMEcol}{Name of the column in data that contains time of the event.}

\item{CENScol}{Name of the column in data that contains censoring information.
Expects 0 for uncensored and 1 for censored observations.}

\item{PREDcol}{Name(s) of the column in data that should be used as a predictor.}

\item{IDcol}{Name of the column with subject IDs (only for annotation purpose).}

\item{PREDinteraction}{Character vector with comma separated predictor names for which an interaction term is included.
Only second order interactions are considered.}

\item{PREDval}{Named vector with coefficients of numerical predictors that should be fixed (categorical are not handled yet).
Second order interactions can be fixed by the two predictor names separated by comma.
Note that the order of variables within interaction terms needs to be the same as given in PREDinteraction or the formula.}

\item{RHSformula}{Formula or string to define the model for coxph. If given (not NULL) the arguments
VARcol, PREDcol, PREDinteraction, and FLAGintercept are ignored}

\item{ci.level}{Confidence interval level (between 0 an 1, defaults to 0.95)}

\item{xlab}{Label for the x-axis.}

\item{ylab}{Label for the y-axis.}

\item{pathname}{If given, path to which results are written.}

\item{FLAGreport}{Whether to produce report ready table with estimates.}

\item{SIGNIF}{Number of significant digits used for the displayed values.}
}
\value{
IQRcoxRegression object: Main output is a table with estimation results.
Attributes to the output argument contain a data frame with the estimates, a data
frame with global model metrics, the coxph fit object, and diagnostic plots
}
\description{
This is a convenient interface to the coxph function that performs a proportional hazard
regression for one or multiple predictors and displays the results graphically.
It handles continuous and categorical predictors as well as their interaction.
}
\seealso{
Other Survival analysis: 
\code{\link{export_IQRcoxRegression}()},
\code{\link{import_IQRcoxRegression}()},
\code{\link{km_IQRsurvival}()},
\code{\link{plot_IQRcoxRegression}()},
\code{\link{summary_IQRcoxRegression}()}
}
\concept{Survival analysis}
