% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/general_classes_IQRdosing.R
\name{IQRdosing}
\alias{IQRdosing}
\title{IQRdosing class}
\usage{
IQRdosing(TIME, ADM, AMT, TINF = NULL, RATE = NULL, ADDL = NULL, II = NULL)
}
\arguments{
\item{TIME}{Scalar or vector with dosing times (numeric)}

\item{ADM}{Scalar or vector with ADM numbers (matching IQRmodel INPUT*)
and same length as TIME. (numeric)}

\item{AMT}{Scalar or vector with dose amount (numeric)}

\item{TINF}{Scalar or vector with duration of administration (numeric)
This can be 0 in case of a BOLUS and larger if longer duration administrations
happen (e.g. infusion time). 0 values will be implemented by a short duration
of 1e-4 time units.}

\item{RATE}{Scalar or vector with rate of administration (numeric)
To implement a bolus, RATE needs to be set to 0. Definition of both RATE and
TINF will lead to an error.}

\item{ADDL}{Additional doses to be given. If undefined ADDL=0, coding for only a
single dose record. If ADDL is defined then also II argument needs to be defined.}

\item{II}{Dosing interval for additional doses, defined by ADDL. If II is defined
then also ADDL needs to be defined.}
}
\value{
An IQRdosing object.
}
\description{
IQRdosing objects represent dosing schemes that can be passed to simulation
functions included in IQRtools. Essentially, they are data frames with a
define set of columns and certain requirements.
}
\details{
The function IQRdosing constructs IQRdosing objects. Required input arguments
are: TIME, ADM, AMT, which need to be passed as numeric vectors.

Optional input arguments are: RATE or TINF, ADDL and II. RATE and TINF
are mutually exclusive and if defined need to be numeric vectors. ADDL and II
need to be present in pair and define the additional doses and the dosing interval.
During creation of an IQRdosing object the ADDL and II information will be
expanded to separate dose records in the IQRdosing object.

The resulting IQRdosing object has the following columns:
TIME, ADM, AMT, TINF
}
\seealso{
Other Simulation: 
\code{\link{IQReventTable}()},
\code{\link{create_IQReventData}()},
\code{\link{create_IQReventTable}()},
\code{\link{extract_IQRdosing}()},
\code{\link{is_IQRdosing}()},
\code{\link{is_IQReventTable}()},
\code{\link{is_IQRsimresMulti}()},
\code{\link{is_IQRsimres}()},
\code{\link{plot.IQRsimresMulti}()},
\code{\link{plot.IQRsimres}()},
\code{\link{print.IQRdosing}()},
\code{\link{print.IQReventTable}()},
\code{\link{print.IQRsimresMulti}()},
\code{\link{print.IQRsimres}()},
\code{\link{rbind_IQRdosing}()},
\code{\link{sim_IQRmodel}()}
}
\concept{Simulation}
