% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/general_classes_IQReventTable.R
\name{IQReventTable}
\alias{IQReventTable}
\title{IQReventTable class}
\usage{
IQReventTable(
  data,
  regression = NULL,
  abs0inputs = NULL,
  abs0Tk0param = NULL,
  FLAGfixDoseOverlap = FALSE
)
}
\arguments{
\item{data}{data.frame with the following columns: ID, TIME, ADM, AMT, TINF or RATE,
ADDL and II, additional regression parameter columns defined by the user.
ADDL and II will be handled by expansion. RATE can be present if TINF is not present.
If neither RATE nor TINF is present, TINF=0 will be assumed. TIME is the only required
column. ADM and AMT will be set to NA is not provided.}

\item{regression}{Vector with names of regression parameters (need to be present as
columns in "data")}

\item{abs0inputs}{numeric vector with numbers of inputs (ADM) that are of type
ABSORPTION0. If this argument is set also abs0Tk0param needs to be defined}

\item{abs0Tk0param}{character vector with names of regression parameters that
should be used as 0-order infusion time (by updating TINF). The regression
parameters for these values are kept in the event table. Ordering has to be
as in abs0inputs}

\item{FLAGfixDoseOverlap}{If TRUE then ensure non-overlapping dosing intervals if these occur
by re-defining the dosing events. If FALSE (default) in case of overlapping dose intervals,
error is issued.}
}
\value{
An IQReventTable object with the following columns:
ID, TIME, ADM, AMT, TINF (+ all defined regression parameters). The IQReventTable
will be sorted by ID, TIME, ADM
}
\description{
IQReventTable objects represent event tables that can be passed to simulation
functions (such as sim_IQRmodel). Essentially, they are data frames with a
define set of columns and certain requirements. These columns code for doses
and/or regression parameters.
}
\details{
Event tables are essentially data frames with the following minimum set of
columns: ID, TIME, ADM, AMT, TINF. ID codes the unique subject ID and is present
even if only a single subject is simulated. TIME is the time of dosing, ADM is the
number of the dosing (INPUT"number"), AMT is the amount of dosing, and TINF is the
dose administration time. Note that TINF=0 will be exchanged to TINF=0.0001.
Additional columns can be present in event tables and from these regression parameters
can be selected. Matching with model parameters will be done by name
of parameter and regression parameter column, which need to be identical (case-sensitive).
}
\seealso{
Other Simulation: 
\code{\link{IQRdosing}()},
\code{\link{create_IQReventData}()},
\code{\link{create_IQReventTable}()},
\code{\link{extract_IQRdosing}()},
\code{\link{is_IQRdosing}()},
\code{\link{is_IQReventTable}()},
\code{\link{is_IQRsimresMulti}()},
\code{\link{is_IQRsimres}()},
\code{\link{plot.IQRsimresMulti}()},
\code{\link{plot.IQRsimres}()},
\code{\link{print.IQRdosing}()},
\code{\link{print.IQReventTable}()},
\code{\link{print.IQRsimresMulti}()},
\code{\link{print.IQRsimres}()},
\code{\link{rbind_IQRdosing}()},
\code{\link{sim_IQRmodel}()}
}
\concept{Simulation}
