% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dMod_classes_IQRsysData.R,
%   R/nlme_classes_IQRnlmeData.R
\name{IQRsysData}
\alias{IQRsysData}
\alias{IQRnlmeData}
\title{Imports a csv dataset as IQRnlmeData object}
\usage{
IQRsysData(input, covNames = NULL, catNames = NULL, regressorNames = NULL)

IQRnlmeData(
  input,
  covNames = NULL,
  catNames = NULL,
  regressorNames = NULL,
  FLAGqsp = FALSE
)
}
\arguments{
\item{input}{Path to an NLME datafile or data.frame}

\item{covNames}{Vector with names of continuous covariates (matching column names
in the dataset (datafile).}

\item{catNames}{Vector with names of categorical covariates (matching column names
in the dataset (datafile).}

\item{regressorNames}{Vector with names of regrossors (matching column names
in the dataset (datafile).}

\item{FLAGqsp}{If TRUE then it is assumed that SysFit is used ... which allows to relax
some of the checks that are needed for NONMEM and MONOLIX. Do not use if you do not know
exactly what you are doing!}
}
\value{
If at least one of the required columns is not present an error will
be shown, otherwise the original data will be returned
}
\description{
Performs additional checks if the header of the dataset is adequate and
determines the "headerIdent" string based on the header names. If the optional
covNames, catNames, and regressorNames arguments are provided, it also will
make the correct settings for these in the "headerIdent" string.
}
\details{
Spaces in character strings will be replaced by ":::" for NONMEM and commata
in character strings will be replaced by ";" - to allow for a CSV output without
the need for quotes (not liked by NONMEM).

There is an intentional difference between an IQRnlmeData object and an IQRdataGENERAL
object that is exported as an NLME dataset. The separation allows to use datasets
for NLME modeling that have not been created through IQRtools. This means that for
now, the IQRnlmeData object does not re-use information from the attributes of
an IQRdataGENERAL object. This might change in the future.

In order to support also the changes in MONOLIX >=2018 we will do the following
changes to the data during import to an IQRnlmeData object:
\enumerate{
\item YTYPE: NA for dosing events
\item ADM: NA for observation events
}

IQRtools requires the presence of the following columns in an IQRnlmeData object
that is used for fitting:

\tabular{ll}{
COLUMN          \tab MEANING \cr
=============== \tab =================================================== \cr
IXGDF           \tab A column with index numbers of the records in the
dataset either defined for this dataset alone as 1,2,3, ... or
defined in a dataset from which this one here has been
derived and the IXGDF entries make the link between the
remaining records and the original records.\cr
USUBJID         \tab Unique subject identifier\cr
ID              \tab Modeling tool specific subject identifier (typically numeric)\cr
TIME            \tab Time relative to first dose (per subject)\cr
TIMEPOS         \tab Time from first event in the dataset (per subject)\cr
TAD             \tab Time after previous dose\cr
DV              \tab Observed value or 0 for doses or LLOQ value if CENS=1\cr
MDV             \tab Missing data flag\cr
EVID            \tab Event ID (0 for observations, 1 for dosing records)\cr
CENS            \tab Censoring flag (0 uncensored, 1 left censored)\cr
AMT             \tab Dosing amount if dose event, 0 if observation event\cr
ADM             \tab Number of the input if a dose, NA if an observation\cr
RATE            \tab This column is only used for NONMEM. This column is NOT
used for the specification of the infusion rate. This column
is only used to indicate with 0 a bolus and with -2 that
either the TINF column should be used for the infusion duration
(if INFUSION dosing) or that the infusion time should be estimated
(if ABSORPTION0 dosing) - in the latter case the entry in the TINF
column is not considered. If RATE colum is not defined as discussed
above, it will be updated and a new dataset for NONMEM will be generated
automatically. For MONOLIX this column is not used.
\cr
TINF            \tab Infusion time - used for both NONMEM and MONOLIX.
0 if bolus, >0 if infusion. If infusion (or 0th order absorption)
duration is selected to be estimated then the values in this column
are neglected.\cr
YTYPE or CMT    \tab If YTYPE: Number of output if observation, NA if dosing event.
If CMT: Number of output if observation, number of state
to which to add dose if dosing event.\cr
}
An OCC column might be present and can be used to define distinct occasions for consideration
of IOV in the modeling. An OCC column needs to contain numeric entries (integers only allowed).
}
\seealso{
Other IQRnlmeData: 
\code{\link{IQRcalcTAD}()},
\code{\link{IQRexpandADDLII}()},
\code{\link{date2dateday_IQRdataProgramming}()},
\code{\link{date2datetime_IQRdataProgramming}()},
\code{\link{date2time_IQRdataProgramming}()},
\code{\link{export_IQRnlmeData}()},
\code{\link{getLabels_dataframe}()},
\code{\link{is_IQRnlmeData}()},
\code{\link{plot.IQRnlmeData}()},
\code{\link{print.IQRnlmeData}()},
\code{\link{removeCommata_dataframe}()},
\code{\link{unlabel_dataframe}()}
}
\concept{IQRnlmeData}
