% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_classes_IQRnlmeProject.R
\name{IQRnlmeProject}
\alias{IQRnlmeProject}
\title{Creating an IQRnlmeProject object}
\usage{
IQRnlmeProject(
  est,
  projectPath,
  comment = "",
  tool = "MONOLIX",
  toolVersion = NULL,
  multiTestN = 1,
  multiTestSD = 0.5,
  FLAGanalytic = TRUE,
  keepProjectFolder = FALSE,
  algOpt.SEED = 123456,
  algOpt.K1 = 500,
  algOpt.K2 = 200,
  algOpt.NRCHAINS = NA,
  algOpt.NONMEM.METHOD = "SAEM",
  algOpt.NONMEM.MAXEVAL = 9999,
  algOpt.NONMEM.SIGDIGITS = 3,
  algOpt.NONMEM.PRINT = 1,
  algOpt.NONMEM.COVSTEP_MATRIX = "S",
  algOpt.NONMEM.ADVAN7 = TRUE,
  algOpt.NONMEM.N1 = 1000,
  algOpt.NONMEM.TOL = 9,
  algOpt.NONMEM.SIGL = 9,
  algOpt.NONMEM.M4 = FALSE,
  algOpt.NONMEM.FOCEIOFV = FALSE,
  algOpt.NONMEM.IMPORTANCESAMPLING = TRUE,
  algOpt.NONMEM.IMP_ITERATIONS = 10,
  algOpt.NONMEM.IMP_ISAMPLE = 1000,
  algOpt.NONMEM.ITS = TRUE,
  algOpt.NONMEM.ITS_ITERATIONS = 10,
  algOpt.NONMEM.WRES = NULL,
  algOpt.NONMEM.PRED = NULL,
  algOpt.NONMEM.RES = NULL,
  algOpt.MONOLIX.individualParameters = "conditionalMode",
  algOpt.MONOLIX.indivMCMClength = 50,
  algOpt.MONOLIX.indivNsim = 10,
  algOpt.MONOLIX.indivRatio = 0.05,
  algOpt.MONOLIX.logLikelihood = "Linearization",
  algOpt.MONOLIX.fim = "Linearization",
  algOpt.MONOLIX.variability = "FirstStage",
  algOpt.MONOLIX.startTime = NULL,
  algOpt.MONOLIX.STIFF = TRUE,
  algOpt.MONOLIX.M4 = FALSE,
  algOpt.NLMIXR.method = "SAEM",
  algOpt.NLMIXR.control = NULL,
  verbose = TRUE
)
}
\arguments{
\item{est}{IQRnlmeEst object}

\item{projectPath}{Path where to generate the NLME project}

\item{comment}{Character string. Allows the user to enter some information about the model.
This can be displayed in summary tables. It is stored in the model in the metadata section}

\item{tool}{character string with tool name ("NONMEM", "MONOLIX", or "NLMIXR")}

\item{toolVersion}{character string with the tool version name as defined
in the setup_options_IQRtools.R file (can be set with setup_IQRtools() function). By
default the first option defined in the respective lists in setup_options_IQRtools.R
is used.}

\item{multiTestN}{Doing robustness analysis - number of models to generate
with different initial guesses for fixed effects (randomly generated based
on POPvalues0). Only fixed effects which are considered for estimation will
be randomized. If multiTestN=1 (default) then no randomization is done.}

\item{multiTestSD}{Standard deviation to use to add noise__ to the initial
parameter guesses (default=0.5 (50\%CV))
Normal:         Parameter_guess + multiTestSD\emph{Parameter_guess}randomNumbers(0-1)
LogNormal:      Parameter_guess * exp(multiTestSD*randomNumbers(0-1))
LogitNormal:    Similar and between 0-1}

\item{FLAGanalytic}{TRUE: use analytic solution if possible, FALSE: always
use ODE based solution.}

\item{keepProjectFolder}{FALSE: erases projectFolder before creating new.
TRUE: keeps projectFolder contents when creating new
NLME project files.}

\item{algOpt.SEED}{Used for NONMEM SAEM, MONOLIX, and NLMIXR SAEM}

\item{algOpt.K1}{First iterations for SAEM. Same for NONMEM SAEM, MONOLIX, and NLMIXR SAEM}

\item{algOpt.K2}{Second iterations for SAEM. Same for NONMEM SAEM, MONOLIX, and NLMIXR SAEM}

\item{algOpt.NRCHAINS}{Used for NONMEM SAEM, MONOLIX, and NLMIXR SAEM. In case of few subjects
in the dataset and use of the SAEM method it is important to adjust this parameter.
It should be chosen such that the NRCHAINS * number of subjects in the dataset is >50.
The user can set this value but by default it is chosen automatically such that
NRCHAINS * number of subjects >= 50.}

\item{algOpt.NONMEM.METHOD}{'FO','FOCE','FOCEI','SAEM','BAYES' (ignored when using MONOLIX)}

\item{algOpt.NONMEM.MAXEVAL}{NONMEM option}

\item{algOpt.NONMEM.SIGDIGITS}{NONMEM option}

\item{algOpt.NONMEM.PRINT}{NONMEM option}

\item{algOpt.NONMEM.COVSTEP_MATRIX}{Option to set tzhe MATRIX type for the $COV step in NONMEM. Allowed are "S", "R", and "RSR".
"RSR" translates to unspecified MATRIX. IQRtools uses S as default. It works (for larger number of subjects - and for small number
MONOLIX is anyway better)}

\item{algOpt.NONMEM.ADVAN7}{TRUE: use ADVAN7 in case that model can be solved analytically. FALSE: use ADVAN5.
This is only used in case of NONMEM. ADVAN5 handles complex eigenvalues. ADVAN7 real ones and can be
faster.}

\item{algOpt.NONMEM.N1}{ESAMPLE setting for tables.}

\item{algOpt.NONMEM.TOL}{Tolerance settings for ADVAN13. For 1e-6 set TOL=6}

\item{algOpt.NONMEM.SIGL}{Number of significant digits for LL calculation. Default: undefined
If SIGL defined, Only used in gradient based methods. Good to set SIGDIG to <=SIGL/3.}

\item{algOpt.NONMEM.M4}{if CENS=1 entries present in data and M4=TRUE then the M4 method is used, otherwise the M3
method. this requires DV to be set to LLOQ and CENS=1 if the observation is BLLOQ.}

\item{algOpt.NONMEM.FOCEIOFV}{Determine the objective function value using an FOCE step with MAXEVAL=0.
Experts agree that the IMP method with MAPITER=0 leads to better objective functions. However, in practice this method
suffers from non reproducibility when running on multiple cores. Even at identical population parameter estimates the
obtained OFVs can differ greatly. Therefor, instead of using the IMP method after an SAEM estimation, this option
allows to perform a FOCEI step with MAXEVAL=0. This option cannot be used in combination with
algOpt.NONMEM.IMPORTANCESAMPLING.}

\item{algOpt.NONMEM.IMPORTANCESAMPLING}{Determine the objective function value with importance sampling}

\item{algOpt.NONMEM.IMP_ITERATIONS}{Number of iterations for importance sampling}

\item{algOpt.NONMEM.IMP_ISAMPLE}{ISAMPLE setting for NONMEM IMP runs. If fluctuation of objective function value to high in
the IMP run then select a higher value than the default of 1000.}

\item{algOpt.NONMEM.ITS}{Allow to run an ITS method as first method befor all other methods (METHOD)
ITS = FALSE or TRUE. ITS=TRUE only accepted if not FO!}

\item{algOpt.NONMEM.ITS_ITERATIONS}{Number of ITS iterations (NONMEM only)}

\item{algOpt.NONMEM.WRES}{String with name of weighted residuals to use in diagnostics (by default the standard ones
are used based the estimation method and on the NONMEM manual). Example: "CWRES", "CWRESI", "EWRES", etc.}

\item{algOpt.NONMEM.PRED}{String with name of predictions to use in diagnostics (by default the standard ones
are used based the estimation method and on the NONMEM manual). Example: "CPREDI", "EPRED", "NPRED", etc.}

\item{algOpt.NONMEM.RES}{String with name of residuals to use in diagnostics (by default the standard ones
are used based the estimation method and on the NONMEM manual). Example: "CRESI", "ERES", "NPRES", etc.}

\item{algOpt.MONOLIX.individualParameters}{MONOLIX option. 'conditionalMode' (default), 'conditionalMean', or 'All'}

\item{algOpt.MONOLIX.indivMCMClength}{MONOLIX option if individualParameters 'conditionalMean' or 'All'. Interval length of the MCMC convergence assessment for the conditional distribution}

\item{algOpt.MONOLIX.indivNsim}{MONOLIX option if individualParameters 'conditionalMean' or 'All'. Number of simulated individual parameters per individual}

\item{algOpt.MONOLIX.indivRatio}{MONOLIX option if individualParameters 'conditionalMean' or 'All'. Relative interval width (between 0 and 1)}

\item{algOpt.MONOLIX.logLikelihood}{MONOLIX option. 'Linearization' (default) or 'ImportanceSampling'}

\item{algOpt.MONOLIX.fim}{MONOLIX option. 'Linearization' (default) or 'StochasticApproximation'}

\item{algOpt.MONOLIX.variability}{MONOLIX option. 'no', 'Decreasing', 'FirstStage' (default), 'Mixed'}

\item{algOpt.MONOLIX.startTime}{MONOLIX option. Start time of integration. default: NULL (not set).}

\item{algOpt.MONOLIX.STIFF}{MONOLIX option. Use stiff solver (TRUE-default) or non-stiff (FALSE).}

\item{algOpt.MONOLIX.M4}{By default the M3 method is used - unless a LIMIT column is present in the dataset, then that
LIMIT is used. If algOpt.MONOLIX.M4=TRUE is set then the LIMIT column is enforced and set to 0. If a LIMIT column is
present in the dataset already than that column is overwritten.}

\item{algOpt.NLMIXR.method}{NLMIXR method ("SAEM" or "NLME" or "FOCEI")}

\item{algOpt.NLMIXR.control}{Control settings for chosen method. Use "nlmixr::saemControl()" or "nlmixr::nlmeControl()" or "nlmixr::foceiControl()", depending on chosen method.
If SAEM is chosen and nlmixr::saemControl(...) is defined, the options algOpt.SEED, algOpt.K1, algOpt.K2, and algOpt.NRCHAINS will be overwritten if the respective
arguments (seed, nBurn, nEm, nmc) are defined in the nlmixr::saemControl(...) call.}

\item{verbose}{Logical. If FALSE then text output in console is avoided (except warnings and errors).}
}
\value{
An IQRnlmeProject object
}
\description{
This function takes and IQRnlmeEst object and other optional input arguments
and exports an NMLE project to a folder. It is this folder that we call an
"IQRnlmeProject" object and it is tool specific (e.g. NONMEM, MONOLIX, or NLMIXR).
The original IQRmodel used here will be exported to the project folder as well
as "model.txt" The project folder will contain in addition the
IQRnlmeEst object as a project.est file.
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{compareModels_IQRnlmeProjectMulti}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}
}
\concept{IQRnlmeProject}
