% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compliance_tools.R
\name{IQRoutputDEFINE}
\alias{IQRoutputDEFINE}
\title{Exports a define file for the provided dataset}
\usage{
IQRoutputDEFINE(
  data,
  datasetName = NULL,
  datasetLocation = NULL,
  datasetDescription = "Analysis dataset",
  covInfoAdd = NULL,
  catInfoAdd = NULL,
  addColLabels = NULL,
  filename = NULL
)
}
\arguments{
\item{data}{data.frame object}

\item{datasetName}{A character string with a name for the dataset. It should not be longer than 8 characters if
you plan to send it to the FDA.}

\item{datasetLocation}{A character string with the location (path) to the dataset.}

\item{datasetDescription}{A short character string stating the purpose of this dataset}

\item{covInfoAdd}{(Handling covariates that are stored in additional columns in the dataset)
List with information about additional continuous covariates. The list needs to contain
4 named elements: COLNAME, NAME, UNIT, TIME.VARYING (in this order). Each value of these elements is a vector.
COLNAME defines the column names of the additional covariates, NAME the "real" name, UNIT their UNIT, and
TIME.VARYING is TRUE or FALSE depending ...
Example: \code{covInfoAdd <- list( COLNAME=c("WT0","AGE0"),NAME=c("Bodyweight at baseline","Age"),
  UNIT=c("kg","years"),TIME.VARYING=c(FALSE,FALSE))}}

\item{catInfoAdd}{(Handling covariates that are stored additional columns in the dataset)
List with information about additional categorical covariates. The list needs to contain
6 named elements: COLNAME, NAME, UNIT, VALUETXT, VALUES, TIME.VARYING (in this order). Each value of these elements is a vector.
COLNAME defines the column names of the additional covariates, NAME the "real" name, and UNIT their UNIT.
VALUETXT is a string defining a vector in R notation, containing the text version of the different levels.
VALUES is a string defining a numeric vector in  notation, containing the numeric version of the different levels (used in the
corresponding covariate column), and TIME.VARYING is TRUE or FALSE depending ...
Example: \code{catInfoAdd <- list( COLNAME=c("SEX","FOOD"),NAME=c("Gender","Food taken"),
  UNIT=c("-","-"),VALUETXT=c("Male,Female", "NO,YES"), VALUES=c("1,2","0,1"),TIME.VARYING=c(FALSE,FALSE))}}

\item{addColLabels}{List with named elements. Names are column names and
the value of an element is the label. If defining addColLabels for columns that
are already handled automatically, the provided labels will overwrite the automatic ones.
Example: \code{addColLabels <- list(IXGDF="Other label",NEWCCOL="Label for NEWCOL")}}

\item{filename}{If filename is not provided, then the filename is defined automatically by
"'datasetName'_define.rmd" and saved to the current work folder.}
}
\description{
Exports a define file for the provided dataset
}
\seealso{
Other Output: 
\code{\link{IQRinitCompliance}()},
\code{\link{IQRoutputCSV}()},
\code{\link{IQRoutputFigure}()},
\code{\link{IQRoutputFile}()},
\code{\link{IQRoutputPDFend}()},
\code{\link{IQRoutputPDFstart}()},
\code{\link{IQRoutputPDF}()},
\code{\link{IQRoutputPNG}()},
\code{\link{IQRoutputRDS}()},
\code{\link{IQRoutputTable}()},
\code{\link{IQRoutputValueTable}()},
\code{\link{IQRoutputXPT}()},
\code{\link{createSubmissionPack}()},
\code{\link{getModelSpecification}()},
\code{\link{getProgramSpecification}()},
\code{\link{import_IQRdataOriginal}()},
\code{\link{is_enabled_complianceMode}()},
\code{\link{is_enabled_rdsMode}()},
\code{\link{packageR_IQRtools}()},
\code{\link{print.IQRoutputTable}()},
\code{\link{read_IQRoutputTable}()},
\code{\link{text_IQRoutputTable}()}

Other Submission package: 
\code{\link{IQRoutputXPT}()},
\code{\link{addLabel_IQRaedataER}()},
\code{\link{addLabel_IQRdataGENERAL}()},
\code{\link{createSubmissionPack}()},
\code{\link{exportDEFINE_IQRaedataER}()},
\code{\link{exportDEFINE_IQRdataGENERAL}()},
\code{\link{exportDEFINEpdf_IQRdataGENERAL}()},
\code{\link{exportXPT_IQRaedataER}()},
\code{\link{getModelSpecification}()},
\code{\link{getProgramSpecification}()}
}
\concept{Output}
\concept{Submission package}
