% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/optimaldesign_classes_poped.R
\name{IQRpopEDdb}
\alias{IQRpopEDdb}
\title{Create a PopED database for an IQRmodel}
\usage{
IQRpopEDdb(model, design, modelSpec, transform_pop = FALSE, ...)
}
\arguments{
\item{model}{\code{\link{IQRmodel}} object}

\item{design}{list to define the design, can contain elements \code{time} (
observation time points), \code{dosing} (the dosing scheme),
\code{groupsize} (number of subjects per group). See details and example.}

\item{modelSpec}{list to define model specification. See example. See
\code{\link{IQRnlmeEst}} for a full description of the list structure.}

\item{transform_pop}{Define the reference frame for the population parameters.
If TRUE, the parameters are transformed according to the model specification
and standard errors are reported on the transformed scale. If FALSE, standard
error as reported on the original, untransformed scale.}

\item{...}{Arguments for create.poped.database}
}
\value{
A PopED database object, see \code{\link[PopED]{create.poped.database}}.
}
\description{
Create a PopED database for an IQRmodel
}
\details{
The \code{IQRpopEDdb} function uses the model, design and model specification
input to internally generate model prediction functions, residual error
functions and parameterization functions as being required
by \code{\link[PopED]{create.poped.database}}. Subsequently, it calls
\code{create.poped.database()} with the appropriate arguments. Additional
arguments can be passed using the \code{...} argument.

The \code{design} argument defines the experimental design by a list of
\itemize{
\item observation time points,
\item dosing scheme,
\item group size.
}

The typical design definition looks like this:

\verb{
design <- list(
  time = list(
    group1 = list(
      OUTPUT1 = c(1, 2, 5, 10),
      OUTPUT2 = c(1, 5, 20)
    ),
    group2 = list(
      OUTPUT1 = c(1, 2, 5, 10),
      OUTPUT2 = c(1, 5, 20)
    )
  ),
  dosing = list(
    group1 = IQRdosing(
      TIME = 0, ADM = 1, AMT = 40, TINF = 0
    ),
    group2 = . IQRdosing(
      TIME = 0, ADM = 1, AMT = 40, TINF = 0
    )),
  groupsize = list(
    group1 = 12, group2 = 3
  )
)
}

Groups names do not have to follow the scheme "groupx", but can be arbitrary names.

The element \bold{time} is defined per group and per model output. Vectors
of time points are expected. They can have different length. If the
observation time points are the same for all groups, it is sufficient to
define them for exactly one group.

The element \bold{dosing} is defined per group. See \code{\link{IQRdosing}}
for the correct specification of a dosing scheme.
\bold{The resulting dosing data frames for each group must have equal
dimensions.} Sometimes this must be enforced by introducing zero amounts by
hand. If the dosing is the same for all groups, it is sufficient to define
dosing for exactly one group.

The element \bold{groupsize} defines the number of subjects in each group.
The names found in the argument \code{groupsize} define the available groups.
They are used if \code{time} or \code{dosing} have been defined for one
group only to duplicate the element for each available group.

\bold{NOTE ABOUT COVARIATES}
By default, the AMT columns of the dosings are added as covariates such that popED can optimize the amounts.
Other covariates are not yet implemented and have to be specified manually via \code{...}
}
\seealso{
PopED functions: \code{\link[PopED]{model_prediction}},
\code{\link[PopED]{plot_model_prediction}},
\code{\link[PopED]{evaluate_design}}

Other Optimal Experiment Design: 
\code{\link{evaluate_IQRpopEDdb}()},
\code{\link{sim_IQRpopEDdb}()}
}
\concept{Optimal Experiment Design}
