% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dMod_classes_IQRsysProject.R
\name{IQRsysProject}
\alias{IQRsysProject}
\title{Creating an IQRsysProject object}
\usage{
IQRsysProject(
  est,
  projectPath,
  comment = "",
  keepProjectFolder = FALSE,
  SIMOPT.method = "lsodes",
  SIMOPT.atol = 1e-06,
  SIMOPT.rtol = 1e-06,
  SIMOPT.hmin = 0,
  SIMOPT.hmax = NULL,
  SIMOPT.hini = 0,
  SIMOPT.maxsteps = 5000,
  SIMOPT.nauxtimes = 0,
  SIMOPT.cores = 1,
  opt.method = "trust",
  opt.nfits = 1,
  opt.sd = 1,
  opt.rinit = 1,
  opt.rmax = 10,
  opt.iterlim = 100,
  opt.prior_sigma = 10,
  opt.parlower = NULL,
  opt.parupper = NULL,
  algOpt.SEED = 123456,
  FLAGprofileLL = F,
  FLAGkeepFits = F,
  FLAGchecks = T,
  ...
)
}
\arguments{
\item{est}{IQRsysEst object}

\item{projectPath}{Path where to generate the NLME project}

\item{comment}{character, comment describing the model. Used in overview tables.}

\item{keepProjectFolder}{if FALSE (default), remove existing project folder before writing the project again}

\item{SIMOPT.method}{character denoting the integration method, e.g. "lsodes" (default), "lsoda"
See the deSolve package for a list of available integrators}

\item{SIMOPT.atol}{numeric, absolute error tolerance}

\item{SIMOPT.rtol}{numeric, relative error tolerance}

\item{SIMOPT.hmin}{numeric, minimal integration step size}

\item{SIMOPT.hmax}{numeric, maximal integration step size}

\item{SIMOPT.hini}{numeric, initial integration step size}

\item{SIMOPT.maxsteps}{numeric, maximum number of integration steps}

\item{SIMOPT.nauxtimes}{additional times to simulate the prediction function}

\item{SIMOPT.cores}{number of cores used for parallel evaluation of conditions/individuals}

\item{opt.method}{optimization method ("trust" = trust region optimization using sensitivity equations,
"hjkb" = derivative-free optimization by the Hooke-Jeeves algorithm, also known as pattern search, or
"nmkb" = derivative-free optimization by the Nelder-Mead algorighm).}

\item{opt.nfits}{number of fits (starting from random positions)}

\item{opt.sd}{the standard deviation of the initial parameter sample from where optimization
is started}

\item{opt.rinit}{initial trust region radius for optimization}

\item{opt.rmax}{maximal trust region radius for optimization}

\item{opt.iterlim}{iteration limit for optimization}

\item{opt.prior_sigma}{use a quadratic prior to regularize the estimation problem. Larger sigma values
correspond to a weaker prior. The prior sigma should be much larger than the expected parameter uncertainty.
As a rule of thumb, "1" corresponds to a rather strong prior whereas "10" and larger corresponds to a weak
prior. To switch the prior off, use \code{NULL} as value.}

\item{opt.parlower, opt.parupper}{named vector providing lower/upper bounds for parameter values. Provide values on the linear (natural) scale, even if parameters are estimated on log-scale.}

\item{algOpt.SEED}{set seed for fully reproducible optimization outcome.}

\item{FLAGprofileLL}{(Default: FALSE) Compute profile likelihood if TRUE AND if best fit is converged.
Do not use \code{FLAGprofileLL = TRUE} with \code{opt.prior_sigma = NULL} unless the model is fully identifiable.}

\item{FLAGkeepFits}{When post-processing fits, keep original \code{parlist} output of \code{\link[dMod]{mstrust}}?
If FALSE, potential error messages might be deleted.}

\item{FLAGchecks}{Perform checks of the generated functions before running fits (Default: TRUE). For very large systems,
this step can be time-consuming in which case it might be switched off by the user.}

\item{...}{currently not used}
}
\value{
An IQRsysProject object
}
\description{
This function takes and IQRsysEst object and other optional input arguments
and exports an NMLE project to a folder. It is this folder that we call an
"IQRsysProject" object and it is tool specific (e.g. NONMEM, MONOLIX, or NLMIXR).
The original IQRmodel used here will be exported to the project folder as well
as "model.txt"
}
\seealso{
Other QSP: 
\code{\link{IQRsysEst}()},
\code{\link{IQRsysModel}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{as_IQRsysEst}()},
\code{\link{as_IQRsysProjectMulti}()},
\code{\link{as_IQRsysProject}()},
\code{\link{comparePars_IQRsysModel}()},
\code{\link{duplicate_IQRsysProject}()},
\code{\link{exportVariant_IQRmodel}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{export_IQRsysData}()},
\code{\link{getDosing_IQRsysModel}()},
\code{\link{getEmpiricalETACovarianceMatrix_IQRsysProject}()},
\code{\link{getOptTrace_IQRsysProject}()},
\code{\link{getPars_IQRoptTrace}()},
\code{\link{getPars_IQRsysModel}()},
\code{\link{getPrediction_IQRsysModel}()},
\code{\link{hasrun_IQRsysProject}()},
\code{\link{importVariant_IQRmodel}()},
\code{\link{import_IQRsysData}()},
\code{\link{is_IQRsysEst}()},
\code{\link{is_IQRsysModel}()},
\code{\link{is_IQRsysProjectMulti}()},
\code{\link{is_IQRsysProject}()},
\code{\link{load_IQRsysProject}()},
\code{\link{modelSpec_IQRsysEst}()},
\code{\link{model_IQRsysModel}()},
\code{\link{offsetTIME_IQRsysData}()},
\code{\link{plotDVPRED_IQRsysModel}()},
\code{\link{plotFit_IQRsysModel}()},
\code{\link{plotPars_IQRsysModel}()},
\code{\link{plotPred_IQRsysModel}()},
\code{\link{plotProfile_IQRsysModel}()},
\code{\link{plotWRES_IQRsysModel}()},
\code{\link{plotWaterfall_IQRsysModel}()},
\code{\link{plot_IQRoptTrace}()},
\code{\link{plot_IQRsysModel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{print.IQRsysProject}()},
\code{\link{profile_IQRsysModel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{run_IQRsysProjectMulti}()},
\code{\link{run_IQRsysProject}()},
\code{\link{sample_IQRsysModel}()},
\code{\link{sensitivity_IQRmodel}()},
\code{\link{setPars_IQRsysModel}()},
\code{\link{sim_IQRsysModel}()},
\code{\link{sim_IQRvirtualSubjects}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{simbio_updateParamIC_IQRmodel}()},
\code{\link{spmIIV_IQRsysProject}()},
\code{\link{spm_IQRsysProject}()},
\code{\link{switchOpt_IQRsysModel}()},
\code{\link{tablePars_IQRsysModel}()}
}
\author{
Daniel Lill, Daniel Kaschek
}
\concept{QSP}
