% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tables_classes_IQRtable.R
\name{IQRtable}
\alias{IQRtable}
\title{Flexibly generate output tables based on a data frame and derived statistical quantities}
\usage{
IQRtable(data, stat, ...)
}
\arguments{
\item{data}{data frame, the input.}

\item{stat}{a statistical function as returned by \link{statSE} or \link{statCI}.}

\item{...}{defining the outputs, e.g. \code{"Value + 95\%CI" = "value [lower.95, upper.95]"}.
See also details and examples.}
}
\value{
Character matrix with one column for each argument in \code{...}. The first element in a column is always the
name of the argument name in \code{...} (header), the other elements correspond to the formatted values.
For exporting use \link{as.data.frame.IQRtable} before \link{IQRoutputTable}
}
\description{
The function allows to define a table composed of user-define output columns being specified by
strings and keywords.
}
\details{
Keywords in the strings in \code{...} are replaced by values provided by \code{stat}
or found in \code{data}. First, all statistical key words are replaced (see \link{statSE} and \link{statCI}
for a list
of keywords). Second, the employed column names of \code{data} are replace by the data values. All non-recognized
symbols/words are returned as they are.

Keywords can be composed to flexibly control the output format. For example \code{value (rse\%)} could return
\code{1.36 (18.5\%)} for a value of \code{1.3564} and a standard error of \code{0.25123}.
}
\examples{
mydata <- data.frame(
  parameter = c("A", "B"),
  value = c(pi, pi),
  lower = c(1.5214, -Inf),
  upper = c(37.4831, 4.27134),
  se    = c(0.082723, 0.57)
)

as_IQRtable(mydata)

mytable <- IQRtable(
  data = mydata,
  stat = statSE(value, se),
  # Output
  `Parameter`      = "parameter",
  `Value`          = "value",
  `CI [95\%]`       = "[lower.95, upper.95]",
  `RSE [\%]`        = "rse\%",
  `Value + 68\% CI` = "value + [lower.68, upper.68]",
  `Value (RSE)`    = "value (rse\%)"
)

print(mytable)

# To export the table, convert to data frame and use IQRoutputTable()
# IQRoutputTable(as.data.frame(mytable), filename = "mytable.txt")

mytable <- IQRtable(
  data = mydata,
  stat = statCI(value, lower, upper, CL = 0.68),
  # Output
  `Parameter`      = "parameter",
  `Value`          = "value",
  `CI [95\%]`       = "[lower.95, upper.95]",
  `RSE [\%]`        = "rse\%",
  `Value + 68\% CI` = "value + [lower.68, upper.68]",
  `Value (RSE)`    = "value (rse\%)"
)

print(mytable)

}
\seealso{
Other IQR Table: 
\code{\link{as.data.frame.IQRtable}()},
\code{\link{as_IQRtable}()},
\code{\link{cjoin_IQRtable}()},
\code{\link{composeByRule_IQRtable}()},
\code{\link{compose_IQRtable}()}
}
\author{
Daniel Kaschek, IntiQuan
}
\concept{IQR Table}
