% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/estimation_classes_IQRest.R
\name{addCovariateToModelSpec_IQRest}
\alias{addCovariateToModelSpec_IQRest}
\title{Extends the model specification by covariate relationships.}
\usage{
addCovariateToModelSpec_IQRest(
  modelSpec,
  covariateModel,
  covariateModelValues = NULL,
  COVestimate = NULL,
  COVcentering = NULL
)
}
\arguments{
\item{modelSpec}{Model specification to be extended.}

\item{covariateModel}{Named list with covariate relationships to be added.}

\item{covariateModelValues}{Optional named list with initial covariate values}

\item{COVestimate}{Optional named list with flags whether to estimate the respective
covariate relationship}

\item{COVcentering}{Optional named vector with reference values for covariates
(will only be applied for non-existing reference values)}
}
\value{
Returns modified model specification.
}
\description{
Can be used for syspharm and NLME type of estimation objects. This is a convenience function to ease the extension
of model specification by covariate relationships taking care of the entries for 'covariateModel', 'COVestimate',
'COVcentering', and 'covariateModelValues'
}
\examples{
\dontrun{
# Model specification with one covariate relationship
modelSpec0 <- list(
  POPvalues = c(ka = 0.1, CL = 1, Vc = 20),
  covariateModel = list(CL = "BWT")
)

# Add covariate model with initial guess
modelSpec1 <- addCovariateToModelSpec_IQRest(
  modelSpec = modelSpec0,
  covariateModel = list(Vc = "SEX"),
  covariateModelValues = list(Vc = c("SEX" = 0.5))
)
}
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{compareModels_IQRnlmeProjectMulti}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}
}
\concept{IQRnlmeProject}
