% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_classes_IQRdataGeneral.R
\name{addIndivRegressors_IQRdataGENERAL}
\alias{addIndivRegressors_IQRdataGENERAL}
\title{Adds individual parameter estimates from a IQRnlmeProject to a dataset.
Existing regression parameters are kept.
Existing columns with same names as regression parameters are substituted.}
\usage{
addIndivRegressors_IQRdataGENERAL(
  projectPath,
  dataPath = NULL,
  data = NULL,
  filename = NULL,
  model = NULL,
  regressorNames = NULL,
  doseNAMES = NULL,
  obsNAMES = NULL,
  FLAGrmNoInd = FALSE,
  FLAGnoCovSample = FALSE,
  FLAGxpt = FALSE,
  FLAGdefine = TRUE,
  FLAGzip = FALSE,
  addColLabels = NULL
)
}
\arguments{
\item{projectPath}{IQRnlmeProject folder from which the estimates are added
as regression parameters.}

\item{dataPath}{path to dataset (IQRdataGENERAL) to which regression parameters
will be added}

\item{data}{Instead of the path in dataPath also an IQRdataGENERAL object can be
provided.}

\item{filename}{Filename of the NLME CSV file to create (not more than 8 characters
without extension - if FLAGxpt=TRUE). If filename not provided the dataset is returned
by the function.}

\item{model}{If given (IQR model or path to IQR model file), set of added
regression parameters is reduced to parameters that exist in the model}

\item{regressorNames}{If given (character vector), set of added regression
parameters is reduced to given set.}

\item{doseNAMES}{Vector with dose record names to use during NLME data export. ADM values will be set according
to the order of NAMEs in the doseNAMES argument}

\item{obsNAMES}{Vector with observation names to use during NLME data export. YTYPE values will be set according
to the order of NAMEs in the obsNAMES argument}

\item{FLAGrmNoInd}{If TRUE then subjects for which no individual regression parameters
are available will be removed. If FALSE, population mean parameters will be used instead.}

\item{FLAGnoCovSample}{If TRUE then if individual parameters are missing they will be set to
point mean estimates without consideration of covariates. If FALSE then covariates will be considered.}

\item{FLAGxpt}{If TRUE then a SAS XPT file will be generated additionally}

\item{FLAGdefine}{If TRUE then a define.rmd file will be generated additionally. The syntax
of this file is in the IQReport markdown syntax and allows human readbility. The IQReport
software can subsequently be used to convert this file to Microsoft WORD, allowing further
editing and saving as a PDF file. Please read the documentation for the \link{exportDEFINE_IQRdataGENERAL}
function to learn more about IQReport.}

\item{FLAGzip}{If TRUE then the exported data files (.csv, .atr, .xpt, .docx, .rmd, etc.) will be zipped
and placed in the potential path in the "filename" as the filename.dat.zip. Other files will be removed.}

\item{addColLabels}{List with named elements. Names are column names and
the value of an element is the label. If defining addColLabels for columns that
are already handled automatically, the provided labels will overwrite the automatic ones.
Example: \code{addColLabels <- list(IXGDF="Other label",NEWCCOL="Label for NEWCOL")}.
This information is needed only for XPT and define file generation}
}
\value{
If a filename is provided, NULL is returned. Otherwise a list is returned with a vector of the added
regression parameter names and the updated dataset.
}
\description{
In the case that individual parameter information is not available in the
model fit, then the regression parameters will be set to population mean parameters.
By default, if covariates have been used in the model, the mean parameters will
by adjusted by covariates. Using FLAGnoCovSample=TRUE this can be disabled and
only mean point estimates will be imputed.
}
\seealso{
Other IQRdataGeneral: 
\code{\link{+.IQRdataGENERAL}()},
\code{\link{IQRcalcTAD}()},
\code{\link{IQRdataGENERAL}()},
\code{\link{IQRexpandADDLII}()},
\code{\link{IQRloadCSVdata}()},
\code{\link{IQRsaveCSVdata}()},
\code{\link{addLabel_IQRdataGENERAL}()},
\code{\link{attributes0}()},
\code{\link{blloqInfo_IQRdataGENERAL}()},
\code{\link{blloq_IQRdataGENERAL}()},
\code{\link{check_IQRdataGENERAL}()},
\code{\link{clean_IQRdataGENERAL}()},
\code{\link{combine_IQRdataGENERAL}()},
\code{\link{convertCat2Text}()},
\code{\link{covImpute_IQRdataGENERAL}()},
\code{\link{date2dateday_IQRdataProgramming}()},
\code{\link{date2datetime_IQRdataProgramming}()},
\code{\link{date2time_IQRdataProgramming}()},
\code{\link{exportDEFINE_IQRaedataER}()},
\code{\link{exportDEFINE_IQRdataGENERAL}()},
\code{\link{exportDEFINEpdf_IQRdataGENERAL}()},
\code{\link{exportSYS_IQRdataGENERAL}()},
\code{\link{export_IQRdataGENERAL}()},
\code{\link{getLabels_dataframe}()},
\code{\link{getNAcolNLME_IQRdataGENERAL}()},
\code{\link{handleSameTimeObs_IQRdataGENERAL}()},
\code{\link{is_IQRdataGENERAL}()},
\code{\link{loadATRinfo_csvData}()},
\code{\link{loadAttributeFile}()},
\code{\link{load_IQRdataGENERAL}()},
\code{\link{mapCategoricalCovariate_IQRnlmeProject}()},
\code{\link{mapCategoricalCovariate_csvData}()},
\code{\link{mapContinuousCovariate_IQRnlmeProject}()},
\code{\link{mapContinuousCovariate_csvData}()},
\code{\link{mutateCov_IQRdataGENERAL}()},
\code{\link{obfuscate_IQRdataGENERAL}()},
\code{\link{plot.IQRdataGENERAL}()},
\code{\link{plotCorCat_IQRdataGENERAL}()},
\code{\link{plotCorCovCat_IQRdataGENERAL}()},
\code{\link{plotCorCov_IQRdataGENERAL}()},
\code{\link{plotCovDistribution_IQRdataGENERAL}()},
\code{\link{plotDoseSchedule_IQRdataGENERAL}()},
\code{\link{plotIndiv_IQRdataGENERAL}()},
\code{\link{plotRange_IQRdataGENERAL}()},
\code{\link{plotSampleSchedule_IQRdataGENERAL}()},
\code{\link{plotSpaghetti_IQRdataGENERAL}()},
\code{\link{print.IQRdataGENERAL}()},
\code{\link{removeCommata_dataframe}()},
\code{\link{rmAMT0_IQRdataGENERAL}()},
\code{\link{rmDosePostLastObs_IQRdataGENERAL}()},
\code{\link{rmIGNOREd_IQRdataGENERAL}()},
\code{\link{rmMissingTIMEobsRecords_IQRdataGENERAL}()},
\code{\link{rmNOobsSUB_IQRdataGENERAL}()},
\code{\link{rmNonTask_IQRdataGENERAL}()},
\code{\link{rmPLACEBO_IQRdataGENERAL}()},
\code{\link{rmSubjects_IQRdataGENERAL}()},
\code{\link{setIGNORErecords_IQRdataGENERAL}()},
\code{\link{setMissingDVobsRecordsIGNORE_IQRdataGENERAL}()},
\code{\link{subset.IQRdataGENERAL}()},
\code{\link{summary.IQRdataGENERAL}()},
\code{\link{summaryCat_IQRdataGENERAL}()},
\code{\link{summaryCov_IQRdataGENERAL}()},
\code{\link{summaryObservations_IQRdataGENERAL}()},
\code{\link{transformObs_IQRdataGENERAL}()},
\code{\link{unlabel_dataframe}()}
}
\concept{IQRdataGeneral}
