% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/estimation_classes_modelSpec.R
\name{addPar_modelSpec}
\alias{addPar_modelSpec}
\alias{addCov_modelSpec}
\alias{addErr_modelSpec}
\alias{removePar_modelSpec}
\alias{removeCov_modelSpec}
\alias{removeErr_modelSpec}
\title{Convenience functions for model spec manipulation}
\usage{
addPar_modelSpec(
  modelSpec,
  parname,
  value,
  estimate = NULL,
  distribution = NULL,
  IIVvalue = NULL,
  IIVestimate = NULL
)

addCov_modelSpec(
  modelSpec,
  parname,
  covname,
  value = NULL,
  estimate = NULL,
  center = NULL
)

addErr_modelSpec(modelSpec, output, value_abs = 0, value_rel = 0)

removePar_modelSpec(modelSpec, parname)

removeCov_modelSpec(modelSpec, parname, covname)

removeErr_modelSpec(modelSpec, output)
}
\arguments{
\item{modelSpec}{model specification list, see \link{modelSpec_IQRest}.}

\item{parname}{character (for add functions), or character vector (for remove functions).
The name of the parameter(s) to add or remove.}

\item{value}{numeric, value of the parameter.}

\item{estimate}{integer or NULL (default). 0 = fix, 1 = estimate, \code{NULL} = auto.}

\item{distribution}{character or NULL (default), "L" = log, "G" = logit, "N" = natural, \code{NULL} = auto.}

\item{IIVvalue}{numeric or NULL (default), value for standard deviation of the random effect.}

\item{IIVestimate}{integer or NULL (default), 0 = fix to zero, 1 = estimate, 2 = fix to IIVvalue, \code{NULL} = auto.}

\item{covname}{character (for add function), or character vector (for remove function).}

\item{center}{numeric, the reference value for the covariate. \strong{Attention:} currently,
it is not possible to have different center for different parmeters of the same covariate. When
center is provided with the \code{addCov} function, its current value will be overwritten.}

\item{output}{character ("OUTPUT1", "OUTPUT2", etc) or numeric (1, 2, 3, etc.), pointing to the output
for which the error model should be defined.}

\item{value_abs}{numeric, initial value of absolute error. If 0 (default), no absolute error is considered.}

\item{value_rel}{numeric, initial value of the relative error. If 0 (default), no relative error is considered.}
}
\value{
model specification list
}
\description{
\verb{add*} functions create entries in the model spec if they do not yet exist and
\strong{overwrite} entries if present. Please consider using \link{print_modelSpec} after
all manipulations to check if manipulations took the expected effect.
\verb{remove*} functions remove entries from all places in the model specification.
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{compareModels_IQRnlmeProjectMulti}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}
}
\author{
Daniel Kaschek, IntiQuan
}
\concept{IQRnlmeProject}
