% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_classes_IQRdataGeneral.R
\name{blloq_IQRdataGENERAL}
\alias{blloq_IQRdataGENERAL}
\title{Updates an IQRdataGENERAL object for a specific BLLOQ handling method}
\usage{
blloq_IQRdataGENERAL(data, methodBLLOQ = "M1")
}
\arguments{
\item{data}{IQRdataGENERAL object}

\item{methodBLLOQ}{Character string, determining the method to use. Allowed are:
"M1","M3","M4","M5","M6", and "M7"}
}
\value{
An updated IQRdataOBJECT with handled BLLOQ information
}
\description{
This function allows to handle BLOQ data in several different ways by
updating the IQRdataOBJECT according to needs. As BLLOQ handling methods
standard Beales Methods for NONMEM are considered (see below in details).
}
\details{
\itemize{
\item M1: Ignore values below LLOQ (MDV=1 , CENS=0)
\item M3: Estimate likelihood at times measurements are BLLOQ (CENS=1 and DV=BLOQ)
\item M4: Like M3 but also assume measurements are >=0 (CENS=1 and DV=BLOQ)
\item M5: Replace all BLLOQ with LLOQ/2 (DV=LLOQ/2, CENS=0)
\item M6: Replace first BLLOQ with LLOQ/2, ignore others (CENS=0, DV=LLOQ/2, MDV=0 for
first occurence in a sequence, MDV=1 for following in sequence)
\item M7: Replace all BLLOQ with zero (DV=0, CENS=0, MDV=0)
}

IQRtools handles all on the level of the dataset - even for the M3 and M4 methods.
The NONMEM models will be automatically adapted to the chosen method. The changes
in the dataset for M3 and M4 methods are identical and the choice between M3 or M4 is
done when generating the NONMEM model. In MONOLIX instead of M3 or M4 the
MONOLIX own method is used.

Each record that obtains MDV=1 through this function will also obtain an
entry in the IGNORE column (if not yet present). It will be "BLLOQ (Mx)"
where the x is replaced by the number of the method that is being used.

Records that are already IGNORED by having set the IGNORE column and
MDV=1 are not considered and remain unchanged.
}
\seealso{
Other IQRdataGeneral: 
\code{\link{+.IQRdataGENERAL}()},
\code{\link{IQRcalcTAD}()},
\code{\link{IQRdataGENERAL}()},
\code{\link{IQRexpandADDLII}()},
\code{\link{IQRloadCSVdata}()},
\code{\link{IQRsaveCSVdata}()},
\code{\link{addIndivRegressors_IQRdataGENERAL}()},
\code{\link{addLabel_IQRdataGENERAL}()},
\code{\link{attributes0}()},
\code{\link{blloqInfo_IQRdataGENERAL}()},
\code{\link{check_IQRdataGENERAL}()},
\code{\link{clean_IQRdataGENERAL}()},
\code{\link{combine_IQRdataGENERAL}()},
\code{\link{convertCat2Text}()},
\code{\link{covImpute_IQRdataGENERAL}()},
\code{\link{date2dateday_IQRdataProgramming}()},
\code{\link{date2datetime_IQRdataProgramming}()},
\code{\link{date2time_IQRdataProgramming}()},
\code{\link{exportDEFINE_IQRaedataER}()},
\code{\link{exportDEFINE_IQRdataGENERAL}()},
\code{\link{exportDEFINEpdf_IQRdataGENERAL}()},
\code{\link{exportSYS_IQRdataGENERAL}()},
\code{\link{export_IQRdataGENERAL}()},
\code{\link{getLabels_dataframe}()},
\code{\link{getNAcolNLME_IQRdataGENERAL}()},
\code{\link{handleSameTimeObs_IQRdataGENERAL}()},
\code{\link{is_IQRdataGENERAL}()},
\code{\link{loadATRinfo_csvData}()},
\code{\link{loadAttributeFile}()},
\code{\link{load_IQRdataGENERAL}()},
\code{\link{mapCategoricalCovariate_IQRnlmeProject}()},
\code{\link{mapCategoricalCovariate_csvData}()},
\code{\link{mapContinuousCovariate_IQRnlmeProject}()},
\code{\link{mapContinuousCovariate_csvData}()},
\code{\link{mutateCov_IQRdataGENERAL}()},
\code{\link{obfuscate_IQRdataGENERAL}()},
\code{\link{plot.IQRdataGENERAL}()},
\code{\link{plotCorCat_IQRdataGENERAL}()},
\code{\link{plotCorCovCat_IQRdataGENERAL}()},
\code{\link{plotCorCov_IQRdataGENERAL}()},
\code{\link{plotCovDistribution_IQRdataGENERAL}()},
\code{\link{plotDoseSchedule_IQRdataGENERAL}()},
\code{\link{plotIndiv_IQRdataGENERAL}()},
\code{\link{plotRange_IQRdataGENERAL}()},
\code{\link{plotSampleSchedule_IQRdataGENERAL}()},
\code{\link{plotSpaghetti_IQRdataGENERAL}()},
\code{\link{print.IQRdataGENERAL}()},
\code{\link{removeCommata_dataframe}()},
\code{\link{rmAMT0_IQRdataGENERAL}()},
\code{\link{rmDosePostLastObs_IQRdataGENERAL}()},
\code{\link{rmIGNOREd_IQRdataGENERAL}()},
\code{\link{rmMissingTIMEobsRecords_IQRdataGENERAL}()},
\code{\link{rmNOobsSUB_IQRdataGENERAL}()},
\code{\link{rmNonTask_IQRdataGENERAL}()},
\code{\link{rmPLACEBO_IQRdataGENERAL}()},
\code{\link{rmSubjects_IQRdataGENERAL}()},
\code{\link{setIGNORErecords_IQRdataGENERAL}()},
\code{\link{setMissingDVobsRecordsIGNORE_IQRdataGENERAL}()},
\code{\link{subset.IQRdataGENERAL}()},
\code{\link{summary.IQRdataGENERAL}()},
\code{\link{summaryCat_IQRdataGENERAL}()},
\code{\link{summaryCov_IQRdataGENERAL}()},
\code{\link{summaryObservations_IQRdataGENERAL}()},
\code{\link{transformObs_IQRdataGENERAL}()},
\code{\link{unlabel_dataframe}()}
}
\concept{IQRdataGeneral}
