% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_tools_bootstrap.R
\name{bootstrap_IQRnlmeProject}
\alias{bootstrap_IQRnlmeProject}
\title{Perform a non-parametric bootstrap on an IQRnlmeProject}
\usage{
bootstrap_IQRnlmeProject(
  projectPath,
  bootstrapPath = "bootstrap",
  Nsamples = 200,
  group = NULL,
  FLAGanalysisOnly = FALSE,
  FLAGgenerateModelsOnly = FALSE,
  Nparallel = 1,
  ncores = 1,
  SIGDIG = 4,
  FLAGreturnOutput = FALSE,
  FLAGremoveRESULTSORIG = FALSE
)
}
\arguments{
\item{projectPath}{Path to an NLME project folder.}

\item{bootstrapPath}{Path where to store the bootstrap projects}

\item{Nsamples}{Number of bootstrap samples}

\item{group}{String with group name to use for stratification (some column
name in the dataset that contains categorical information).
The sampling of the dataset then is done to approximately keep the
proportion of the group categories the same as in the original dataset.
Can be vector of column names in the dataset. Stratification will then
be done by all of the columns.}

\item{FLAGanalysisOnly}{If set to TRUE then the function does not re-run the parameter
estimation but assumes that bootstrap models already have
been executed and only produces the output}

\item{FLAGgenerateModelsOnly}{If set to TRUE then the function only generates the models}

\item{Nparallel}{Number of parallel model runs}

\item{ncores}{Number of cores to parallelize single run}

\item{SIGDIG}{Number of significant digits for table information}

\item{FLAGreturnOutput}{Logical. If TRUE then the resulting plots and tables are returned as
list of ggplot and IQRoutputTable objects}

\item{FLAGremoveRESULTSORIG}{Logical. If TRUE then the RESULTSORIG folder will be removed.
this will save a considerable amount of space on disk.}
}
\value{
See FLAGreturnOutput
}
\description{
Runs a non-parametric bootstrap analysis on the provided NLME project folder.
The provided NLME fit is used as the reference. NSAMPLES bootstrap fits
are generated and run. Stratification for dataset resampling is possible
along a single column in the dataset.
The results are plotted and stored as a PDF. 95\% confidence intervals and
medians are shown for the bootstrap results. For the reference model the
point estimate and its 95\% confidence interval are shown.
Additionally to the plots a text file (results_bootstrap.txt) with tabular
information is generated in the bootstrapPath.
Fits that lead to an objective function of NaN are assumed to be "crashed
fits" and are excluded from the bootstrap result generation.
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{compareModels_IQRnlmeProjectMulti}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}
}
\concept{Bootstrap}
\concept{IQRnlmeProject}
