% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_param_sampling.R
\name{calcIndParamValues}
\alias{calcIndParamValues}
\title{Calculate individual parameter values by applying sampled random effects
to typical individual parameter values}
\usage{
calcIndParamValues(spec, typicalIndParamValues, randomEffects)
}
\arguments{
\item{spec}{a filename (character string) denoting the path to a GPF
excel file, or a GPF object, or an IQRnlmeParamSpec object.}

\item{typicalIndParamValues}{a data.frame specifying typical individual
parameter values on an original (not transformed to normal) scale for
the model parameters in \code{spec}. Apart from the
parameter columns, this data.frame should have an \code{ID.POP} and an
\code{ID} column corresponding to the columns \code{ID.POP} and \code{ID}
in \code{randomEffects}. This data.frame
should have the same number of rows as \code{randomEffects}. See
\code{\link{calcTypicalIndParamValues}}.}

\item{randomEffects}{a data.frame specifying random effect values on a
normal (transformed) scale for the model parameters in \code{spec}.
Apart from the parameter columns, this data.frame should have an \code{ID.POP}
and an \code{ID} integer columns corresponding to population id and individual id
within a population respectively. See \code{\link{sampleRandomEffects}}.}
}
\value{
a data.frame with the same column names as the arguments \code{typicalIndParamValues}
and \code{randomEffects}. The individual parameter values in this data.frame are on
the original scale (not transformed to a normal scale).
}
\description{
Calculate individual parameter values by applying sampled random effects
to typical individual parameter values
}
\examples{
\dontrun{
#See the examples for sampleIndParamValues:
?sampleIndParamValues
}
# See examples in \code{\link{sampleIndParamValues}}.

}
\seealso{
\href{https://iqrtools.intiquan.com/doc/book/paramsampling.html}{Random sampling of NLME model parameters}

\href{https://iqrtools.intiquan.com/doc/book/GPF.html}{General Parameter Format}

Other Parameter sampling: 
\code{\link{calcTypicalIndParamValues}()},
\code{\link{combineGPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{generate_GPFFromProjectInfo}()},
\code{\link{getCorMatrixUncertainty}()},
\code{\link{getCovMatrixIIV}()},
\code{\link{getCovMatrixUncertainty}()},
\code{\link{getNamesAllParameters}()},
\code{\link{getNamesCovariateParameters}()},
\code{\link{getNamesCovariates}()},
\code{\link{getNamesErrorParameters}()},
\code{\link{getNamesIIVCorrParameters}()},
\code{\link{getNamesIIVParameters}()},
\code{\link{getNamesModelParameters}()},
\code{\link{getParamEstimates}()},
\code{\link{getParamTransformationTypes}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{is_GPF}()},
\code{\link{is_IQRnlmeParamSpec}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sampleIDs}()},
\code{\link{sampleIndParamValues}()},
\code{\link{sampleParamFromUncertainty}()},
\code{\link{sampleRandomEffects}()},
\code{\link{sample_GPF}()},
\code{\link{select_FromGPF}()},
\code{\link{specifyParamSampling}()},
\code{\link{transformParamToNormal}()},
\code{\link{untransformParamFromNormal}()}
}
\author{
Venelin Mitov (IntiQuan)
}
\concept{Parameter sampling}
\keyword{internal}
