% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_param_sampling.R
\name{calcTypicalIndParamValues}
\alias{calcTypicalIndParamValues}
\title{Calculate typical individual parameter values by applying covariate
formulae to reference population parameter values}
\usage{
calcTypicalIndParamValues(
  spec,
  referencePopParamValues,
  data,
  doCartesian = TRUE
)
}
\arguments{
\item{spec}{a filename (character string) denoting the path to a GPF
excel file, or a GPF object, or an IQRnlmeParamSpec object.}

\item{referencePopParamValues}{a data.frame with a column ID.POP and columns
including at least the model parameters and the betas.}

\item{data}{a data.frame describing patient or other subject covariate and
regressor data. If nrow(data) == nrow(referencePopParamValues), then
the function supports two possible treatments depending on doCartesian (see
description for doCartesian argument below).}

\item{doCartesian}{a logical. When TRUE (the DEFAULT), each row in referencePopParamValues
is bound to data, so that the returned data.frame contains
nrow(referencePopParamValues)*nrow(data) rows. If FALSE
(only allowed when \code{nrow(referencePopParamValues) == nrow(data)}), then
the two tables are joined using \code{\link{cbind}}.}
}
\value{
a data.frame with number of rows equal either to
\code{nrow(referencePopParamValues)*nrow(data)} (when \code{doCartesian == TRUE) (default)}),
or \code{nrow(referencePopParamValues)} (when
\code{doCartesian == FALSE && nrow(referencePopParamValues) == nrow(data)}).
The columns in this data.frame are ID.POP, ID and other columns matching
the model parameters according to spec.
}
\description{
Calculate typical individual parameter values by applying covariate
formulae to reference population parameter values
}
\examples{
\dontrun{
#See the examples for sampleIndParamValues:
?sampleIndParamValues
}

}
\seealso{
\href{https://iqrtools.intiquan.com/doc/book/paramsampling.html}{Random sampling of NLME model parameters}

\href{https://iqrtools.intiquan.com/doc/book/GPF.html}{General Parameter Format}

Other Parameter sampling: 
\code{\link{calcIndParamValues}()},
\code{\link{combineGPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{generate_GPFFromProjectInfo}()},
\code{\link{getCorMatrixUncertainty}()},
\code{\link{getCovMatrixIIV}()},
\code{\link{getCovMatrixUncertainty}()},
\code{\link{getNamesAllParameters}()},
\code{\link{getNamesCovariateParameters}()},
\code{\link{getNamesCovariates}()},
\code{\link{getNamesErrorParameters}()},
\code{\link{getNamesIIVCorrParameters}()},
\code{\link{getNamesIIVParameters}()},
\code{\link{getNamesModelParameters}()},
\code{\link{getParamEstimates}()},
\code{\link{getParamTransformationTypes}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{is_GPF}()},
\code{\link{is_IQRnlmeParamSpec}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sampleIDs}()},
\code{\link{sampleIndParamValues}()},
\code{\link{sampleParamFromUncertainty}()},
\code{\link{sampleRandomEffects}()},
\code{\link{sample_GPF}()},
\code{\link{select_FromGPF}()},
\code{\link{specifyParamSampling}()},
\code{\link{transformParamToNormal}()},
\code{\link{untransformParamFromNormal}()}
}
\author{
Venelin Mitov (IntiQuan)
}
\concept{Parameter sampling}
\keyword{internal}
