% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_classes_IQRdataGeneral.R
\name{clean_IQRdataGENERAL}
\alias{clean_IQRdataGENERAL}
\title{Wrapper for several IQRdataGENERAL cleaning functions}
\usage{
clean_IQRdataGENERAL(
  data,
  methodBLLOQ = "M1",
  records = NULL,
  subjects = NULL,
  FLAGrmPlacebo = FALSE,
  FLAGrmIGNOREDrecords = FALSE,
  FLAGrmDosePostLastObs = FALSE,
  continuousCovs = NULL,
  categoricalCovs = NULL,
  pathname = NULL
)
}
\arguments{
\item{data}{IQRdataGENERAL object}

\item{methodBLLOQ}{Character string, determining the method to use. Allowed are:
"M1","M3","M4","M5","M6", and "M7". If NULL then not done.}

\item{records}{List with reason for ignoring as fieldnames (in quotes)
and value as a scalar or vector with the IXGDFs
Example: \code{records <- list("Outlier"=c(40,36,190), "Pre-first-dose-PK"=c(170,113,35))}}

\item{subjects}{List with reason for removal as fieldnames (in quotes)
and value as a scalar or vector with the USUBJIDs
Example: \code{subjects <- list("Reason 1"=c("ZY800909106","ZY800909102"), "Reason 2"=c("ZY800505071"))}}

\item{FLAGrmPlacebo}{If TRUE then placebo subjects are removed from the data. If FALSE they are kept}

\item{FLAGrmIGNOREDrecords}{If TRUE then MDV=1 records are removed. If FALSE then not removed.}

\item{FLAGrmDosePostLastObs}{If TRUE then dose records post last observation in each individual are removed.}

\item{continuousCovs}{In case covariate columns contain \code{NA} entries, this should by fixed by an imputation rule.
There are two options:
\itemize{
\item{\strong{Un-named vector:} The vectors elements should contain the names of the covariate columns for which
the imputation is done. In this case, each missing covariate is imputed to the median of this covariate (across subjects) in the
dataset.}
\item{\strong{Named vector:} The names of the vector elements should be the names of the covariate columns for which imputation is done.
The values of the vector elements should be the values to which to impute the covariates to. Apart from numerical values
also function names (such as "median" or "mean" can be provided).}
}}

\item{categoricalCovs}{In case covariate columns contain \code{NA} entries, this should by fixed by an imputation rule.
For categorical covariates always a named vector needs to be provided. The names of the elements
need to define the name of the covariate columns and the value of the numerical imputation value.}

\item{pathname}{Pathname to where to write the log files}
}
\value{
"Cleaned" IQRdataGENERAL object
}
\description{
This functions performs several cleaning operations in the following order:
\itemize{
\item Set the BLLOQ handling method, using the function \code{blloq_IQRdataGENERAL}.
\item Set user defined records to IGNORE, using the function \code{setIGNORErecords_IQRdataGENERAL}.
\item Remove missing observation records with missing TIME, using the function \code{rmMissingTIMEobsRecords_IQRdataGENERAL}.
\item Set missing observation records with missing DV to IGNORE, using the function \code{setMissingDVobsRecordsIGNORE_IQRdataGENERAL}.
\item Remove user defined subjects, using the function \code{rmSubjects_IQRdataGENERAL}.
\item Remove non-dose and non-observation records, using the function \code{rmNonTask_IQRdataGENERAL}.
\item Remove placebo subjects, using the function \code{rmPLACEBO_IQRdataGENERAL}. The removal of placebo subjects is optional and
can be changed by a input flag.
\item Removal of subjects without observations, using the function \code{rmNOobsSUB_IQRdataGENERAL}.
\item Removal of dose records with AMT=0, using the function \code{rmAMT0_IQRdataGENERAL}.
\item Removal of ignored record (MDV=1), using the function \code{rmIGNOREd_IQRdataGENERAL}.
\item Imputation of missing covariates, using the function \code{covImpute_IQRdataGENERAL}.
\item Removal of doses post last observation, using the function \code{rmDosePostLastObs_IQRdataGENERAL}.
A path name can be provided. If it is, then protocols of the changes are written to log files in the
IQRoutputTable format.
}
}
\seealso{
Other IQRdataGeneral: 
\code{\link{+.IQRdataGENERAL}()},
\code{\link{IQRcalcTAD}()},
\code{\link{IQRdataGENERAL}()},
\code{\link{IQRexpandADDLII}()},
\code{\link{IQRloadCSVdata}()},
\code{\link{IQRsaveCSVdata}()},
\code{\link{addIndivRegressors_IQRdataGENERAL}()},
\code{\link{addLabel_IQRdataGENERAL}()},
\code{\link{attributes0}()},
\code{\link{blloqInfo_IQRdataGENERAL}()},
\code{\link{blloq_IQRdataGENERAL}()},
\code{\link{check_IQRdataGENERAL}()},
\code{\link{combine_IQRdataGENERAL}()},
\code{\link{convertCat2Text}()},
\code{\link{covImpute_IQRdataGENERAL}()},
\code{\link{date2dateday_IQRdataProgramming}()},
\code{\link{date2datetime_IQRdataProgramming}()},
\code{\link{date2time_IQRdataProgramming}()},
\code{\link{exportDEFINE_IQRaedataER}()},
\code{\link{exportDEFINE_IQRdataGENERAL}()},
\code{\link{exportDEFINEpdf_IQRdataGENERAL}()},
\code{\link{exportSYS_IQRdataGENERAL}()},
\code{\link{export_IQRdataGENERAL}()},
\code{\link{getLabels_dataframe}()},
\code{\link{getNAcolNLME_IQRdataGENERAL}()},
\code{\link{handleSameTimeObs_IQRdataGENERAL}()},
\code{\link{is_IQRdataGENERAL}()},
\code{\link{loadATRinfo_csvData}()},
\code{\link{loadAttributeFile}()},
\code{\link{load_IQRdataGENERAL}()},
\code{\link{mapCategoricalCovariate_IQRnlmeProject}()},
\code{\link{mapCategoricalCovariate_csvData}()},
\code{\link{mapContinuousCovariate_IQRnlmeProject}()},
\code{\link{mapContinuousCovariate_csvData}()},
\code{\link{mutateCov_IQRdataGENERAL}()},
\code{\link{obfuscate_IQRdataGENERAL}()},
\code{\link{plot.IQRdataGENERAL}()},
\code{\link{plotCorCat_IQRdataGENERAL}()},
\code{\link{plotCorCovCat_IQRdataGENERAL}()},
\code{\link{plotCorCov_IQRdataGENERAL}()},
\code{\link{plotCovDistribution_IQRdataGENERAL}()},
\code{\link{plotDoseSchedule_IQRdataGENERAL}()},
\code{\link{plotIndiv_IQRdataGENERAL}()},
\code{\link{plotRange_IQRdataGENERAL}()},
\code{\link{plotSampleSchedule_IQRdataGENERAL}()},
\code{\link{plotSpaghetti_IQRdataGENERAL}()},
\code{\link{print.IQRdataGENERAL}()},
\code{\link{removeCommata_dataframe}()},
\code{\link{rmAMT0_IQRdataGENERAL}()},
\code{\link{rmDosePostLastObs_IQRdataGENERAL}()},
\code{\link{rmIGNOREd_IQRdataGENERAL}()},
\code{\link{rmMissingTIMEobsRecords_IQRdataGENERAL}()},
\code{\link{rmNOobsSUB_IQRdataGENERAL}()},
\code{\link{rmNonTask_IQRdataGENERAL}()},
\code{\link{rmPLACEBO_IQRdataGENERAL}()},
\code{\link{rmSubjects_IQRdataGENERAL}()},
\code{\link{setIGNORErecords_IQRdataGENERAL}()},
\code{\link{setMissingDVobsRecordsIGNORE_IQRdataGENERAL}()},
\code{\link{subset.IQRdataGENERAL}()},
\code{\link{summary.IQRdataGENERAL}()},
\code{\link{summaryCat_IQRdataGENERAL}()},
\code{\link{summaryCov_IQRdataGENERAL}()},
\code{\link{summaryObservations_IQRdataGENERAL}()},
\code{\link{transformObs_IQRdataGENERAL}()},
\code{\link{unlabel_dataframe}()}

Other IQRdataGeneral: 
\code{\link{+.IQRdataGENERAL}()},
\code{\link{IQRcalcTAD}()},
\code{\link{IQRdataGENERAL}()},
\code{\link{IQRexpandADDLII}()},
\code{\link{IQRloadCSVdata}()},
\code{\link{IQRsaveCSVdata}()},
\code{\link{addIndivRegressors_IQRdataGENERAL}()},
\code{\link{addLabel_IQRdataGENERAL}()},
\code{\link{attributes0}()},
\code{\link{blloqInfo_IQRdataGENERAL}()},
\code{\link{blloq_IQRdataGENERAL}()},
\code{\link{check_IQRdataGENERAL}()},
\code{\link{combine_IQRdataGENERAL}()},
\code{\link{convertCat2Text}()},
\code{\link{covImpute_IQRdataGENERAL}()},
\code{\link{date2dateday_IQRdataProgramming}()},
\code{\link{date2datetime_IQRdataProgramming}()},
\code{\link{date2time_IQRdataProgramming}()},
\code{\link{exportDEFINE_IQRaedataER}()},
\code{\link{exportDEFINE_IQRdataGENERAL}()},
\code{\link{exportDEFINEpdf_IQRdataGENERAL}()},
\code{\link{exportSYS_IQRdataGENERAL}()},
\code{\link{export_IQRdataGENERAL}()},
\code{\link{getLabels_dataframe}()},
\code{\link{getNAcolNLME_IQRdataGENERAL}()},
\code{\link{handleSameTimeObs_IQRdataGENERAL}()},
\code{\link{is_IQRdataGENERAL}()},
\code{\link{loadATRinfo_csvData}()},
\code{\link{loadAttributeFile}()},
\code{\link{load_IQRdataGENERAL}()},
\code{\link{mapCategoricalCovariate_IQRnlmeProject}()},
\code{\link{mapCategoricalCovariate_csvData}()},
\code{\link{mapContinuousCovariate_IQRnlmeProject}()},
\code{\link{mapContinuousCovariate_csvData}()},
\code{\link{mutateCov_IQRdataGENERAL}()},
\code{\link{obfuscate_IQRdataGENERAL}()},
\code{\link{plot.IQRdataGENERAL}()},
\code{\link{plotCorCat_IQRdataGENERAL}()},
\code{\link{plotCorCovCat_IQRdataGENERAL}()},
\code{\link{plotCorCov_IQRdataGENERAL}()},
\code{\link{plotCovDistribution_IQRdataGENERAL}()},
\code{\link{plotDoseSchedule_IQRdataGENERAL}()},
\code{\link{plotIndiv_IQRdataGENERAL}()},
\code{\link{plotRange_IQRdataGENERAL}()},
\code{\link{plotSampleSchedule_IQRdataGENERAL}()},
\code{\link{plotSpaghetti_IQRdataGENERAL}()},
\code{\link{print.IQRdataGENERAL}()},
\code{\link{removeCommata_dataframe}()},
\code{\link{rmAMT0_IQRdataGENERAL}()},
\code{\link{rmDosePostLastObs_IQRdataGENERAL}()},
\code{\link{rmIGNOREd_IQRdataGENERAL}()},
\code{\link{rmMissingTIMEobsRecords_IQRdataGENERAL}()},
\code{\link{rmNOobsSUB_IQRdataGENERAL}()},
\code{\link{rmNonTask_IQRdataGENERAL}()},
\code{\link{rmPLACEBO_IQRdataGENERAL}()},
\code{\link{rmSubjects_IQRdataGENERAL}()},
\code{\link{setIGNORErecords_IQRdataGENERAL}()},
\code{\link{setMissingDVobsRecordsIGNORE_IQRdataGENERAL}()},
\code{\link{subset.IQRdataGENERAL}()},
\code{\link{summary.IQRdataGENERAL}()},
\code{\link{summaryCat_IQRdataGENERAL}()},
\code{\link{summaryCov_IQRdataGENERAL}()},
\code{\link{summaryObservations_IQRdataGENERAL}()},
\code{\link{transformObs_IQRdataGENERAL}()},
\code{\link{unlabel_dataframe}()}
}
\concept{IQRdataGeneral}
