% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_classes_IQRnlmeProject_Multi.R
\name{compareModels_IQRnlmeProjectMulti}
\alias{compareModels_IQRnlmeProjectMulti}
\title{Compare the estimation specifications or results between multiple NLME projects}
\usage{
compareModels_IQRnlmeProjectMulti(
  object,
  type = "result",
  selection = c("fixed", "random", "covariate", "correlation", "error", "metric"),
  order = NULL,
  SIGDIG = 3,
  FLAGreport = TRUE,
  filename = NULL,
  title = NULL,
  footer = NULL
)
}
\arguments{
\item{object}{An \code{IQRnlmeProjectMulti} object}

\item{type}{Output of either parameter estimation setting ("specification") or estimated values ("result", default)}

\item{selection}{Selection of parameters and/or model metrics to return with the table.
Defaults to all possible choices ("fixed", "random", "covariate", "correlation", "error, "metrics").}

\item{order}{Model metric ("BIC", "AIC", or "OBJ") used for ordering. If NULL (default), order is as given in object.}

\item{SIGDIG}{Number of significant digits (defaults to 3)}

\item{FLAGreport}{Add tags for reporting to Word with \code{\link{IQReport}} (TRUE, default)
or avoid the additional tags (FALSE)}

\item{filename}{If provided (not NULL) then table is exported to this file}

\item{title}{Table title. If not provided (NULL) defaults to 'Comparison of model results/specifications for multiple models'.}

\item{footer}{Additional text in table footer}
}
\value{
If no filename is provided, the table contents are returned as IQRoutputTable object
}
\description{
Generate a table with a parameter column (the parameters of all projects) and one column
for each project containing parameter estimates/specifications.
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}

Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}
}
\author{
Anne Kuemmel, IntiQuan GmbH
}
\concept{IQRnlmeProject}
