% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tables_classes_IQRtable.R
\name{composeByRule_IQRtable}
\alias{composeByRule_IQRtable}
\title{Compose tables according to a rule provided by a pattern}
\usage{
composeByRule_IQRtable(..., rule, just = "tl")
}
\arguments{
\item{...}{one or more tables or single list of tables to be composed. Arguments must be named.
The names can be used in "pattern" to reference the table.}

\item{rule}{character containing "x" and "y" defining a pattern, e.g. "x | y" or "x \\n \\n y". See
details of \link{compose_IQRtable} to know more about possible patterns.}

\item{just}{when tables of different size are composed, each matrix is embedded into a
possibly larger matrix to match dimensions of the surrounding tables. "just" is a string to
control where matrices are placed within the larger matrix. Possible values are
"t" (top), "b" (bottom), "l" (left) and "r" (right) which can be combined, e.g. "tl", "br", etc..}
}
\value{
Matrix, the composition of the single tables
}
\description{
The function is similar to \link{compose_IQRtable}. When many tables need to be composed following a
repeated pattern, "composeByRule_IQRtable" is a short-cut to do this.
}
\details{
The pattern of composing matrices "x" and "y" is applied recursively until all matrices
are composed.
}
\examples{
D1 <- data.frame(
  parameter = c("a", "b"),
  value = c(1.53, 2.53)
)

D2 <- data.frame(
  parameter = c("a", "c"),
  value = c(1.34, 8.97)
)

D3 <- data.frame(
  parameter = c("a", "b", "c"),
  value = c(1.28, 2.67, 9.81)
)

rule <- "x\n \n y"

composeByRule_IQRtable(D1, D2, D3, rule = rule)

}
\seealso{
Other IQR Table: 
\code{\link{IQRtable}()},
\code{\link{as.data.frame.IQRtable}()},
\code{\link{as_IQRtable}()},
\code{\link{cjoin_IQRtable}()},
\code{\link{compose_IQRtable}()}
}
\author{
Daniel Kaschek, IntiQuan
}
\concept{IQR Table}
