% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tables_classes_IQRtable.R
\name{compose_IQRtable}
\alias{compose_IQRtable}
\title{Compose several tables to a new table following a construction pattern}
\usage{
compose_IQRtable(..., pattern, just = "tl")
}
\arguments{
\item{...}{one or more tables or single list of tables to be composed. Arguments must be named.
The names can be used in "pattern" to reference the table.}

\item{pattern}{character using the symbols "|" to distinguish between columns and "\\n"
(or an actual line break) to distinguish between lines. Additional symbols should point
to the provided "..." arguments.}

\item{just}{when tables of different size are composed, each matrix is embedded into a
possibly larger matrix to match dimensions of the surrounding tables. "just" is a string to
control where matrices are placed within the larger matrix. Possible values are
"t" (top), "b" (bottom), "l" (left) and "r" (right) which can be combined, e.g. "tl", "br", etc..}
}
\value{
Matrix, the composition of the single tables.
}
\description{
Several tables provided via the "..." argument are composed to a new table. The pattern
of the layout is provided as character using Markdown syntax.
}
\details{
A typical pattern would be:

\if{html}{\out{<div class="sourceCode">}}\preformatted{pattern <-

"   | header1 | header2 |
 C1 | M11     | M12     |
    |         |         |
 C2 | M21     | M22     |"
}\if{html}{\out{</div>}}

Here, "M11", ..., "M22" can all be matrices of different dimensions. "header1" and "header2"
would probably be matrices with one row (not necessarily).
"C1" and "C2" would be matrices with on column (not necessarily).
The empty row in between will be interpreted as an empty row. Characters in R defined over
several lines automatically contain the escape characters "\\n" for new lines. One could also
write the pattern in one line, although less unititively.

Within the pattern, it is also possible to select parts of a matrix for composition:

\if{html}{\out{<div class="sourceCode">}}\preformatted{pattern <-

"   | M11[1 ,] | header2 |
 C1 | M11[-1,] | M12     |"
}\if{html}{\out{</div>}}

The single cells of the pattern are parsed and evaluated with the list of "..." argument.
}
\examples{

M1 <- matrix(letters[1:6], nrow = 2, ncol = 3)
M2 <- matrix(LETTERS[1:6], nrow = 3, ncol = 2)

pattern <-

  "n1 | M1 |
      |    |
   n2 | M2 |
      |    |"


mytable <- compose_IQRtable(M1 = M1, M2 = M2,
                            n1 = "Lower case letters", n2 = "Upper case letters",
                            pattern = pattern)

print(mytable)


pattern <-

  " n1 | M1[1, ] |
    n2 | M2[, 1] |"

mytable <- compose_IQRtable(M1 = M1, M2 = M2,
                            n1 = "Lower case letters", n2 = "Upper case letters",
                            pattern = pattern,
                            just = "r")

print(mytable)


}
\seealso{
Other IQR Table: 
\code{\link{IQRtable}()},
\code{\link{as.data.frame.IQRtable}()},
\code{\link{as_IQRtable}()},
\code{\link{cjoin_IQRtable}()},
\code{\link{composeByRule_IQRtable}()}
}
\author{
Daniel Kaschek, IntiQuan
}
\concept{IQR Table}
