% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_tools_covforrestplot.R
\name{covariateEffect_IQRnlmeProject}
\alias{covariateEffect_IQRnlmeProject}
\title{Assess impact of covariates on parameters}
\usage{
covariateEffect_IQRnlmeProject(
  projectPath,
  filename = NULL,
  Nsamples = 1e+05,
  ClinicalRelevanceLow = 0.8,
  ClinicalRelevanceHigh = 1.2,
  SIGDIG = 3,
  CImethod = c("cov", "typcov", "multi"),
  seed = 1234,
  fontsize = 8
)
}
\arguments{
\item{projectPath}{Path to an NLME project folder}

\item{filename}{Filename for export of results. If filename specified, then
output written to file PDF file and as a text
file with tabular information. If not provided then
outputs are only displayed.}

\item{Nsamples}{How many samples should be taken from the uncertainty
distributions. This number should be much larger than the
number of individuals in the analysis dataset, so the covariate
information in the dataset is well sampled.}

\item{ClinicalRelevanceLow}{Lower boundary of a grey box around 1}

\item{ClinicalRelevanceHigh}{Upper boundary of a grey box around 1
This grey box is drawn around the nominal value of 1 and
allows a visual feedback of potential clinical relevance.}

\item{SIGDIG}{Number of significant digits for table output and other values
that are printed in some form.}

\item{CImethod}{Method to determine the confidence interval of the covariate effect.
\code{"cov"} = consider only uncertainty of the covariate effect parameter (default),
\verb{"typcov} = consider uncertainty of the typical parameter and covariate effect
as independent uncertainties. That is an upper bound for the uncertainty of the
individual parameter assumed for a certain continuous covariate quantile (5\%, 95\%)
or covariate category.
\code{"multi"} = consider only uncertainty of the covariate effect parameter,
adjusting standard errors to account for the multiple testing problem. See
Xu XS, Yuan M, Zhu H, Yang Y, Wang H, Zhou H, Xu J, Zhang L, Pinheiro J.
Full covariate modelling approach in population pharmacokinetics:
understanding the underlying hypothesis tests and implications of multiplicity.
British journal of clinical pharmacology. 2018 Jul;84(7):1525-34.}

\item{seed}{Seed for random sampling from uncertainty to make the returned plots
and tables fully reproducible.}

\item{fontsize}{Fontsize for the y-axis text and subtitle.}
}
\value{
List with ggplot2 objects with each "plotData" attribute, containing
the data that were plotted. List also contains the generated table as
IQRoutputTable object.
}
\description{
This function assesses the changes that covariates introduce on the
model parameters, relative to a reference individual. Uncertainty in the
estimated fixed effect parameters and covariate coefficients is
considered.
Per model parameter that is changed by covariates, one plot is done.
Showing the uncertainty range for the parameter and the impact of the
covariates on this parameter. The horizontal lines correspond to the 95\%
confidence intervals.
Plots are done for both estimated and fixed covariate/parameter relationships.
Works for all interfaced NLME tools (NONMEM, MONOLIX, NLMIXR). If called
without a filename it will return the ggplot objects as a list. If called with filename
it will generate the PDF file at the given location. The data used for the
plot are returned as attr(,"plotData") in each list element.
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{compareModels_IQRnlmeProjectMulti}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}
}
\concept{Covariate analysis}
\concept{IQRnlmeProject}
