% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compliance_submissionPackage.R
\name{createSubmissionPack}
\alias{createSubmissionPack}
\title{Create submission package for analysis}
\usage{
createSubmissionPack(
  specification,
  analysisname,
  pathroot = ".",
  programExtension = ".txt",
  extensionChange = c("_lower", "_", "-lower", "-", "none"),
  allowedProgExt = c(".txt", ".lua", ".sas", ".r", ".ctl"),
  fullpathData = FALSE,
  logfile = "logfile.txt",
  substituteUpper = TRUE,
  substituteUnderscore = FALSE,
  allowSubfolder = FALSE,
  overwrite = FALSE,
  calcMD5 = FALSE,
  copyAttributes = FALSE,
  stop_at_missing = TRUE
)
}
\arguments{
\item{specification}{Data frame with one row per mode, data set, or script that should be copied.
The following columns need to be defined in the specification:.
\tabular{llll}{
COLUMN      \tab DESCRIPTION \cr
=========== \tab =============================================================== \cr
Source      \tab Path to dataset, script, or model project folder\cr
SubFolder   \tab Optional subfolder to 'programs' folder to which the script/model should be copied or prefix that is added to the filename(s) of copied files. Use "." or "" to not use the subfolder option.\cr
Name        \tab Name of which is used for filenames of the copied program, model, or data files. Renaming might be required in case datasets and models with same filenames exist. If not given, the model folder name is used for model files and the original file names for datasets (including the modeling data sets). If the given name does not contain an extension, the original will be used and adjusted as required.\cr
Type        \tab Either 'model', 'dataset', or 'program'. Datasets and datasets of the model are copied to 'datasets' folder, programs and model files to 'programs' \cr
Description \tab Short describtion of model, dataset, or program used in define file or reviewer's guide.\cr
defineRMD   \tab Path to rmd of define file if not existing with same filename in same location as the dataset. NA otherwise. This argument is ignored for programs.\cr
}
Note that helper functions, i.e., \link{getProgramSpecification} and \link{getModelSpecification} exist to create the specification data frame.}

\item{analysisname}{Name of the analysis folder}

\item{pathroot}{Path where submission package is created}

\item{programExtension}{Extention to be used for program and model files that do not already have
allowed file extension. Defaults to '.txt'.}

\item{extensionChange}{Option how the current program and model file extensions are modified before adding new extension.

\if{html}{\out{<div class="sourceCode">}}\preformatted{      * "_lower": Dot substituted with underscore (_) and all letters converted to lower case (default)
      * "_": Dot substituted with underscore (_)
      * "-lower": Dot substituted with hyphen (-) and all letters converted to lower case
      * "-": Dot substituted with hyphen (-)
      * "none": No change
}\if{html}{\out{</div>}}}

\item{allowedProgExt}{Program and model file extension that are kept as is.}

\item{fullpathData}{Flag whether full path of dataset should be given in define file}

\item{logfile}{File with notes on manual post-processing information.}

\item{substituteUpper}{Flag whether letters of file names should be converted to lower case}

\item{substituteUnderscore}{Flag whether underscores in file names should be substituted with '-'}

\item{allowSubfolder}{Flag whether to allow subfolder in programs (default FALSE)}

\item{overwrite}{Flag whether to allow overwriting existing analyis folder in submission package}

\item{calcMD5}{Flag whether to calculate the MD5 checksum for copied files. If true, checksums
will be written to 'checksums.csv' in the 'pathroot' folder}

\item{copyAttributes}{Flag whether to copy attribute files to programs/Resources (default FALSE)}

\item{stop_at_missing}{Flag whether to stop if a required file does not exist. Defaults to TRUE.
Switching to FALSE could be handy when developing the submission package as the log file tracks missing files and other issues.}
}
\value{
None. Datasets and programs are copied to the submission package folder
structure and a log file with postprocessing information written.
}
\description{
Copies scripts, datasets or NLME models with related datasets into folder
structure as required by FDA for submission. Define files are copied or created if possible,
and a reviewer's guides is prepared in terms of rmd/docx file.
The structure of the created package is 'm5/datasets/\emph{analysisname}/analysis/legacy' with
subfolders 'programs' and 'datasets'. The datasets folder will contain all copied datasets
and one define file. The programs folder will contain Reviewer's guide describing scripts and
model files that have been copied.
For NLME models, the NONMEM control and output file or mlxtran, Monolix model file and output file
will be copied to programs and the modeling dataset to 'datasets'. The modeling datasets are .
For scripts, it will be attempted to parse the description of the file from the file header if not
given by the user to add
The reviewer's guide and the define file for data sets need to be manually opened, potentially
adjusted, and stored as PDF.
A logfile is giving an overview on files that were copied and potential actions that need to be done.
}
\examples{
\dontrun{
### Example1: NLME models
# Specify models to include in submission package
  specificationModels <- tribble(
    ~Source                                         , ~SubFolder  , ~Name , ~Type      , ~Description       , ~defineRMD,
    "../Models/01_NONMEM"                           , "."         , "nm"  , "model"    , "nonmem model"     , NA        ,
    "../Models/02_MLX"                              , "."         , "mlx" , "model"    , "monolix model"    , NA
  ) \%>\% as.data.frame()

# Create analysis path with model input/output files and the used datasets
  createSubmissionPack(
    specification = specificationModels,
    analysisname = "PKmodel",
    pathroot = "../../package/",
    logfile = "../../package/logModels.txt",
    overwrite = TRUE,
    substituteUpper = FALSE
  )

### Example 2: datasets and programs
# Specify dataset and scripts to include in submission package
  specificationScripts <- tribble(
    ~Source                                         , ~SubFolder  , ~Name , ~Type      , ~Description       , ~defineRMD,
    "SCRIPT_40_ExposureMetrics_Individuals.R"       , "."         , NA    , "program"  , NA                 , NA        ,
    "SCRIPT_50_Visualize_IGGBASEdistribution.R"     , "."         , NA    , "program"  , "done for fun"     , NA        ,
    "Resources/model2cpt_IVSCIG_IGGBASE_IOV_AUC.txt", "Resources" , NA    , "program"  , "structural model" , NA        ,
    "Resources/dataExp.csv"                         , ""          , NA    , "dataset"  , "ER data"          , NA
  ) \%>\% as.data.frame()

# Create analysis path with model input/output files and the used datasets
createSubmissionPack(
    specification = specificationScripts,
    analysisname = "ERanalysis",
    pathroot = "../../package/",
    logfile = "../../package/logScripts.txt",
    overwrite = TRUE
  )


### Example 3: combination
  specification <- bind_rows(specificationModels, specificationScripts)
  createSubmissionPack(
    specification = specification,
    analysisname = "all",
    pathroot = "../../package/",
    logfile = "../../package/logAll.txt"
  )
}
}
\seealso{
Other Output: 
\code{\link{IQRinitCompliance}()},
\code{\link{IQRoutputCSV}()},
\code{\link{IQRoutputDEFINE}()},
\code{\link{IQRoutputFigure}()},
\code{\link{IQRoutputFile}()},
\code{\link{IQRoutputPDFend}()},
\code{\link{IQRoutputPDFstart}()},
\code{\link{IQRoutputPDF}()},
\code{\link{IQRoutputPNG}()},
\code{\link{IQRoutputRDS}()},
\code{\link{IQRoutputTable}()},
\code{\link{IQRoutputValueTable}()},
\code{\link{IQRoutputXPT}()},
\code{\link{getModelSpecification}()},
\code{\link{getProgramSpecification}()},
\code{\link{import_IQRdataOriginal}()},
\code{\link{is_enabled_complianceMode}()},
\code{\link{is_enabled_rdsMode}()},
\code{\link{packageR_IQRtools}()},
\code{\link{print.IQRoutputTable}()},
\code{\link{read_IQRoutputTable}()},
\code{\link{text_IQRoutputTable}()}

Other Submission package: 
\code{\link{IQRoutputDEFINE}()},
\code{\link{IQRoutputXPT}()},
\code{\link{addLabel_IQRaedataER}()},
\code{\link{addLabel_IQRdataGENERAL}()},
\code{\link{exportDEFINE_IQRaedataER}()},
\code{\link{exportDEFINE_IQRdataGENERAL}()},
\code{\link{exportDEFINEpdf_IQRdataGENERAL}()},
\code{\link{exportXPT_IQRaedataER}()},
\code{\link{getModelSpecification}()},
\code{\link{getProgramSpecification}()}
}
\author{
Anne Kuemmel
}
\concept{Output}
\concept{Submission package}
