% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dMod_classes_IQRsysData.R,
%   R/data_classes_IQRdataGeneral.R
\name{exportSYS_IQRdataGENERAL}
\alias{exportSYS_IQRdataGENERAL}
\alias{exportNLME_IQRdataGENERAL}
\title{Exports an IQRdataGENERAL object as an NLME dataset}
\usage{
exportSYS_IQRdataGENERAL(
  data,
  regressorNames = NULL,
  doseNAMES = NULL,
  obsNAMES = NULL,
  filename = NULL,
  FLAGxpt = FALSE,
  FLAGdefine = TRUE,
  FLAGzip = FALSE,
  addColLabels = NULL
)

exportNLME_IQRdataGENERAL(
  data,
  regressorNames = NULL,
  doseNAMES = NULL,
  obsNAMES = NULL,
  filename = NULL,
  FLAGxpt = FALSE,
  FLAGdefine = TRUE,
  FLAGzip = FALSE,
  addColLabels = NULL
)
}
\arguments{
\item{data}{IQRdataGENERAL object}

\item{regressorNames}{Vector with names of regression parameter columns (the order
of these columns is important and they will be ordered exactly as provided here)}

\item{doseNAMES}{Vector with dose record names (= entries in NAME-column) to use during NLME data export. ADM values will be set according
to the order of NAMEs in the doseNAMES argument}

\item{obsNAMES}{Vector with observation names  (= entries in NAME-column) to use during NLME data export. YTYPE values will be set according
to the order of NAMEs in the obsNAMES argument}

\item{filename}{Filename of the NLME CSV file to create (not more than 8 characters without extension - if FLAGxpt=TRUE)}

\item{FLAGxpt}{If TRUE then a SAS XPT file will be generated additionally}

\item{FLAGdefine}{If TRUE then a define.rmd file will be generated additionally. The syntax
of this file is in the IQReport markdown syntax and allows human readbility. The IQReport
software can subsequently be used to convert this file to Microsoft WORD, allowing further
editing and saving as a PDF file. Please read the documentation for the \code{\link{exportDEFINE_IQRdataGENERAL}}
function to learn more about IQReport.}

\item{FLAGzip}{If TRUE then the exported data files (.csv, .atr, .xpt, .docx, .rmd, etc.) will be zipped
and placed in the potential path in the "filename" as the filename.dat.zip. Other files will be removed.}

\item{addColLabels}{List with named elements. Names are column names and
the value of an element is the label. If defining addColLabels for columns that
are already handled automatically, the provided labels will overwrite the automatic ones.
Example: \code{addColLabels <- list(IXGDF="Other label",NEWCCOL="Label for NEWCOL")}.
This information is needed only for XPT and define file generation}
}
\description{
This function exports an IQRdataGENERAL object as an NLME dataset. Such an
NLME dataset is a CSV file that is suitable for NLME analysis in NONMEM and
MONOLIX. The main difference to IQRdataGENERAL datasets is that regression parameters
need to be listed in a certain order and that spaces in character strings need to be removed
(due to good old NONMEM). Additionally, extra rows with non-doses and non-observations
should have been removed before and thus the AE, BASE, and SCREEN related columns are
not of much use anymore. During export of an NLME dataset the following is done:
\itemize{
\item ADM is set according to the order of doseNAMES!
\item Reordering the columns to have the modeling related columns at the beginning and the
regression parameters in the defined order at the end of the columns.
\item Spaces in non-numeric entries will be replaced by ":::" to allow good old NONMEM
to work ...
\item Columns "AE","AEGRADE","AESER","AEDRGREL","VALUETXT","BASE","SCREEN" are
not present anymore, as not very useful in this NLME setting.
In order to support also the changes in MONOLIX 2018 (why do they keep changing
everything over and over again ...???) we will do the following changes to the data
during export to an NLME dataset:
}
\enumerate{
\item YTYPE: NA for dosing events
\item ADM: NA for observation events
}
}
\seealso{
Other IQRdataGeneral: 
\code{\link{+.IQRdataGENERAL}()},
\code{\link{IQRcalcTAD}()},
\code{\link{IQRdataGENERAL}()},
\code{\link{IQRexpandADDLII}()},
\code{\link{IQRloadCSVdata}()},
\code{\link{IQRsaveCSVdata}()},
\code{\link{addIndivRegressors_IQRdataGENERAL}()},
\code{\link{addLabel_IQRdataGENERAL}()},
\code{\link{attributes0}()},
\code{\link{blloqInfo_IQRdataGENERAL}()},
\code{\link{blloq_IQRdataGENERAL}()},
\code{\link{check_IQRdataGENERAL}()},
\code{\link{clean_IQRdataGENERAL}()},
\code{\link{combine_IQRdataGENERAL}()},
\code{\link{convertCat2Text}()},
\code{\link{covImpute_IQRdataGENERAL}()},
\code{\link{date2dateday_IQRdataProgramming}()},
\code{\link{date2datetime_IQRdataProgramming}()},
\code{\link{date2time_IQRdataProgramming}()},
\code{\link{exportDEFINE_IQRaedataER}()},
\code{\link{exportDEFINE_IQRdataGENERAL}()},
\code{\link{exportDEFINEpdf_IQRdataGENERAL}()},
\code{\link{export_IQRdataGENERAL}()},
\code{\link{getLabels_dataframe}()},
\code{\link{getNAcolNLME_IQRdataGENERAL}()},
\code{\link{handleSameTimeObs_IQRdataGENERAL}()},
\code{\link{is_IQRdataGENERAL}()},
\code{\link{loadATRinfo_csvData}()},
\code{\link{loadAttributeFile}()},
\code{\link{load_IQRdataGENERAL}()},
\code{\link{mapCategoricalCovariate_IQRnlmeProject}()},
\code{\link{mapCategoricalCovariate_csvData}()},
\code{\link{mapContinuousCovariate_IQRnlmeProject}()},
\code{\link{mapContinuousCovariate_csvData}()},
\code{\link{mutateCov_IQRdataGENERAL}()},
\code{\link{obfuscate_IQRdataGENERAL}()},
\code{\link{plot.IQRdataGENERAL}()},
\code{\link{plotCorCat_IQRdataGENERAL}()},
\code{\link{plotCorCovCat_IQRdataGENERAL}()},
\code{\link{plotCorCov_IQRdataGENERAL}()},
\code{\link{plotCovDistribution_IQRdataGENERAL}()},
\code{\link{plotDoseSchedule_IQRdataGENERAL}()},
\code{\link{plotIndiv_IQRdataGENERAL}()},
\code{\link{plotRange_IQRdataGENERAL}()},
\code{\link{plotSampleSchedule_IQRdataGENERAL}()},
\code{\link{plotSpaghetti_IQRdataGENERAL}()},
\code{\link{print.IQRdataGENERAL}()},
\code{\link{removeCommata_dataframe}()},
\code{\link{rmAMT0_IQRdataGENERAL}()},
\code{\link{rmDosePostLastObs_IQRdataGENERAL}()},
\code{\link{rmIGNOREd_IQRdataGENERAL}()},
\code{\link{rmMissingTIMEobsRecords_IQRdataGENERAL}()},
\code{\link{rmNOobsSUB_IQRdataGENERAL}()},
\code{\link{rmNonTask_IQRdataGENERAL}()},
\code{\link{rmPLACEBO_IQRdataGENERAL}()},
\code{\link{rmSubjects_IQRdataGENERAL}()},
\code{\link{setIGNORErecords_IQRdataGENERAL}()},
\code{\link{setMissingDVobsRecordsIGNORE_IQRdataGENERAL}()},
\code{\link{subset.IQRdataGENERAL}()},
\code{\link{summary.IQRdataGENERAL}()},
\code{\link{summaryCat_IQRdataGENERAL}()},
\code{\link{summaryCov_IQRdataGENERAL}()},
\code{\link{summaryObservations_IQRdataGENERAL}()},
\code{\link{transformObs_IQRdataGENERAL}()},
\code{\link{unlabel_dataframe}()}
}
\concept{IQRdataGeneral}
