% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qsp_parameterization_variants.R
\name{exportVariant_IQRmodel}
\alias{exportVariant_IQRmodel}
\title{Exports a model structure with associated parameterization variant}
\usage{
exportVariant_IQRmodel(
  model,
  pathname,
  parameters = NULL,
  FLAGss = TRUE,
  comment = NULL,
  variantname = "default",
  timeSS = 10000,
  opt_abstol = 1e-06,
  opt_reltol = 1e-06
)
}
\arguments{
\item{model}{An IQRmodel with a parameterization of interest}

\item{pathname}{The pathname to which to export model and parameterization}

\item{parameters}{Named numeric vector with parameter definitions that are applied to the model
before exporting the parameterization variant.}

\item{FLAGss}{Logical. If TRUE then the parameterization that is saved will
correspond to the steady state of the model. Otherwise the models parameterization
and ICs will be stored as defined in the model. Steady-state computation is conducted
by simulation.}

\item{comment}{A comment about the parameterization can be provided and will be stored in
a separate file as the parameterization - using the same name but with .info attached.
File will be only written if a comment is provided.}

\item{variantname}{The name of the parameterization variant to be stored. The name will
be used as a filename with special characters removed and .csv appended.}

\item{timeSS}{The time to be used to simulate to steady-state (if desired by setting FLAGss to TRUE)}

\item{opt_abstol}{The absolute integrator tolerance for ss stimulation}

\item{opt_reltol}{The relative integrator tolerance for ss stimulation}
}
\description{
IQR Tools allows to store IQRmodels with a certain parameterization in a folder.
Such a folder is allowed to contain the general structural model as model.txt file and
several csv files that contain model parameterizations in terms of state initial conditions
and parameter values. The format of these CSV files is:
Column names: NAME, TYPE, INFO, VALUE
NAME: Name of the parameter or state in the model. Note, not all parameters or states need
to appear. This function here will export all though. But for import only selected
elements can be present.
TYPE: "State" or "Parameter"
INFO: The comment in the IQRmodel for the respective element. "NA" is not present
VALUE: The value of the respective element - always numeric
A special case with more than one VALUE column is possible and will be used to
handle multiple similar parameterizations - e.g. for virtual patients under a same condition.
}
\seealso{
Other IQRmodel: 
\code{\link{IQRmodel}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{exportSBML_IQRmodel}()},
\code{\link{export_IQRmodel}()},
\code{\link{getPars_IQRmodel}()},
\code{\link{hasCcodeFunctions_IQRmodel}()},
\code{\link{hasInitialAssignments_IQRmodel}()},
\code{\link{importSBML_IQRmodel}()},
\code{\link{importVariant_IQRmodel}()},
\code{\link{is_IQRmodel}()},
\code{\link{new_IQRmodel}()},
\code{\link{print.IQRmodel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{regenerate_IQRmodel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{sensitivity_IQRmodel}()},
\code{\link{setParameters_IQRmodel}()},
\code{\link{setPars_IQRmodel}()},
\code{\link{sim_IQRmodel}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{simbio_updateParamIC_IQRmodel}()},
\code{\link{stoichiometry_IQRmodel}()},
\code{\link{strReplace_IQRmodel}()}

Other QSP: 
\code{\link{IQRsysEst}()},
\code{\link{IQRsysModel}()},
\code{\link{IQRsysProject}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{as_IQRsysEst}()},
\code{\link{as_IQRsysProjectMulti}()},
\code{\link{as_IQRsysProject}()},
\code{\link{comparePars_IQRsysModel}()},
\code{\link{duplicate_IQRsysProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{export_IQRsysData}()},
\code{\link{getDosing_IQRsysModel}()},
\code{\link{getEmpiricalETACovarianceMatrix_IQRsysProject}()},
\code{\link{getOptTrace_IQRsysProject}()},
\code{\link{getPars_IQRoptTrace}()},
\code{\link{getPars_IQRsysModel}()},
\code{\link{getPrediction_IQRsysModel}()},
\code{\link{hasrun_IQRsysProject}()},
\code{\link{importVariant_IQRmodel}()},
\code{\link{import_IQRsysData}()},
\code{\link{is_IQRsysEst}()},
\code{\link{is_IQRsysModel}()},
\code{\link{is_IQRsysProjectMulti}()},
\code{\link{is_IQRsysProject}()},
\code{\link{load_IQRsysProject}()},
\code{\link{modelSpec_IQRsysEst}()},
\code{\link{model_IQRsysModel}()},
\code{\link{offsetTIME_IQRsysData}()},
\code{\link{plotDVPRED_IQRsysModel}()},
\code{\link{plotFit_IQRsysModel}()},
\code{\link{plotPars_IQRsysModel}()},
\code{\link{plotPred_IQRsysModel}()},
\code{\link{plotProfile_IQRsysModel}()},
\code{\link{plotWRES_IQRsysModel}()},
\code{\link{plotWaterfall_IQRsysModel}()},
\code{\link{plot_IQRoptTrace}()},
\code{\link{plot_IQRsysModel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{print.IQRsysProject}()},
\code{\link{profile_IQRsysModel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{run_IQRsysProjectMulti}()},
\code{\link{run_IQRsysProject}()},
\code{\link{sample_IQRsysModel}()},
\code{\link{sensitivity_IQRmodel}()},
\code{\link{setPars_IQRsysModel}()},
\code{\link{sim_IQRsysModel}()},
\code{\link{sim_IQRvirtualSubjects}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{simbio_updateParamIC_IQRmodel}()},
\code{\link{spmIIV_IQRsysProject}()},
\code{\link{spm_IQRsysProject}()},
\code{\link{switchOpt_IQRsysModel}()},
\code{\link{tablePars_IQRsysModel}()}
}
\concept{IQRmodel}
\concept{QSP}
