% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qsp_parameterization_variants.R
\name{exportVirtualSubjects_IQRnlmeProject}
\alias{exportVirtualSubjects_IQRnlmeProject}
\title{Exports virtual subjects obtained through individual parameter estimation or sampling from population distribution}
\usage{
exportVirtualSubjects_IQRnlmeProject(
  projectPath,
  pathname,
  FLAGoverwrite = FALSE,
  Nsamples = NULL,
  covariates = NULL,
  FLAGuncertainty = FALSE,
  FLAGss = TRUE,
  comment = NULL,
  timeSS = 10000,
  opt_abstol = 1e-06,
  opt_reltol = 1e-06
)
}
\arguments{
\item{projectPath}{Pato to an IQRsysProject or IQRnlmeProject to obtain the individual parameters
from - or to sample from the population distribution.}

\item{pathname}{The pathname to which to export structural model and virtual subject parameters.}

\item{FLAGoverwrite}{Logical. If TRUE then an existing pathname will be removed and newly created.}

\item{Nsamples}{If set to a value >=1 then instead of storing the individual parameter estimates, Nsamples
individual parameterizations will be drawn from the population distribution. By default this is set to NULL,
which results in storage of the individual parameter estimates.}

\item{covariates}{A data.frame that can be passed to the sampling function (Nsamples >= 1). Each column in this
data.frame can have the name of a covariate in the project and will be used to determine new samples of individual
parameters. If row number less than Nsamples, sampling is done with replacement. If row number is larger then no
replacement will be done and if row number is identical to Nsamples the exact values will be used in the order of
obtained individual parameters.}

\item{FLAGuncertainty}{Logical. If TRUE then new population mean parameters will be drawn from the uncertainty distribution
and then new individual parameters are sampled from these. If FALSE, then point estimates
of population mean parameters are used.}

\item{FLAGss}{Logical. If TRUE then each individual parameterization will be simulated until steady-state
to allow storage of parameters and associated steady-state state variables as initial conditions for subsequent
simulations. If FALSE then state variables and parameter will be stored as is. Only non-numerical ICs will be
calculated based on parameterization in the latter case. Normally a user would want to always set this to TRUE.}

\item{comment}{A comment about the virtual subject population can be provided and will be stored in
a separate file - using the same name but with .info attached. File will be only written if a comment is provided.}

\item{timeSS}{The time to be used to simulate to steady-state (if desired by setting FLAGss to TRUE)}

\item{opt_abstol}{The absolute integrator tolerance for steady-state simulation}

\item{opt_reltol}{The relative integrator tolerance for steady-state simulation}
}
\description{
The export consists of a folder in which the underlying structural model is stored in the form
of a text based IQRmodel. Parameters for all virtual subjects are stored as a CSV file of the following
format: Column names: NAME, TYPE, INFO, VS1, VS2, ... VSN. Exported parameter values are either the individual
parameter estimates of a model fit or can be sampled from the estimated population distribution (with or
without uncertainty). The columns in the exported CSV Virtual Subjects file have the following meaning and content:
\itemize{
\item NAME: Name of the parameter or state in the model. Parameters that are assigned by initial assignments are
not exported.
\item TYPE: "State" or "Parameter" or "Parameter (individual)".
\item INFO: The comment in the IQRmodel for the respective element. "NA" if not present
\item VS1...N: The value of the respective element for virtual subject 1...N
}
}
\details{
Note that in the case of an IQRsysProject the random effects are not sampled from the population distribution (as this
is not estimated in sysfit) but from the empirical post-hoc eta distribution. If an IQRnlmeProject is used as a basis
(estimated in NONMEM, MONOLIX, or NLMIXR) then the estimated random effects will be used.

Virtual subjects are 1-N parameterizations of a model that are either obtained from
individual fits or from sampling from the population parameters. These individual
parameterizations can be stored along with the structural model in a folder of the users
choice. Functionality is available to allow loading this information again and simulate
these individual virtual subjects. Virtual cohorts are formed by a number of subjects (N>1), Virtual
populations are formed by a larger number of virtual subjects (N>>1). It is assumed that statistical
properties on the population level are matched by the virtual population if the estimation of the
parameters led to an adequate description of the underlying population.
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{compareModels_IQRnlmeProjectMulti}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}

Other QSP: 
\code{\link{IQRsysEst}()},
\code{\link{IQRsysModel}()},
\code{\link{IQRsysProject}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{as_IQRsysEst}()},
\code{\link{as_IQRsysProjectMulti}()},
\code{\link{as_IQRsysProject}()},
\code{\link{comparePars_IQRsysModel}()},
\code{\link{duplicate_IQRsysProject}()},
\code{\link{exportVariant_IQRmodel}()},
\code{\link{export_IQRsysData}()},
\code{\link{getDosing_IQRsysModel}()},
\code{\link{getEmpiricalETACovarianceMatrix_IQRsysProject}()},
\code{\link{getOptTrace_IQRsysProject}()},
\code{\link{getPars_IQRoptTrace}()},
\code{\link{getPars_IQRsysModel}()},
\code{\link{getPrediction_IQRsysModel}()},
\code{\link{hasrun_IQRsysProject}()},
\code{\link{importVariant_IQRmodel}()},
\code{\link{import_IQRsysData}()},
\code{\link{is_IQRsysEst}()},
\code{\link{is_IQRsysModel}()},
\code{\link{is_IQRsysProjectMulti}()},
\code{\link{is_IQRsysProject}()},
\code{\link{load_IQRsysProject}()},
\code{\link{modelSpec_IQRsysEst}()},
\code{\link{model_IQRsysModel}()},
\code{\link{offsetTIME_IQRsysData}()},
\code{\link{plotDVPRED_IQRsysModel}()},
\code{\link{plotFit_IQRsysModel}()},
\code{\link{plotPars_IQRsysModel}()},
\code{\link{plotPred_IQRsysModel}()},
\code{\link{plotProfile_IQRsysModel}()},
\code{\link{plotWRES_IQRsysModel}()},
\code{\link{plotWaterfall_IQRsysModel}()},
\code{\link{plot_IQRoptTrace}()},
\code{\link{plot_IQRsysModel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{print.IQRsysProject}()},
\code{\link{profile_IQRsysModel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{run_IQRsysProjectMulti}()},
\code{\link{run_IQRsysProject}()},
\code{\link{sample_IQRsysModel}()},
\code{\link{sensitivity_IQRmodel}()},
\code{\link{setPars_IQRsysModel}()},
\code{\link{sim_IQRsysModel}()},
\code{\link{sim_IQRvirtualSubjects}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{simbio_updateParamIC_IQRmodel}()},
\code{\link{spmIIV_IQRsysProject}()},
\code{\link{spm_IQRsysProject}()},
\code{\link{switchOpt_IQRsysModel}()},
\code{\link{tablePars_IQRsysModel}()}
}
\concept{IQRnlmeProject}
\concept{QSP}
