% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/general_tasks_regression.R
\name{fit_EmaxModel}
\alias{fit_EmaxModel}
\title{Fit Emax model to data}
\usage{
fit_EmaxModel(
  data,
  Emax = NULL,
  EC50 = NULL,
  Hill = NULL,
  y0 = 0,
  errmodel = "abs",
  log10Data = ""
)
}
\arguments{
\item{data}{data frame with \code{x} values (first column) and \code{y} values (second column).}

\item{Emax}{assume Emax to be fixed on this value. If \code{NULL}, Emax is estimated.}

\item{EC50}{assume EC50 to be fixed on this value. If \code{NULL}, EC50 is estimated.}

\item{Hill}{assume Emax to be fixed on this value. If \code{NULL}, Hill is estimated.}

\item{y0}{assume y0 (intercept) to be fixed on this value. If \code{NULL}, y0 is estimated.}

\item{errmodel}{the error model to be use, either \code{"abs"} (absolute error),
\code{"rel"} (proportional error) or \code{"absrel"} (absolute + proportional error).}

\item{log10Data}{specifies if \code{x} or \code{y} values are \code{log10}-transformed.
Possible values are \code{"x"} (first column contains log10-values), \code{"y"} (second
column contains log10-values), \code{"xy"} (both columns contain log10-values)
or \code{""} (no column contains log10-values).}
}
\value{
list with
\itemize{
\item \code{objval} (final objective function value, -2*log(L))
\item \code{converged} (convergence \code{TRUE} or \code{FALSE})
\item \code{iterations} (number of iterations)
\item \code{parameters} (data frame of parameter values, estimated and fixed)
\item \code{prd} (prediction function to evaluate the fitted model at new \code{x} values)
\item \code{prediction} (predicted values at the \code{x} values provded with \code{data})
\item \code{plot} (function that produces a plot)
\item \code{table} (parameter estimation table)
}
}
\description{
Estimate parameters Emax, EC50 and Hill parameter from \code{x} and \code{y}
values provided with a data frame. Error model parameters are
estimated alongside the model parameters via a maximum-
likelihood approach.
}
\details{
The model \code{y = y0 + Emax * x^Hill / (EC50^Hill + x^Hill)}
is fitted to the \code{x} and \code{y} values provided with \code{data}.
The fit is based on minimization of twice the negative
log-likelihood (-2*log(L)).
}
\seealso{
Other Auxiliary: 
\code{\link{IQRloadCSVdata}()},
\code{\link{IQRsaveCSVdata}()},
\code{\link{and}()},
\code{\link{aux_explodePC}()},
\code{\link{aux_explode}()},
\code{\link{aux_fileparts}()},
\code{\link{aux_fileread}()},
\code{\link{aux_filewrite}()},
\code{\link{aux_getRelPath}()},
\code{\link{aux_mkdir}()},
\code{\link{aux_na_locf}()},
\code{\link{aux_postFillChar}()},
\code{\link{aux_preFillChar}()},
\code{\link{aux_quantilenumber}()},
\code{\link{aux_rmdir}()},
\code{\link{aux_simplifypath}()},
\code{\link{aux_splitVectorEqualPieces}()},
\code{\link{aux_strFindAll}()},
\code{\link{aux_strrep}()},
\code{\link{aux_strtrim}()},
\code{\link{aux_unlevel}()},
\code{\link{aux_version}()},
\code{\link{calcAICBIC}()},
\code{\link{clusterX}()},
\code{\link{compare_IQRmodel_IQRsysModel_simulation}()},
\code{\link{format_GUM}()},
\code{\link{gen_aux_version}()},
\code{\link{geocv}()},
\code{\link{geomean}()},
\code{\link{geosd}()},
\code{\link{ge}()},
\code{\link{ginv}()},
\code{\link{gt}()},
\code{\link{interp0}()},
\code{\link{interp1}()},
\code{\link{interpcs}()},
\code{\link{inv_logit}()},
\code{\link{le}()},
\code{\link{logit}()},
\code{\link{lt}()},
\code{\link{mod}()},
\code{\link{mvrnorm}()},
\code{\link{or}()},
\code{\link{piecewise}()},
\code{\link{progressBar}()},
\code{\link{run_silent_IQR}()},
\code{\link{stopIQR}()},
\code{\link{tempdirIQR}()},
\code{\link{tempfileIQR}()},
\code{\link{warningIQR}()}
}
\concept{Auxiliary}
