% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/general_auxiliaries.R
\name{format_GUM}
\alias{format_GUM}
\title{Format numbers (with uncertainty) according to the "Guide to the Expression of Uncertainty in
Measurement (GUM)"}
\usage{
format_GUM(
  value,
  se = NULL,
  digits = 2,
  justify = c("decimal", "left", "right", "centre"),
  na.string = "--",
  ...
)
}
\arguments{
\item{value}{numeric values to be formatted.}

\item{se}{uncertainty values for \code{value}, either absolute (e.g. 0.93) or relative (e.g. "12\%").
Defaults to \code{NULL}, in which case
\code{value} is rounded according to \code{digits}.}

\item{digits}{number of significant digits to which \code{se} or \code{value}
(if \code{se} is missing) is rounded.}

\item{justify}{character (decimal, left, right or centre) to determine the output format
if \code{length(value) > 1}.}

\item{na.string}{instead of \code{NA} write na.string.}

\item{...}{additional arguments going to base \code{\link[base]{format}}.}
}
\value{
Character vector of rounded and justified values.
}
\description{
Uncertainties are rounded by default to two significant digits. Then, the values are rounded
to the precision implied by the uncertainty. If the uncertainty is missing, values are
rounded to two significant digits by default. The number of digits and the justification of the output
format can be changed.
}
\examples{
value <- c(2.0873624, 0.0057687, 0.087865, 3856.9898273, 1736.8735123)
se    <- c(0.0013756, 0.001765, 0.0006782, 9.23958, 124.79823)

niceTable <- data.frame(
  Value  = format_GUM(value, se),
  StdErr = format_GUM(se)
)

print(niceTable)

# Another example assuming 10\% uncertainty for all values
format_GUM(value, se = "10\%")

}
\references{
ISO, IEC, and BIPM OIML. Guide to the Expression of Uncertainty in Measurement. Geneva, Switzerland 1995.
}
\seealso{
Other Auxiliary: 
\code{\link{IQRloadCSVdata}()},
\code{\link{IQRsaveCSVdata}()},
\code{\link{and}()},
\code{\link{aux_explodePC}()},
\code{\link{aux_explode}()},
\code{\link{aux_fileparts}()},
\code{\link{aux_fileread}()},
\code{\link{aux_filewrite}()},
\code{\link{aux_getRelPath}()},
\code{\link{aux_mkdir}()},
\code{\link{aux_na_locf}()},
\code{\link{aux_postFillChar}()},
\code{\link{aux_preFillChar}()},
\code{\link{aux_quantilenumber}()},
\code{\link{aux_rmdir}()},
\code{\link{aux_simplifypath}()},
\code{\link{aux_splitVectorEqualPieces}()},
\code{\link{aux_strFindAll}()},
\code{\link{aux_strrep}()},
\code{\link{aux_strtrim}()},
\code{\link{aux_unlevel}()},
\code{\link{aux_version}()},
\code{\link{calcAICBIC}()},
\code{\link{clusterX}()},
\code{\link{compare_IQRmodel_IQRsysModel_simulation}()},
\code{\link{fit_EmaxModel}()},
\code{\link{gen_aux_version}()},
\code{\link{geocv}()},
\code{\link{geomean}()},
\code{\link{geosd}()},
\code{\link{ge}()},
\code{\link{ginv}()},
\code{\link{gt}()},
\code{\link{interp0}()},
\code{\link{interp1}()},
\code{\link{interpcs}()},
\code{\link{inv_logit}()},
\code{\link{le}()},
\code{\link{logit}()},
\code{\link{lt}()},
\code{\link{mod}()},
\code{\link{mvrnorm}()},
\code{\link{or}()},
\code{\link{piecewise}()},
\code{\link{progressBar}()},
\code{\link{run_silent_IQR}()},
\code{\link{stopIQR}()},
\code{\link{tempdirIQR}()},
\code{\link{tempfileIQR}()},
\code{\link{warningIQR}()}
}
\author{
Daniel Kaschek, IntiQuan
}
\concept{Auxiliary}
