% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_param_sampling.R
\name{generate_GPFFromProjectInfo}
\alias{generate_GPFFromProjectInfo}
\title{Rename/pick parameters and covariates in a GPF}
\usage{
generate_GPFFromProjectInfo(
  projectInfo,
  filename = NULL,
  FLAGdropErrParams = TRUE
)
}
\arguments{
\item{projectInfo}{A \link{GPFprojectInfo}, i.e. a list(projectPath, indPars_select, popPars_select, cov_select)}

\item{filename}{File to write the GPF to}

\item{FLAGdropErrParams}{Flag whether to drop error parameters such as "error_PROP1" (defaults to TRUE)}
}
\value{
\link{GPF}
}
\description{
Rename/pick parameters and covariates in a GPF
}
\examples{
\dontrun{
projPath <- system.file("examples/GPFExamples/project3_Epo", package = "IQRtools")
projectInfo <- GPFprojectInfo(projPath)
xls_fromProject <- generate_GPFFromProjectInfo(projectInfo, FLAGdropErrParams = TRUE)

# Rename parameters to parameter_X1 with indPars_select
pars <- getPopParameters_IQRnlmeProject(projPath)
projectInfo <- GPFprojectInfo(projPath,
                              indPars_select = setNames(names(pars),
                              paste0(names(pars), "_X1")))
xls_fromProject <- generate_GPFFromProjectInfo(projectInfo, FLAGdropErrParams = TRUE)
}
}
\seealso{
\href{https://iqrtools.intiquan.com/doc/book/GPF.html}{General Parameter Format}

Other Parameter sampling: 
\code{\link{calcIndParamValues}()},
\code{\link{calcTypicalIndParamValues}()},
\code{\link{combineGPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{getCorMatrixUncertainty}()},
\code{\link{getCovMatrixIIV}()},
\code{\link{getCovMatrixUncertainty}()},
\code{\link{getNamesAllParameters}()},
\code{\link{getNamesCovariateParameters}()},
\code{\link{getNamesCovariates}()},
\code{\link{getNamesErrorParameters}()},
\code{\link{getNamesIIVCorrParameters}()},
\code{\link{getNamesIIVParameters}()},
\code{\link{getNamesModelParameters}()},
\code{\link{getParamEstimates}()},
\code{\link{getParamTransformationTypes}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{is_GPF}()},
\code{\link{is_IQRnlmeParamSpec}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sampleIDs}()},
\code{\link{sampleIndParamValues}()},
\code{\link{sampleParamFromUncertainty}()},
\code{\link{sampleRandomEffects}()},
\code{\link{sample_GPF}()},
\code{\link{select_FromGPF}()},
\code{\link{specifyParamSampling}()},
\code{\link{transformParamToNormal}()},
\code{\link{untransformParamFromNormal}()}

Other GPF: 
\code{\link{GPF}()},
\code{\link{addIIVCov_toGPF}()},
\code{\link{combineGPF}()},
\code{\link{export_GPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{load_GPF}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sample_GPF}()},
\code{\link{select_FromGPF}()}
}
\author{
Daniel Lill (IntiQuan)
}
\concept{GPF}
\concept{Parameter sampling}
