% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_param_sampling.R
\name{getCovMatrixIIV}
\alias{getCovMatrixIIV}
\title{Construct an IIV covariance matrix}
\usage{
getCovMatrixIIV(
  obj,
  iivPopParamValues = getParamEstimates(obj),
  FLAGcheckPDCovMatrix = TRUE,
  FLAGreturnCorrMatrix = FALSE,
  FLAGcheckPDCorrMatrix = FLAGcheckPDCovMatrix
)
}
\arguments{
\item{obj}{a filename (character string) denoting the path to a GPF
file, or a GPF object, or a IQRnlmeParamSpec object.}

\item{iivPopParamValues}{a data.frame with population parameter values
describing the IIV distribution. The number of rows in this data.frame
defines the number of populations for which random effects are to be
sampled.}

\item{FLAGcheckPDCovMatrix}{logical indicating if the returned cov matrix should be
checked for positive-definiteness and adjusted to a positive-definite matrix (if possible).
Default: TRUE.}

\item{FLAGreturnCorrMatrix}{logical indicating if instead only returning the cov matrix,
a named list with an entry cov and corr should be containing the cov and corr matrices,
respectively. Default: FALSE.}

\item{FLAGcheckPDCorrMatrix}{logical that is meaningful only if FLAGreturnCorrMatrix is set
to TRUE. If so, the FLAG has analogical meaning to FLAGcheckPDCovMatrix. Default: FLAGcheckPDCovMatrix.}
}
\value{
a covariance matrix or (if FLAGreturnCorrMatrix == TRUE) a named list with elements cov and cor.
Note: if FLAGcheckPDCorrMatrix and FLAGcheckPDcovMatrix are TRUE, the returned object may not be matrices
but character strings with the value "failed".
}
\description{
Construct an IIV covariance matrix
}
\seealso{
\href{https://iqrtools.intiquan.com/doc/book/paramsampling.html}{Random sampling of NLME model parameters}

\href{https://iqrtools.intiquan.com/doc/book/GPF.html}{General Parameter Format}

Other Parameter sampling: 
\code{\link{calcIndParamValues}()},
\code{\link{calcTypicalIndParamValues}()},
\code{\link{combineGPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{generate_GPFFromProjectInfo}()},
\code{\link{getCorMatrixUncertainty}()},
\code{\link{getCovMatrixUncertainty}()},
\code{\link{getNamesAllParameters}()},
\code{\link{getNamesCovariateParameters}()},
\code{\link{getNamesCovariates}()},
\code{\link{getNamesErrorParameters}()},
\code{\link{getNamesIIVCorrParameters}()},
\code{\link{getNamesIIVParameters}()},
\code{\link{getNamesModelParameters}()},
\code{\link{getParamEstimates}()},
\code{\link{getParamTransformationTypes}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{is_GPF}()},
\code{\link{is_IQRnlmeParamSpec}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sampleIDs}()},
\code{\link{sampleIndParamValues}()},
\code{\link{sampleParamFromUncertainty}()},
\code{\link{sampleRandomEffects}()},
\code{\link{sample_GPF}()},
\code{\link{select_FromGPF}()},
\code{\link{specifyParamSampling}()},
\code{\link{transformParamToNormal}()},
\code{\link{untransformParamFromNormal}()}
}
\author{
Venelin Mitov, IntiQuan
}
\concept{Parameter sampling}
\keyword{internal}
