% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qsp_parameterization_variants.R
\name{importVariant_IQRmodel}
\alias{importVariant_IQRmodel}
\title{Important a model structure with defined parameterization variant}
\usage{
importVariant_IQRmodel(pathname, variantname)
}
\arguments{
\item{pathname}{The pathname from which to export model and parameterization}

\item{variantname}{The name of the parameterization variant to be stored. Either the
full path to the CSV file or the filename with or without extension can be
provided. Its is required though that the file is located in the pathname folder!}
}
\value{
An IQRmodel parameterized with the defined parameterization variant.
The models name is appended with the variant information.
}
\description{
IQR Tools allows to store IQRmodels with a certain parameterization in a folder.
Such a folder is allowed to contain the general structural model as model.txt file and
several csv files that contain model parameterizations in terms of state initial conditions
and parameter values. The format of these CSV files is:
Column names: NAME, TYPE, INFO, VALUE
NAME: Name of the parameter or state in the model. Note, not all parameters or states need
to appear. This function here will export all though. But for import only selected
elements can be present.
TYPE (optional): "State" or "Parameter". If not present it will be inferred from the model.
INFO (optional): The comment in the IQRmodel for the respective element. "NA" is not present.
If column not present it will be inferred from the model.
VALUE: The value of the respective element - always numeric
A special case with more than one VALUE column is possible and will be used to
handle multiple similar parameterizations - e.g. for virtual patients under a same condition.
}
\seealso{
Other IQRmodel: 
\code{\link{IQRmodel}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{exportSBML_IQRmodel}()},
\code{\link{exportVariant_IQRmodel}()},
\code{\link{export_IQRmodel}()},
\code{\link{getPars_IQRmodel}()},
\code{\link{hasCcodeFunctions_IQRmodel}()},
\code{\link{hasInitialAssignments_IQRmodel}()},
\code{\link{importSBML_IQRmodel}()},
\code{\link{is_IQRmodel}()},
\code{\link{new_IQRmodel}()},
\code{\link{print.IQRmodel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{regenerate_IQRmodel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{sensitivity_IQRmodel}()},
\code{\link{setParameters_IQRmodel}()},
\code{\link{setPars_IQRmodel}()},
\code{\link{sim_IQRmodel}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{simbio_updateParamIC_IQRmodel}()},
\code{\link{stoichiometry_IQRmodel}()},
\code{\link{strReplace_IQRmodel}()}

Other QSP: 
\code{\link{IQRsysEst}()},
\code{\link{IQRsysModel}()},
\code{\link{IQRsysProject}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{as_IQRsysEst}()},
\code{\link{as_IQRsysProjectMulti}()},
\code{\link{as_IQRsysProject}()},
\code{\link{comparePars_IQRsysModel}()},
\code{\link{duplicate_IQRsysProject}()},
\code{\link{exportVariant_IQRmodel}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{export_IQRsysData}()},
\code{\link{getDosing_IQRsysModel}()},
\code{\link{getEmpiricalETACovarianceMatrix_IQRsysProject}()},
\code{\link{getOptTrace_IQRsysProject}()},
\code{\link{getPars_IQRoptTrace}()},
\code{\link{getPars_IQRsysModel}()},
\code{\link{getPrediction_IQRsysModel}()},
\code{\link{hasrun_IQRsysProject}()},
\code{\link{import_IQRsysData}()},
\code{\link{is_IQRsysEst}()},
\code{\link{is_IQRsysModel}()},
\code{\link{is_IQRsysProjectMulti}()},
\code{\link{is_IQRsysProject}()},
\code{\link{load_IQRsysProject}()},
\code{\link{modelSpec_IQRsysEst}()},
\code{\link{model_IQRsysModel}()},
\code{\link{offsetTIME_IQRsysData}()},
\code{\link{plotDVPRED_IQRsysModel}()},
\code{\link{plotFit_IQRsysModel}()},
\code{\link{plotPars_IQRsysModel}()},
\code{\link{plotPred_IQRsysModel}()},
\code{\link{plotProfile_IQRsysModel}()},
\code{\link{plotWRES_IQRsysModel}()},
\code{\link{plotWaterfall_IQRsysModel}()},
\code{\link{plot_IQRoptTrace}()},
\code{\link{plot_IQRsysModel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{print.IQRsysProject}()},
\code{\link{profile_IQRsysModel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{run_IQRsysProjectMulti}()},
\code{\link{run_IQRsysProject}()},
\code{\link{sample_IQRsysModel}()},
\code{\link{sensitivity_IQRmodel}()},
\code{\link{setPars_IQRsysModel}()},
\code{\link{sim_IQRsysModel}()},
\code{\link{sim_IQRvirtualSubjects}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{simbio_updateParamIC_IQRmodel}()},
\code{\link{spmIIV_IQRsysProject}()},
\code{\link{spm_IQRsysProject}()},
\code{\link{switchOpt_IQRsysModel}()},
\code{\link{tablePars_IQRsysModel}()}
}
\concept{IQRmodel}
\concept{QSP}
