% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compliance_tools.R
\name{import_IQRdataOriginal}
\alias{import_IQRdataOriginal}
\title{Import a data file into the current folder structure}
\usage{
import_IQRdataOriginal(
  filename,
  description = "No description available",
  MD5 = NULL,
  target = basename(filename),
  interactive = TRUE
)
}
\arguments{
\item{filename}{relative or absolute path to the file to be imported.}

\item{description}{description of the imported file.}

\item{MD5}{customer-provided MD5 sum. If not provided, this will be noted in the log file.}

\item{target}{new name, with or without path information, of the imported file
(the base name of the original file by default).}

\item{interactive}{if \code{TRUE}, ask the user what should be done in case of conflicts.}
}
\description{
External data should be collected in a traceable way,
keeping the information where it came from. The function
takes the file specified by \code{filename}, copies
it to a \code{path} and creates/updates a logfile with
the information
\verb{@File} (filename in the new location),
\verb{@Source} (original filename),
\verb{@Description} (user-defined comment),
\verb{@Date} (date of import)
\verb{@MD5 File} (MD5 sum of imported file),
\verb{@MD5 Source} (MD5 sum of source file),
\verb{@MD5 Customer} (MD5 sum provided by customer/user), and
\verb{@MD5 Check} (Check message).
}
\details{
The target folder will automatically be created if not existing.
A logfile named \code{"datasources.txt"} will be created if missing in
the target folder.

The source file will always be copied to the target location unless the target file
already extisted and had a different MD5 sum than the new file. In that case,
the user is asked (in interactive mode), if the file should be overwritten. In
non-interactive mode, the file is always overwritten.
If a file was copied, the new file is checked against the provided MD5 information
and available information in the logfile. The logfile is then updated appropriately:
\itemize{
\item If MD5 sums are not consistent, a warning will be thrown and written to the logfile
\item If the target file was not in the logfile, a new entry is created
\item If the target file was in the logfile, the entry is updated
}
}
\examples{
\dontrun{

# Just for illustration
import_IQRdataOriginal(
  filename    = "../../Communication/Emails/181107/PKdata.xls",
  description = "PK data for compound X provided by Y via Email",
  target      = "data_X_PK.xls"
)

# Import to another folder
import_IQRdataOriginal(
  filename    = "../../Communication/Emails/181107/PKdata.xls",
  description = "PK data for compound X provided by Y via Email",
  target      = "../test/data_X_PK.xls"
)

}

}
\seealso{
Other Output: 
\code{\link{IQRinitCompliance}()},
\code{\link{IQRoutputCSV}()},
\code{\link{IQRoutputDEFINE}()},
\code{\link{IQRoutputFigure}()},
\code{\link{IQRoutputFile}()},
\code{\link{IQRoutputPDFend}()},
\code{\link{IQRoutputPDFstart}()},
\code{\link{IQRoutputPDF}()},
\code{\link{IQRoutputPNG}()},
\code{\link{IQRoutputRDS}()},
\code{\link{IQRoutputTable}()},
\code{\link{IQRoutputValueTable}()},
\code{\link{IQRoutputXPT}()},
\code{\link{createSubmissionPack}()},
\code{\link{getModelSpecification}()},
\code{\link{getProgramSpecification}()},
\code{\link{is_enabled_complianceMode}()},
\code{\link{is_enabled_rdsMode}()},
\code{\link{packageR_IQRtools}()},
\code{\link{print.IQRoutputTable}()},
\code{\link{read_IQRoutputTable}()},
\code{\link{text_IQRoutputTable}()}
}
\author{
Daniel Kaschek, IntiQuan
}
\concept{Output}
