% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_tools_informationcontent.R
\name{informationContent_IQRnlmeProject}
\alias{informationContent_IQRnlmeProject}
\title{Assess the expected information content wrt parameters, given a dosing and
observation schedule.}
\usage{
informationContent_IQRnlmeProject(
  projectPath,
  ...,
  sampling = NULL,
  output = NULL,
  dosing = NULL,
  pertSize = 10,
  filename = NULL,
  verbose = TRUE
)
}
\arguments{
\item{projectPath}{Path to an NLME project folder - from this project both the
structural model and the population mean parameterization is obtained.}

\item{...}{Additional arguments, passed to the simulator as options.
see sim_IQRmodel for integrator options.}

\item{sampling}{Vector with sampling times (for all considered OUTPUTs in the model the same).
It is possible to also define sampling as a list of these lists explained
above to be able to code for several different study arms or studies.
In this case also the "dosing" input argument needs to be a list - as long
as the sampling list.}

\item{output}{A vector with model output names (OUTPUT1, OUTPUT2, etc.) which are considered
for the analysis. By default all present OUTPUT* are used. The same sampling
is applied to all outputs (for now ... can be changed if desired).}

\item{dosing}{An single IQRdosing object or a list of IQRdosing objects. Such a list
needs to have the same length as the corresponding sampling list.}

\item{pertSize}{Relative parameter perturbations are used (in percent)}

\item{filename}{Path where to write out the resulting figures as a PDF file.}

\item{verbose}{Logical. If TRUE then informative input might be shown in the console.}
}
\value{
If no filename is provided, then the resulting plot is returned as a ggplot object with the
plotting data attached as attribute plotData
}
\description{
This function allows to predict the information content in data of
future studies, given the planned dosing and observation schedules. All with
respect to parameters in a predefined model structure.
}
\details{
It is simply based on sensitivity analysis wrt to changes in the model
parameters and correlation of the sensitivity trajectories.

Assessed will be the impact of changes in single model parameters on the
readout at given observation times. The median of these predicted
observations will be calculated and normalized sensitivities plotted as
barplot.

What is this function good for? Just an example:
If you have densly sampled data from Phase II studies and get a load of
sparsly sampled Phase III data in. Then this function might support you
in the selection of the parameters that you want to consider for
refitting on all data together.

Covariates, random effects, residual errors are NOT taken into account!
Population mean estimates of parameters are used!
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{compareModels_IQRnlmeProjectMulti}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}

Other Sensitivity Analysis: 
\code{\link{print.IQRsensitivity}()},
\code{\link{sensitivity_IQRmodel}()}
}
\concept{IQRnlmeProject}
\concept{Sensitivity Analysis}
