% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/logisticregression_tools.R
\name{modelEvaluation_IQRlogisticRegression}
\alias{modelEvaluation_IQRlogisticRegression}
\title{Model evaluation IQRlogisticRegression projects}
\usage{
modelEvaluation_IQRlogisticRegression(
  project,
  filename = NULL,
  SIGNIF = 3,
  AUCthreshold = 0.75,
  HLpValueThreshold = 0.05
)
}
\arguments{
\item{project}{Path to the IQRlogisticRegression to conduct the model evaluation for.}

\item{filename}{File name (with path) to store the resulting figure.}

\item{SIGNIF}{Number of significant digits used for the displayed p-value.}

\item{AUCthreshold}{Threshold for acceptance of model (calculated value should lie >=)}

\item{HLpValueThreshold}{Threshold for acceptance of model (calculated value should lie >=)}
}
\value{
IQRoutputFigure object with all results.
}
\description{
Two methods of model evaluation are applied to an IQRlogisticRegression object:
\enumerate{
\item Hosmer-Lemeshow goodness of fit test.
\item Area under the receiver operating characteristic (ROC) curve.
In order to consider that the logistic regression model developed
has sufficient predictive performance, one could usually accept models
with an AUC ROC>0.75 and a p value>0.05 for the Hosmer-Lemeshow test.
Of course, personally preferred different values would be possible to
define.
}
}
\details{
Some references:
\itemize{
\item Hosmer-Lemeshow goodness of fit test
\itemize{
\item Hosmer 2000: Hosmer Jr. D, Lemeshow S. Applied Logistic Regression. 2nd ed. New York, NY: John Wiley & Sons; 2000.
\item Rana 2010: Rana S, Midi H, Sarkar S. Validation and performance analysis of binary logistic regression model. Paper presented at: The WSEAS International Conference on Environment, Medicine, and Health Sciences. 2010.
}
\item ROC
\itemize{
\item Hanley 1982: Hanley JA, McNeil BJ. The meaning and use of the area under a receiver operating characteristic (ROC) curve. Radiology. 1982;143(1):29-36.
\item Eberhart 2000: Eberhart LH, Hogel J, Seeling W, Staack AM, Geldner G, Georgieff M. Evaluation of three risk scores to predict postoperative nausea and vomiting. Acta Anaesthesiol Scand. 2000;44(4):480-488
}
}
}
\seealso{
Other Logistic regression: 
\code{\link{IQRlogisticRegression}()},
\code{\link{export_IQRlogisticFit}()},
\code{\link{import_IQRlogisticFit}()},
\code{\link{plot_IQRlogistRegressFit}()},
\code{\link{simple_IQRlogisticRegression}()},
\code{\link{summary_IQRlogisticRegression}()}
}
\concept{Logistic regression}
