% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/estimation_classes_IQRest.R
\name{modelSpec_IQRest}
\alias{modelSpec_IQRest}
\title{Defines a modelSpec list for use in setting up estimation objects.}
\usage{
modelSpec_IQRest(
  POPvalues0,
  POPestimate = NULL,
  IIVdistribution = NULL,
  IIVvalues0 = NULL,
  IIVestimate = NULL,
  IOVvalues0 = NULL,
  IOVestimate = NULL,
  errorModel = NULL,
  covarianceModel = NULL,
  covariateModel = NULL,
  covariateModelValues = NULL,
  COVestimate = NULL,
  COVcentering = NULL,
  PriorVarPOP = NULL,
  PriorVarCovariateModelValues = NULL,
  PriorDFerrorModel = NULL,
  PriorIIV = NULL,
  PriorDFIIV = NULL
)
}
\arguments{
\item{POPvalues0}{A named vector. Names are names of the parameters set to "estimate" in the model.
Values are the initial guesses for the fixed effects. This is a required entry, as the function needs to know
at least which parameters are in scope for the estimation!}

\item{POPestimate}{A named vector. Names are names of the parameters set to "estimate" in the model.
A value of 0 indicates that the fixed effect of this parameter is fixed on its initial guess. A value of 1
indicates that this parameter is estimated.}

\item{IIVdistribution}{A named vector. Names are names of the parameters set to "estimate" in the model.
Elements can be "N", "L", and "G". "N" indicates a normal distribution of the corresponding
individual parameters. "L": logNormal, and "G": logitNormal. If IOV is estimated, the
same distribution is used.}

\item{IIVvalues0}{A named vector. Names are names of the parameters set to "estimate" in the model.
Values are the initial guesses for the random effects.}

\item{IIVestimate}{A named vector. Names are names of the parameters set to "estimate" in the model.
A value of 0 indicates that the random effect of this parameter is fixed to 0. A value of 1
indicates that the random effect is estimated. A value of 2 indicates that this random effect is
fixed to its initial guess and not estimated.}

\item{IOVvalues0}{A named vector. Names are names of the parameters set to "estimate" in the model.
Values are the initial guesses for the IOV. Same distribution as for IIV is assumed.}

\item{IOVestimate}{A named vector. Names are names of the parameters set to "estimate" in the model.
A value of 0 indicates that the IOV of this parameter is fixed to 0. A value of 1
indicates that the IOV is estimated. A value of 2 indicates that this IOV is
fixed to its initial guess and not estimated.}

\item{errorModel}{A list with as many fields as OUTPUT* definitions in the model. Names of these
fields need to be the names of the OUTPUT* definitions. Each field is defined
by a vector with the following elements:
First element: "type" and "guess". "type" can be
"abs" for absolute/additive error model, "rel" for relative/proportional error model,
and "absrel" for absolute/additive : relative/proportional error model.
Following elements (optional): initial guesses for error parameters. For "abs" and "rel"
only one additional element needs to be present. For "absrel" two, whereby the first element
is the initial guess for the absolute error and the second for the relative error.
In addition it is possible to choose "event" for the error model type. This allows
Joint Modeling with a TTE outcome. In this case no initial guess needs to be provided but the
name of the variable in the model that describes the hazard function value. \cr
Example: \code{errorModel = list(OUTPUT1 = c(type = "abs", guess = 1), OUTPUT2 = c(type = "absrel", 1,0.1))}}

\item{covarianceModel}{Vector with definitions of blocks. Syntax is as follows:
\code{covarianceModel = c("ka,CL,Vc","Q1,Q2")}. If covarianceModel=NULL or
\code{covarianceModel = "diagonal"} then no off diagonal elements will be estimated.
IMPORTANT: If NONMEM BAYES algorithm is planned to be used then covariance model needs to be
full! This means that if any of the prior information is provided, the covarianceModel setting
will be disregarded and et to full. The user is warned about that.}

\item{covariateModel}{List with definition of covariate model. Elements are named with the names of the
parameters on which to add a covariate. Values are vectors with names of covariates to add.
By default continuous covariates will be added as *(COV/REF)^THETA and categorical covariates
multiplicative as well. Reference values are medians of continuous and smallest categories of
categorical covariates. More complex desired covariate models can be coded in the model
itself - then covariates become "regression" parameters. Example:
\code{covariateModel = list(
                                CL = c("WT0","SEX"),
                                ka = c("SEX"),
                                Vc = c("WT0")
                            )}}

\item{covariateModelValues}{List with definition of covariate model initial guesses. Elements are named with the names of the
parameters on which to add a covariate. Values are named vectors with names of covariates and
values as the initial guesses. For categorical covariates the same initial guess is used for all categories.
\code{covariateModelValues = list(
                                CL = c(WT0=0.75, SEX=0.3),
                                ka = c(SEX=0.5),
                                Vc = c(WT0=1)
                                )}}

\item{COVestimate}{List with definition of covariate model estimation settings. Elements are named with the names of the
parameters on which to add a covariate. Values are 1 for estimation and 0 for fixing the covariate
coefficient. For categorical covariates only all category coefficients or none can be estimated or fixed.
Example:
\code{COVestimate = list(
                                CL = c(WT0=0, SEX=1),
                                ka = c(SEX=1),
                                Vc = c(WT0=0)
                                )}}

\item{COVcentering}{Named vector, defining the centering/reference values for covariates. Example:
\code{COVcentering  = c(WT0=70, SEX=2)}}

\item{PriorVarPOP}{An unnamed vector (same order as in POPvalues0), defining the variances of the priors for the fixed effects.
If this argument is not provided, non-informative priors will be used with variance 100*trans(POPvalues0).
Where trans() depends on the individual distribution "L": log, "N": none, "G": logit. Please avoid starting
guesses that lead to 0 transformed values!}

\item{PriorVarCovariateModelValues}{A list with the same struture as covariateModelValues, defining the variances for the priors of the
covariate coefficients. If undefined 1000 times covariateModelValues will be used (non-informative).
Example: \code{PriorVarCovariateModelValues = list(
                                      CL = c(WT0=0.1, SEX=10),
                                      ka = c(SEX=1000),
                                      Vc = c(WT0=0.1)
                                   )}}

\item{PriorDFerrorModel}{Degrees of freedom of SIGMA Prior. Scalar value for vector (integers). If scalar then
same value is used for all sigmas. If vector then the length of the vector needs to
match the number of error model parameters. Only used currently for NONMEM BAYES estimation.
Default scalar value: 4 (arbitrarily chosen).}

\item{PriorIIV}{An unnamed matrix of dimension NxN where N is the number of fixed effects in the model.
Standard deviation priors for random effects in the diagonal. And priors for correlations in the
off-diagonal elements. ONLY WORKS CORRECTLY FROM NONMEM 7.4 on! Do NOT use with NONMEM <7.4!
Full matrix of dimension NxN needs to be provided, where N is the number of fixed effects in the
model. Only lower triangular matrix will be used.
If not provided,
a diagonal matrix with initial guesses for standard devitation of the random effects will be used. The order of the matrix
can not be selected but is the same as the ordering of the named elements in POPvalues0.
Internally, the matrix will be split according to the provided covariance model into block diagonal elements.}

\item{PriorDFIIV}{Degrees of freedom of OMEGA Prior. Scalar value for vector (integers). If scalar then
same value is used for all omega blocks. If vector then the length of the vector needs to
match the number of omega blocks. One important thing here is that
all omega blocks (even if of dimension 1) need to be defined in the covarianceModel argument
(parameters for which no IIV is estimated should not appear in the covarianceModel argument).
Only used currently for NONMEM BAYES estimation. Default scalar value: 4 (arbitrarily chosen).
You could set it according to the formula that was proposed by D. Mats Karlsson:
\code{2*[(Omega estimate of previous analysis)/(SE of omega of previous analysis)]^2} or
\code{2*[(Omega estimate of previous analysis)/(SE of omega of previous analysis)]^2+1}}
}
\value{
Returns a modelSpec list for IQRnlmeEst and IQRsysEst
}
\description{
Can be used for syspharm and NLME type of estimation objects. This is a convenience function to allow better
documentation of the elements that can be in the modelSpec argument for IQRnlmeEst and IQRsysEst.
No consistency checks are done at this point. This is conducted in the IQRnlmeEst and IQRsysEst functions.
}
\details{
The prior information for fixed effects, covariate coefficients, random effect, and error model parameters
can be provided for use with the BAYES algorithm in NONMEM (MONOLIX is currently not supported for BAYES).
Important: priors for fixed effects are defined by the initial guesses, provided in \code{POPvalues0}.
Priors for covariate coefficients are provided by the initial guesses in \code{covariateModelValues}.
Priors for error model parameters are provided as the inital guesses in \code{errorModel}.
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{compareModels_IQRnlmeProjectMulti}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}
}
\author{
Henning Schmidt, IntiQuan
}
\concept{IQRnlmeProject}
