% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dMod_classes_IQRsysModel_aux.R
\name{modelSpec_IQRsysEst}
\alias{modelSpec_IQRsysEst}
\title{Model specification for IQRsysEst}
\usage{
modelSpec_IQRsysEst(
  POPvalues0 = NULL,
  POPestimate = NULL,
  IIVdistribution = NULL,
  IIVvalues0 = NULL,
  IIVestimate = NULL,
  errorModel = NULL,
  covarianceModel = NULL,
  covariateModel = NULL,
  covariateModelValues = NULL,
  COVestimate = NULL,
  COVcentering = NULL,
  PriorVarPOP = NULL,
  PriorVarCovariateModelValues = NULL,
  PriorDFerrorModel = NULL,
  PriorIIV = NULL,
  PriorDFIIV = NULL,
  LOCmodel = NULL,
  LOCvalues0 = NULL,
  LOCestimate = NULL,
  LOCdistribution = NULL
)
}
\arguments{
\item{POPvalues0}{named vector. Names are names of the parameters set to "estimate" in the model. A value of 0 indicates that
the fixed effect of this parameter is fixed on its initial guess. A value of 1 indicates that this parameter is estimated.}

\item{POPestimate}{A named vector. Names are names of the parameters set to "estimate" in the model. Values are
the initial guesses for the fixed effects. This is a required entry, as the function needs to know at least which
parameters are in scope for the estimation!}

\item{IIVdistribution}{A named vector. Names are names of the parameters set to "estimate" in the model. Elements
can be "N", "L", and "G". "N" indicates a normal distribution of the corresponding individual parameters. "L": logNormal,
and "G": logitNormal.}

\item{IIVvalues0}{A named vector. Names are names of the parameters set to "estimate" in the model. A value of 0 indicates
that the random effect of this parameter is fixed to 0. A value of 1 indicates that the random effect is estimated. A value
of 2 indicates that this random effect is fixed to its initial guess and not estimated.}

\item{IIVestimate}{A named vector. Names are names of the parameters set to "estimate" in the model. Values are the initial
guesses for the random effects.}

\item{errorModel}{A list with as many fields as OUTPUT* definitions in the model. Names of these fields need to be the names of the OUTPUT* definitions. Each field is defined by a vector with the following elements: First element: "type" and "guess". "type" can be "abs" for absolute/additive error model, "rel" for relative/proportional error model, and "absrel" for absolute/additive : relative/proportional error model. Following elements (optional): initial guesses for error parameters. For "abs" and "rel" only one additional element needs to be present. For "absrel" two, whereby the first element is the initial guess for the absolute error and the second for the relative error. In addition it is possible to choose "event" for the error model type. This allows Joint Modeling with a TTE outcome. In this case no initial guess needs to be provided but the name of the variable in the model that describes the hazard function value.}

\item{covarianceModel}{Vector with definitions of blocks. Syntax is as follows:
\code{covarianceModel = c("ka,CL,Vc","Q1,Q2")}. If covarianceModel=NULL or
\code{covarianceModel = "diagonal"} then no off diagonal elements will be estimated.
IMPORTANT: If NONMEM BAYES algorithm is planned to be used then covariance model needs to be
full! This means that if any of the prior information is provided, the covarianceModel setting
will be disregarded and et to full. The user is warned about that.}

\item{covariateModel}{List with definition of covariate model. Elements are named with the names of the
parameters on which to add a covariate. Values are vectors with names of covariates to add.
By default continuous covariates will be added as *(COV/REF)^THETA and categorical covariates
multiplicative as well. Reference values are medians of continuous and smallest categories of
categorical covariates. More complex desired covariate models can be coded in the model
itself - then covariates become "regression" parameters. Example:
\code{covariateModel = list(
                                CL = c("WT0","SEX"),
                                ka = c("SEX"),
                                Vc = c("WT0")
                            )}}

\item{covariateModelValues}{List with definition of covariate model initial guesses. Elements are named with the names of the
parameters on which to add a covariate. Values are named vectors with names of covariates and
values as the initial guesses. For categorical covariates the same initial guess is used for all categories.
\code{covariateModelValues = list(
                                CL = c(WT0=0.75, SEX=0.3),
                                ka = c(SEX=0.5),
                                Vc = c(WT0=1)
                                )}}

\item{COVestimate}{List with definition of covariate model estimation settings. Elements are named with the names of the
parameters on which to add a covariate. Values are 1 for estimation and 0 for fixing the covariate
coefficient. For categorical covariates only all category coefficients or none can be estimated or fixed.
Example:
\code{COVestimate = list(
                                CL = c(WT0=0, SEX=1),
                                ka = c(SEX=1),
                                Vc = c(WT0=0)
                                )}}

\item{COVcentering}{Named vector, defining the centering/reference values for covariates. Example:
\code{COVcentering  = c(WT0=70, SEX=2)}}

\item{PriorVarPOP}{Not used in IQR Tools QSP modeling}

\item{PriorVarCovariateModelValues}{Not used in IQR Tools QSP modeling}

\item{PriorDFerrorModel}{Not used in IQR Tools QSP modeling}

\item{PriorIIV}{Not used in IQR Tools QSP modeling}

\item{PriorDFIIV}{Not used in IQR Tools QSP modeling}

\item{LOCmodel}{Deprecated in IQR Tools QSP modeling}

\item{LOCvalues0}{Deprecated in IQR Tools QSP modeling}

\item{LOCestimate}{Deprecated in IQR Tools QSP modeling}

\item{LOCdistribution}{Deprecated in IQR Tools QSP modeling}
}
\value{
IQRsysEst object
}
\description{
Definition of estimation settings. See documentation for IQRnlmeEst
}
\seealso{
Other QSP: 
\code{\link{IQRsysEst}()},
\code{\link{IQRsysModel}()},
\code{\link{IQRsysProject}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{as_IQRsysEst}()},
\code{\link{as_IQRsysProjectMulti}()},
\code{\link{as_IQRsysProject}()},
\code{\link{comparePars_IQRsysModel}()},
\code{\link{duplicate_IQRsysProject}()},
\code{\link{exportVariant_IQRmodel}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{export_IQRsysData}()},
\code{\link{getDosing_IQRsysModel}()},
\code{\link{getEmpiricalETACovarianceMatrix_IQRsysProject}()},
\code{\link{getOptTrace_IQRsysProject}()},
\code{\link{getPars_IQRoptTrace}()},
\code{\link{getPars_IQRsysModel}()},
\code{\link{getPrediction_IQRsysModel}()},
\code{\link{hasrun_IQRsysProject}()},
\code{\link{importVariant_IQRmodel}()},
\code{\link{import_IQRsysData}()},
\code{\link{is_IQRsysEst}()},
\code{\link{is_IQRsysModel}()},
\code{\link{is_IQRsysProjectMulti}()},
\code{\link{is_IQRsysProject}()},
\code{\link{load_IQRsysProject}()},
\code{\link{model_IQRsysModel}()},
\code{\link{offsetTIME_IQRsysData}()},
\code{\link{plotDVPRED_IQRsysModel}()},
\code{\link{plotFit_IQRsysModel}()},
\code{\link{plotPars_IQRsysModel}()},
\code{\link{plotPred_IQRsysModel}()},
\code{\link{plotProfile_IQRsysModel}()},
\code{\link{plotWRES_IQRsysModel}()},
\code{\link{plotWaterfall_IQRsysModel}()},
\code{\link{plot_IQRoptTrace}()},
\code{\link{plot_IQRsysModel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{print.IQRsysProject}()},
\code{\link{profile_IQRsysModel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{run_IQRsysProjectMulti}()},
\code{\link{run_IQRsysProject}()},
\code{\link{sample_IQRsysModel}()},
\code{\link{sensitivity_IQRmodel}()},
\code{\link{setPars_IQRsysModel}()},
\code{\link{sim_IQRsysModel}()},
\code{\link{sim_IQRvirtualSubjects}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{simbio_updateParamIC_IQRmodel}()},
\code{\link{spmIIV_IQRsysProject}()},
\code{\link{spm_IQRsysProject}()},
\code{\link{switchOpt_IQRsysModel}()},
\code{\link{tablePars_IQRsysModel}()}
}
\author{
Daniel Lill, IntiQuan
}
\concept{QSP}
