% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_classes_IQRdataGeneral_aux.R
\name{mutateCov_IQRdataGENERAL}
\alias{mutateCov_IQRdataGENERAL}
\title{Add Covariate to IQRdataGENERAL object}
\usage{
mutateCov_IQRdataGENERAL(data, ..., unit, name)
}
\arguments{
\item{data}{IQRdataGENERAL object.}

\item{...}{specification of new covariates, e.g. \code{STD = "STUDY"} where
\code{STUDY} is a column in \code{data}. More than one categorical covariate can
be specified this way. Later covariates can make use of earlier covariates.}

\item{unit}{units of the covariates. Argument is recyled until its length is that of
the list of new covariates.}

\item{name}{description for the new covariate, e.g. "Study identifier".}
}
\value{
IQRdataGeneral object
}
\description{
New covariates specified in terms of data columns are added as columns
to the data and as rows to the covInfo and catInfo tables.
The function is also useful to
add existing columns to the catInfo/covInfo table.
}
\details{
The characters provided by the dots argument are parsed and evaluated within
\code{data}. New columns are appended to the original data. Depending on the columns
used and the output of the evaluation (numeric or character), the new covariate is
interpreted as continuous or categorical variable.
The covInfo/catInfo table is modified to contain the new variable.
However, the covariate is not introduced as a new set of rows with NAME equal to the
\code{name} argument. For any new covariate it is checked if the covariate takes different
values within one group defined by each \code{USUBJID}. IF that is the case, the covariate
is marked as TIME.VARYING in the covInfo/catInfo table.
}
\examples{
\dontrun{
# Add new continuous covariate
test <- mutateCov_IQRdataGENERAL(
  dataGeneral,
  BMI = "WGT/HGT^2",
  unit = "kg/m^2",
  name = "Body mass index"
)

# Do the same based on names instead of colnames
test <- mutateCov_IQRdataGENERAL(
  dataGeneral,
  BMI = "Weight/Height^2",
  unit = "kg/m^2",
  name = "Body mass index"
)

# Convert existing STUDY column into categorical covariate
test <- mutateCov_IQRdataGENERAL(
  dataGeneral,
  STD = "STUDY",
  unit = NA,
  name = "Study identifier"
)

# Create covariate based on general expressions
test <- mutateCov_IQRdataGENERAL(
  dataGeneral,
  ASN = "ifelse(REG == 1, 'yes', 'no')",
  unit = NA,
  name = "Is Asian"
)

# Do the same with names of the covariates
test <- mutateCov_IQRdataGENERAL(
  dataGeneral,
  ASN = "ifelse(Region == 'Asia', 'yes', 'no')",
  unit = NA,
  name = "Is Asian"
)

# If names contain spaces, use "."
test <- mutateCov_IQRdataGENERAL(
  dataGeneral,
  EVM = "as.character(Time.to.vomit < 1)",
  unit = NA,
  name = "Early vomit"
)

}
}
\seealso{
Other IQRdataGeneral: 
\code{\link{+.IQRdataGENERAL}()},
\code{\link{IQRcalcTAD}()},
\code{\link{IQRdataGENERAL}()},
\code{\link{IQRexpandADDLII}()},
\code{\link{IQRloadCSVdata}()},
\code{\link{IQRsaveCSVdata}()},
\code{\link{addIndivRegressors_IQRdataGENERAL}()},
\code{\link{addLabel_IQRdataGENERAL}()},
\code{\link{attributes0}()},
\code{\link{blloqInfo_IQRdataGENERAL}()},
\code{\link{blloq_IQRdataGENERAL}()},
\code{\link{check_IQRdataGENERAL}()},
\code{\link{clean_IQRdataGENERAL}()},
\code{\link{combine_IQRdataGENERAL}()},
\code{\link{convertCat2Text}()},
\code{\link{covImpute_IQRdataGENERAL}()},
\code{\link{date2dateday_IQRdataProgramming}()},
\code{\link{date2datetime_IQRdataProgramming}()},
\code{\link{date2time_IQRdataProgramming}()},
\code{\link{exportDEFINE_IQRaedataER}()},
\code{\link{exportDEFINE_IQRdataGENERAL}()},
\code{\link{exportDEFINEpdf_IQRdataGENERAL}()},
\code{\link{exportSYS_IQRdataGENERAL}()},
\code{\link{export_IQRdataGENERAL}()},
\code{\link{getLabels_dataframe}()},
\code{\link{getNAcolNLME_IQRdataGENERAL}()},
\code{\link{handleSameTimeObs_IQRdataGENERAL}()},
\code{\link{is_IQRdataGENERAL}()},
\code{\link{loadATRinfo_csvData}()},
\code{\link{loadAttributeFile}()},
\code{\link{load_IQRdataGENERAL}()},
\code{\link{mapCategoricalCovariate_IQRnlmeProject}()},
\code{\link{mapCategoricalCovariate_csvData}()},
\code{\link{mapContinuousCovariate_IQRnlmeProject}()},
\code{\link{mapContinuousCovariate_csvData}()},
\code{\link{obfuscate_IQRdataGENERAL}()},
\code{\link{plot.IQRdataGENERAL}()},
\code{\link{plotCorCat_IQRdataGENERAL}()},
\code{\link{plotCorCovCat_IQRdataGENERAL}()},
\code{\link{plotCorCov_IQRdataGENERAL}()},
\code{\link{plotCovDistribution_IQRdataGENERAL}()},
\code{\link{plotDoseSchedule_IQRdataGENERAL}()},
\code{\link{plotIndiv_IQRdataGENERAL}()},
\code{\link{plotRange_IQRdataGENERAL}()},
\code{\link{plotSampleSchedule_IQRdataGENERAL}()},
\code{\link{plotSpaghetti_IQRdataGENERAL}()},
\code{\link{print.IQRdataGENERAL}()},
\code{\link{removeCommata_dataframe}()},
\code{\link{rmAMT0_IQRdataGENERAL}()},
\code{\link{rmDosePostLastObs_IQRdataGENERAL}()},
\code{\link{rmIGNOREd_IQRdataGENERAL}()},
\code{\link{rmMissingTIMEobsRecords_IQRdataGENERAL}()},
\code{\link{rmNOobsSUB_IQRdataGENERAL}()},
\code{\link{rmNonTask_IQRdataGENERAL}()},
\code{\link{rmPLACEBO_IQRdataGENERAL}()},
\code{\link{rmSubjects_IQRdataGENERAL}()},
\code{\link{setIGNORErecords_IQRdataGENERAL}()},
\code{\link{setMissingDVobsRecordsIGNORE_IQRdataGENERAL}()},
\code{\link{subset.IQRdataGENERAL}()},
\code{\link{summary.IQRdataGENERAL}()},
\code{\link{summaryCat_IQRdataGENERAL}()},
\code{\link{summaryCov_IQRdataGENERAL}()},
\code{\link{summaryObservations_IQRdataGENERAL}()},
\code{\link{transformObs_IQRdataGENERAL}()},
\code{\link{unlabel_dataframe}()}
}
\author{
Daniel Kaschek, IntiQuan
}
\concept{IQRdataGeneral}
