% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qsp_tools_data.R
\name{offsetTIME_IQRsysData}
\alias{offsetTIME_IQRsysData}
\title{Function to shift data right on time axis by a certain offset}
\usage{
offsetTIME_IQRsysData(data, offset)
}
\arguments{
\item{data}{Estimation dataset for sysfit}

\item{offset}{Desired time offset to allow reaching steady-state}
}
\value{
Updated dataset
}
\description{
In QSP modeling the steady-state _/ baseline values are dependent by parameters
without the possibility of analytically calculating the steady-state. Therefor,
a runin-period needs to be allowed for so that when changing parameters a new
steady-state can be obtained prior to starting the experiment - or the comparison
between data and simulations in estimation and in simulation.
This function allows to introduce such a runin period by adding a dose of 0 into the
dataset that comes "offset" time before the first recorded event in the dataset.
For this to work it is important that the model contains at least an INPUT1 argument.
Also required are the presence of the columns introduced by import_IQRsysData.
}
\details{
Important are also the numerics. If offset chosen to large, it might lead to numerical
difficulties which can be circumvented by setting the options SIMOPT.atol or SIMOPT.hmax
in the call to IQRsysProject().
}
\seealso{
Other QSP: 
\code{\link{IQRsysEst}()},
\code{\link{IQRsysModel}()},
\code{\link{IQRsysProject}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{as_IQRsysEst}()},
\code{\link{as_IQRsysProjectMulti}()},
\code{\link{as_IQRsysProject}()},
\code{\link{comparePars_IQRsysModel}()},
\code{\link{duplicate_IQRsysProject}()},
\code{\link{exportVariant_IQRmodel}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{export_IQRsysData}()},
\code{\link{getDosing_IQRsysModel}()},
\code{\link{getEmpiricalETACovarianceMatrix_IQRsysProject}()},
\code{\link{getOptTrace_IQRsysProject}()},
\code{\link{getPars_IQRoptTrace}()},
\code{\link{getPars_IQRsysModel}()},
\code{\link{getPrediction_IQRsysModel}()},
\code{\link{hasrun_IQRsysProject}()},
\code{\link{importVariant_IQRmodel}()},
\code{\link{import_IQRsysData}()},
\code{\link{is_IQRsysEst}()},
\code{\link{is_IQRsysModel}()},
\code{\link{is_IQRsysProjectMulti}()},
\code{\link{is_IQRsysProject}()},
\code{\link{load_IQRsysProject}()},
\code{\link{modelSpec_IQRsysEst}()},
\code{\link{model_IQRsysModel}()},
\code{\link{plotDVPRED_IQRsysModel}()},
\code{\link{plotFit_IQRsysModel}()},
\code{\link{plotPars_IQRsysModel}()},
\code{\link{plotPred_IQRsysModel}()},
\code{\link{plotProfile_IQRsysModel}()},
\code{\link{plotWRES_IQRsysModel}()},
\code{\link{plotWaterfall_IQRsysModel}()},
\code{\link{plot_IQRoptTrace}()},
\code{\link{plot_IQRsysModel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{print.IQRsysProject}()},
\code{\link{profile_IQRsysModel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{run_IQRsysProjectMulti}()},
\code{\link{run_IQRsysProject}()},
\code{\link{sample_IQRsysModel}()},
\code{\link{sensitivity_IQRmodel}()},
\code{\link{setPars_IQRsysModel}()},
\code{\link{sim_IQRsysModel}()},
\code{\link{sim_IQRvirtualSubjects}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{simbio_updateParamIC_IQRmodel}()},
\code{\link{spmIIV_IQRsysProject}()},
\code{\link{spm_IQRsysProject}()},
\code{\link{switchOpt_IQRsysModel}()},
\code{\link{tablePars_IQRsysModel}()}
}
\concept{QSP}
