% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_auxiliaries_plots.R
\name{plotINDIVSIM_IQRnlmeProject}
\alias{plotINDIVSIM_IQRnlmeProject}
\title{Plot the individual fits for NLME projects using simulated individual fits.}
\usage{
plotINDIVSIM_IQRnlmeProject(
  projectPath,
  obssel = NULL,
  plotLog = FALSE,
  nsimtimes = 500,
  simtimes = NULL,
  ncol = 4,
  nrow = 2,
  filename = NULL,
  FLAGincludeIPRED = FALSE,
  opt_abstol = 1e-06,
  opt_reltol = 1e-06,
  opt_minstep = 0,
  opt_maxstep = 0,
  opt_initstep = 0
)
}
\arguments{
\item{projectPath}{path to NLME project}

\item{obssel}{character string that can be used to subset the observations (and fits accodingly)}

\item{plotLog}{Logical, selects if Y axis linear or log scale}

\item{nsimtimes}{Number of timepoints to evaluate in the simulations if simtimes is NULL}

\item{simtimes}{Vector with simulation times. Defaults to NULL.}

\item{ncol}{Number of columns per page}

\item{nrow}{Number of rows per page}

\item{filename}{name to file to which the plots will be exported.
If not given (NULL), plot object including plotting data as attributes are returned}

\item{FLAGincludeIPRED}{Flag whether to load and display the individual predictions from
the estimation software.}

\item{opt_abstol}{Double value for absolute tolerance}

\item{opt_reltol}{Double value for relative tolerance}

\item{opt_minstep}{Double value for minimal integrator step-size}

\item{opt_maxstep}{Double value for maximal integrator step-size}

\item{opt_initstep}{Double value for initial step-size to be attempted}
}
\value{
IQRoutputFigure returned if no filename given. Otherwise called for side effect.
}
\description{
Individual panels for each observable (YTYPE/OUTPUT) are created showing the observations
and the individual predictions. Predictions are evaluated at equidistant timepoints spanning
the time frame for each individual and the observations times. The individual time frame is
taken as the minimum to maximum time per individual (pooling dose and observation records).
Alternatively, a time vector which is applied for all subject can be speified. In any case,
simulation are evaluated at the individual observation times.
To cross-check the simulations, the individual predictions that were determined by the
parameter estimation tool can be displayed in addition.
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{compareModels_IQRnlmeProjectMulti}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}
}
\author{
Anne Kuemmel
}
\concept{IQRnlmeProject}
