% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_tools_vpc.R
\name{plotVPC_IQRdataVPC}
\alias{plotVPC_IQRdataVPC}
\title{Create VPC plot}
\usage{
plotVPC_IQRdataVPC(
  dataVPC,
  stratifyBy = NULL,
  periodBy = NULL,
  FLAGstratifyByPeriod = FALSE,
  filename = NULL,
  FLAGlogY = FALSE,
  FLAGuseTAD = FALSE,
  FLAGdataPlotOnly = FALSE,
  FLAGnoDataPoints = FALSE,
  FLAGrmBLQ = FALSE,
  FLAGpc = FALSE,
  FLAGplotBins = FALSE,
  FLAGplotN = FALSE,
  FLAGsmooth = FALSE,
  smoothDFfact = 0.5,
  title = NULL,
  subtitle = NULL,
  BIN.column = NULL,
  BIN.breaks = NULL,
  BIN.groupsize = NULL,
  BIN.lambda = 1,
  BIN.resolution = 0.1,
  CIlevel = 95,
  percentiles = c(5, 95),
  alphaDataPoints = 0.4,
  nrow = 1,
  ncol = 1
)
}
\arguments{
\item{dataVPC}{Named list with simulated (\emph{sim}) and potentially typical
predictions for observed (\emph{obs}) data}

\item{stratifyBy}{Column name used to stratify VPC plots}

\item{periodBy}{Colum name identifying different periods (time-varying categorical covariates)
Time courses are binned and plotted separately. Whether they are plotted in
the same panel is set by FLAGstratifyByPeriod}

\item{FLAGstratifyByPeriod}{Flag whether period are plotted in separate panels}

\item{filename}{Filename for export of the VPC to a PDF. If NULL object including
plotting data is returned.}

\item{FLAGlogY}{logical. If TRUE the Y axis will be shown in logscale.}

\item{FLAGuseTAD}{logical. If TRUE then time after previous dose (TAD) used for x-axis. If TRUE then}

\item{FLAGdataPlotOnly}{logical. If TRUE then no simulation is done and only
the data and lines for the percentiles are plotted. This allows to find suitable
settings for the binning parameters BIN.groupsize and BIN.lambda.}

\item{FLAGnoDataPoints}{If TRUE then data points will be ommitted but percentiles for data will be shown}

\item{FLAGrmBLQ}{Flag whether to remove BLQ values from simulated data AND observations}

\item{FLAGpc}{Flag whether to apply prediction correction. Can only be performed
if typical prediction are present in dataVPC}

\item{FLAGplotBins}{Flag whether to plot the bin boundaries as vertical lines}

\item{FLAGplotN}{Flag whether to display number of subjects in panel}

\item{FLAGsmooth}{Flag whether CI of simulated data should be smoothed}

\item{smoothDFfact}{Factor to multiply the number of unique time points determining
the degrees of freedom for smoothing}

\item{title}{Character string to be plotted as plot title (on each page)}

\item{subtitle}{Character string to be plotted as plot subtitle (on each page)}

\item{BIN.column}{Column name of integer column assigning the observations to time bins. Defaults to NULL
such that bins are automatically generated or the user-provided BIN.breaks are used.}

\item{BIN.breaks}{Numerical vector with bin borders that are used for the observation times. Defaults to NULL
such that bins are automatically generated. This input is ignored if BIN.column is provided.}

\item{BIN.groupsize}{Smallest expected group size for the binning. By default the round(0.5 x number
of subjects) in the dataset is used.}

\item{BIN.lambda}{Penalization of intra-group variance, set to 1 to have more
groups and set to 0 to get less but larger groups.}

\item{BIN.resolution}{Gaps between groups of data points greater than resolution lead to separation of groups}

\item{CIlevel}{Confidence interval level for percentiles (in percent)}

\item{percentiles}{numeric vector with 2 entries between 0 and 100 to be used as
percentiles for data and simulation plots}

\item{alphaDataPoints}{Alpha transparency level for data points}

\item{nrow}{Number of panel rows for plot layout}

\item{ncol}{Number of panel columns for plot layout}
}
\value{
If no filename is given, ggplot object with additional plotting information
}
\description{
Determines CI for the quantiles across simulated trials and quantiles of the
observation and creates VPC plot.
}
\details{
Input \emph{dataVPC} is the output of \link{vpc_IQRnlmeProject}.
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{compareModels_IQRnlmeProjectMulti}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}

Other VPC: 
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotVPC_IQRtteProject}()},
\code{\link{vpc_IQRnlmeProject}()}
}
\author{
Anne Kuemmel, IntiQuan
}
\concept{IQRnlmeProject}
\concept{VPC}
