% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_classes_IQRnlmeProject.R
\name{pred_IQRnlmeProject}
\alias{pred_IQRnlmeProject}
\title{Predict values based on provided NLME project}
\usage{
pred_IQRnlmeProject(
  project,
  model = NULL,
  data = NULL,
  simtime = NULL,
  abs0inputs = NULL,
  abs0Tk0param = NULL,
  opt_abstol = 1e-06,
  opt_reltol = 1e-06
)
}
\arguments{
\item{project}{NLME project}

\item{model}{By default the IQRmodel stored within the NLNME project will be used.
This can be overridden by providing a different IQRmodel. E.g., with additional
integration odf the AUC.}

\item{data}{By default the data from the NLME project will be used. This can be
overridden by providing an altenative dataset. Elements taken from this dataset
are the doses, regression parameters (time independent and time dependent) and
by default the observation times for each individual (if simtime not provided).}

\item{simtime}{A list with individual simulation time vectors. The list has to be named
with the respective IDs in the dataset.}

\item{abs0inputs}{Numeric vector with numbers of inputs (ADM) that are of type
ABSORPTION0. If this argument is set also abs0Tk0param needs to be defined.}

\item{abs0Tk0param}{Character vector with names of regression parameters that should
be used as 0-order infusion time (by updating TINF). The regression parameters for
these values are kept in the event table. Ordering has to be as in abs0inputs.}

\item{opt_abstol}{Integratior absolute tolerance.}

\item{opt_reltol}{Integrator relative tolerance.}
}
\description{
This function takes an IQRnlmeProject and predicts values based on the
individual parameter estimates. Simulation time can be chosen for each simulated subject
independently. By default information from the NLME project will be used
(individual observation times, the structural model, and the data). But individual
simulation times, the structural model, and the data can also be customized.
}
\details{
A typical use of this function would be in the prediction of individual exposures to
then derive exposure metrics to use in an exposure-response analysis.
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{compareModels_IQRnlmeProjectMulti}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}
}
\concept{IQRnlmeProject}
