% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_param_sampling.R
\name{sampleIDs}
\alias{sampleIDs}
\title{Sample or subset records from a matrix or a data.frame}
\usage{
sampleIDs(data, Nsamples)
}
\arguments{
\item{data}{a data.frame describing patient or other subject covariate and regressor data.
If nrow(data)==Nsamples, then all rows in data
are returned (in their original order) in the resulting data.frame; if
nrow(data)>Nsamples, sampling without replacement from the rows in data
is done; if nrow(data)<Nsamples then sampling with replacement is done.}

\item{Nsamples}{integer denoting the number of individuals in a
population. Note: in the case of \code{FLAG_SAMPLE=2}, this value is used to specify
the number of populations (see \code{Npop}). Default:
\code{if(is_IQRnlmeParamSpec(obj)) obj$Nsamples else 1L}.}
}
\value{
a data.frame. If nrow(data)==Nsamples, then all rows in data
are included (in their original order); if nrow(data)>Nsamples, sampling
without replacement from the rows in data is done; if nrow(data)<Nsamples
then sampling with replacement is done. The returned data.frame has a
column ID set to the integers 1:Nsamples. If the original data object
did have a column ID, this column is copied as a column ID0 in the returned
data.frame.
}
\description{
Sample or subset records from a matrix or a data.frame
}
\examples{
\dontrun{
#See the examples for sampleIndParamValues:
?sampleIndParamValues
}
}
\seealso{
\href{https://iqrtools.intiquan.com/doc/book/paramsampling.html}{Random sampling of NLME model parameters}

\href{https://iqrtools.intiquan.com/doc/book/GPF.html}{General Parameter Format}

Other Parameter sampling: 
\code{\link{calcIndParamValues}()},
\code{\link{calcTypicalIndParamValues}()},
\code{\link{combineGPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{generate_GPFFromProjectInfo}()},
\code{\link{getCorMatrixUncertainty}()},
\code{\link{getCovMatrixIIV}()},
\code{\link{getCovMatrixUncertainty}()},
\code{\link{getNamesAllParameters}()},
\code{\link{getNamesCovariateParameters}()},
\code{\link{getNamesCovariates}()},
\code{\link{getNamesErrorParameters}()},
\code{\link{getNamesIIVCorrParameters}()},
\code{\link{getNamesIIVParameters}()},
\code{\link{getNamesModelParameters}()},
\code{\link{getParamEstimates}()},
\code{\link{getParamTransformationTypes}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{is_GPF}()},
\code{\link{is_IQRnlmeParamSpec}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sampleIndParamValues}()},
\code{\link{sampleParamFromUncertainty}()},
\code{\link{sampleRandomEffects}()},
\code{\link{sample_GPF}()},
\code{\link{select_FromGPF}()},
\code{\link{specifyParamSampling}()},
\code{\link{transformParamToNormal}()},
\code{\link{untransformParamFromNormal}()}
}
\author{
Venelin Mitov (IntiQuan)
}
\concept{Parameter sampling}
\keyword{internal}
