% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_param_sampling.R
\name{sampleParamFromUncertainty}
\alias{sampleParamFromUncertainty}
\title{Sample NLME parameters from their uncertainty distribution}
\usage{
sampleParamFromUncertainty(
  spec,
  Npop = if (is_IQRnlmeParamSpec(spec)) spec$Npop else 1L
)
}
\arguments{
\item{spec}{a filename (character string) denoting the path to a GPF
excel file, or a GPF object, or an IQRnlmeParamSpec object.}

\item{Npop}{integer denoting the number of populations to sample. Default:
\code{if(is_IQRnlmeParamSpec(obj)) obj$Npop else if(FLAG_SAMPLE==2) Nsamples else 1L}.}
}
\value{
a data.frame of \code{Npop} rows with columns \code{ID.POP} and parameter
value columns as follows:
\describe{
\item{X,Y...: }{reference population values for model parameters X,Y...}
\item{omega(X),omega(Y)...: }{IIV population values for model parameters X,Y,...}
\item{corr(X,Y),...: }{IIV correlation population values for model parameter pairs.}
\item{beta_X(COVRT1),beta_Y(COVRT2),...: }{Covariate coefficient population values.}
\item{error_PROP1,...: }{Residual error population parameters.}
}
}
\description{
Sample NLME parameters from their uncertainty distribution
}
\examples{
\dontrun{
#See the examples for sampleIndParamValues:
?sampleIndParamValues
}
}
\seealso{
\href{https://iqrtools.intiquan.com/doc/book/paramsampling.html}{Random sampling of NLME model parameters}

\href{https://iqrtools.intiquan.com/doc/book/GPF.html}{General Parameter Format}

\href{https://iqrtools.intiquan.com/doc/book/paramsampling.html}{Random sampling of NLME model parameters}

\href{https://iqrtools.intiquan.com/doc/book/GPF.html}{General Parameter Format}

Other Parameter sampling: 
\code{\link{calcIndParamValues}()},
\code{\link{calcTypicalIndParamValues}()},
\code{\link{combineGPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{generate_GPFFromProjectInfo}()},
\code{\link{getCorMatrixUncertainty}()},
\code{\link{getCovMatrixIIV}()},
\code{\link{getCovMatrixUncertainty}()},
\code{\link{getNamesAllParameters}()},
\code{\link{getNamesCovariateParameters}()},
\code{\link{getNamesCovariates}()},
\code{\link{getNamesErrorParameters}()},
\code{\link{getNamesIIVCorrParameters}()},
\code{\link{getNamesIIVParameters}()},
\code{\link{getNamesModelParameters}()},
\code{\link{getParamEstimates}()},
\code{\link{getParamTransformationTypes}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{is_GPF}()},
\code{\link{is_IQRnlmeParamSpec}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sampleIDs}()},
\code{\link{sampleIndParamValues}()},
\code{\link{sampleRandomEffects}()},
\code{\link{sample_GPF}()},
\code{\link{select_FromGPF}()},
\code{\link{specifyParamSampling}()},
\code{\link{transformParamToNormal}()},
\code{\link{untransformParamFromNormal}()}

Other Parameter sampling: 
\code{\link{calcIndParamValues}()},
\code{\link{calcTypicalIndParamValues}()},
\code{\link{combineGPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{generate_GPFFromProjectInfo}()},
\code{\link{getCorMatrixUncertainty}()},
\code{\link{getCovMatrixIIV}()},
\code{\link{getCovMatrixUncertainty}()},
\code{\link{getNamesAllParameters}()},
\code{\link{getNamesCovariateParameters}()},
\code{\link{getNamesCovariates}()},
\code{\link{getNamesErrorParameters}()},
\code{\link{getNamesIIVCorrParameters}()},
\code{\link{getNamesIIVParameters}()},
\code{\link{getNamesModelParameters}()},
\code{\link{getParamEstimates}()},
\code{\link{getParamTransformationTypes}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{is_GPF}()},
\code{\link{is_IQRnlmeParamSpec}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sampleIDs}()},
\code{\link{sampleIndParamValues}()},
\code{\link{sampleRandomEffects}()},
\code{\link{sample_GPF}()},
\code{\link{select_FromGPF}()},
\code{\link{specifyParamSampling}()},
\code{\link{transformParamToNormal}()},
\code{\link{untransformParamFromNormal}()}
}
\author{
Venelin Mitov (IntiQuan)
}
\concept{Parameter sampling}
\keyword{internal}
