% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_param_sampling.R
\name{sampleRandomEffects}
\alias{sampleRandomEffects}
\title{Sample NLME random effects given population parameter values
describing the inter-individual variability distribution}
\usage{
sampleRandomEffects(
  spec,
  iivPopParamValues,
  Nsamples = if (is_IQRnlmeParamSpec(spec)) spec$Nsamples else 1
)
}
\arguments{
\item{spec}{a filename (character string) denoting the path to a GPF
excel file, or a GPF object, or an IQRnlmeParamSpec object.}

\item{iivPopParamValues}{a data.frame with population parameter values
describing the IIV distribution. The number of rows in this data.frame
defines the number of populations for which random effects are to be
sampled.}

\item{Nsamples}{integer denoting the number of individuals in a
population. Note: in the case of \code{FLAG_SAMPLE=2}, this value is used to specify
the number of populations (see \code{Npop}). Default:
\code{if(is_IQRnlmeParamSpec(obj)) obj$Nsamples else 1L}.}
}
\value{
a data.frame of \code{Nsamples*nrow(iivPopParamValues)} rows and
columns \code{ID.POP}, \code{ID} and a column for each model parameter
defined in \code{spec}.
}
\description{
Sample NLME random effects given population parameter values
describing the inter-individual variability distribution
}
\examples{
\dontrun{
#See the examples for sampleIndParamValues:
?sampleIndParamValues
}
}
\seealso{
\href{https://iqrtools.intiquan.com/doc/book/paramsampling.html}{Random sampling of NLME model parameters}

\href{https://iqrtools.intiquan.com/doc/book/GPF.html}{General Parameter Format}

Other Parameter sampling: 
\code{\link{calcIndParamValues}()},
\code{\link{calcTypicalIndParamValues}()},
\code{\link{combineGPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{generate_GPFFromProjectInfo}()},
\code{\link{getCorMatrixUncertainty}()},
\code{\link{getCovMatrixIIV}()},
\code{\link{getCovMatrixUncertainty}()},
\code{\link{getNamesAllParameters}()},
\code{\link{getNamesCovariateParameters}()},
\code{\link{getNamesCovariates}()},
\code{\link{getNamesErrorParameters}()},
\code{\link{getNamesIIVCorrParameters}()},
\code{\link{getNamesIIVParameters}()},
\code{\link{getNamesModelParameters}()},
\code{\link{getParamEstimates}()},
\code{\link{getParamTransformationTypes}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{is_GPF}()},
\code{\link{is_IQRnlmeParamSpec}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sampleIDs}()},
\code{\link{sampleIndParamValues}()},
\code{\link{sampleParamFromUncertainty}()},
\code{\link{sample_GPF}()},
\code{\link{select_FromGPF}()},
\code{\link{specifyParamSampling}()},
\code{\link{transformParamToNormal}()},
\code{\link{untransformParamFromNormal}()}
}
\author{
Venelin Mitov (IntiQuan)
}
\concept{Parameter sampling}
\keyword{internal}
