% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_param_sampling_2.R
\name{sample_GPF}
\alias{sample_GPF}
\title{Sample wrapper with syntax as sample_IQRnlmeProject for GPF excel files}
\usage{
sample_GPF(
  input,
  Nsamples = NULL,
  FLAG_SAMPLE = 0,
  covariates = NULL,
  FLAGid = FALSE,
  verbose = TRUE
)
}
\arguments{
\item{input}{a filename (character string) denoting the path to a GPF
excel file, or a GPF object.}

\item{Nsamples}{Number of samples to generate. If NULL number of samples is set equal
set to number of rows of covariates.}

\item{FLAG_SAMPLE}{Flag indicating the type of sampling:
\tabular{ll}{
FLAG_SAMPLE       \tab Meaning \cr
===========       \tab =================================================== \cr
0                 \tab Use point estimates of population parameters (do not consider uncertainty) and sample Nsample
individual patients based on these. Covariates considered if defined by user and used in model.
Please note: population parameters do not take covariates into account!\cr
1                 \tab Sample single set of population parameters from uncertainty distribution and sample Nsample
individual patient parameters based on these. Covariates considered if defined by user and
used in model. Please note: population parameters do not take covariates into account!\cr
3                 \tab Use point estimates of population parameters (do not consider uncertainty)
Return Nsamples sets of population parameters with covariates taken into account.\cr
4                 \tab Sample single set of population parameters from uncertainty distribution
Return Nsamples sets of population parameters with covariates taken into account.\cr
5                 \tab Should not be used by the normal user - used internally only. Use point estimates of population parameters (do not consider uncertainty) and sample Nsample
individual patients based on these. Covariates considered if defined by user and used in model.
Population parameters, typical individual parameters (no IIV, but considering covariates),
and individual parameters are returned.\cr
6                 \tab Should not be used by the normal user - used internally only. Sample single set of population parameters from uncertainty distribution and sample Nsample
individual patient parameters based on these. Covariates considered if defined by user and used in model.
Sampled population parameters, typical individual parameters (no IIV, but considering covariates),
and individual parameters are returned.\cr
}}

\item{covariates}{a data.frame describing individual sets of covariate values.
If nrow(data)==Nsamples, then all rows in data are returned (in their original order)
in the resulting data.frame; if nrow(data)>Nsamples, sampling without replacement from the
rows in data is done; if nrow(data)<Nsamples then sampling with replacement is done.}

\item{FLAGid}{If TRUE ID column is added to individual parameters (SAMPLE_FLAG = 0, 1, 5, 6, 7, 8) or population parameters
(SAMPLE_FLAG = 2, 3, 4). Otherwise only data frames with parameters only are returned (default).}

\item{verbose}{If TRUE then warnings are shown. If FALSE no warnings are shown but only errors.}
}
\value{
a named list with the following elements:
\describe{
\item{\verb{$FLAG_SAMPLE} : }{ Same as the argument }
\item{\verb{$Nsamples} : }{ Same as the argument }
\item{\verb{$covariatesSampled}: }{ A data.frame having \code{Nsample} rows representing sampled records from the provided covariates. }
\item{\verb{$popParamValues}: }{ A data.frame with columns for all population/typical individual parameter values, depending on the FLAG_SAMPLE settings (Values 2,3,4). }
\item{\verb{$typicalIndParamValues} : }{ A data.frame of \code{Nsample} rows corresponding to the typical individual parameter values, basedo on \code{popParamValues}
with taking into account the corresponding covariate values in \verb{$covariatesSampled} but no variability. Only populated for FLAG_SAMPLE 5 and 6. }
\item{\verb{$indParamValues} : }{ A data.frame with \code{Nsamples} rows containing the sampled individual parameter values in FLAG_SAMPLE cases for 0 and 1. }
}
}
\description{
Samples sets of population and / or individual parameters from an IQRnlmeProject.
Different sampling types can be specified (see below).
}
\seealso{
Other GPF: 
\code{\link{GPF}()},
\code{\link{addIIVCov_toGPF}()},
\code{\link{combineGPF}()},
\code{\link{export_GPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{generate_GPFFromProjectInfo}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{load_GPF}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{select_FromGPF}()}

Other Parameter sampling: 
\code{\link{calcIndParamValues}()},
\code{\link{calcTypicalIndParamValues}()},
\code{\link{combineGPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{generate_GPFFromProjectInfo}()},
\code{\link{getCorMatrixUncertainty}()},
\code{\link{getCovMatrixIIV}()},
\code{\link{getCovMatrixUncertainty}()},
\code{\link{getNamesAllParameters}()},
\code{\link{getNamesCovariateParameters}()},
\code{\link{getNamesCovariates}()},
\code{\link{getNamesErrorParameters}()},
\code{\link{getNamesIIVCorrParameters}()},
\code{\link{getNamesIIVParameters}()},
\code{\link{getNamesModelParameters}()},
\code{\link{getParamEstimates}()},
\code{\link{getParamTransformationTypes}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{is_GPF}()},
\code{\link{is_IQRnlmeParamSpec}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sampleIDs}()},
\code{\link{sampleIndParamValues}()},
\code{\link{sampleParamFromUncertainty}()},
\code{\link{sampleRandomEffects}()},
\code{\link{select_FromGPF}()},
\code{\link{specifyParamSampling}()},
\code{\link{transformParamToNormal}()},
\code{\link{untransformParamFromNormal}()}
}
\concept{GPF}
\concept{Parameter sampling}
