% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_classes_IQRnlmeProject.R
\name{sample_IQRnlmeProject}
\alias{sample_IQRnlmeProject}
\title{Samples parameters from an IQRnlmeProject}
\usage{
sample_IQRnlmeProject(
  input,
  Nsamples = NULL,
  FLAG_SAMPLE = 0,
  covariates = NULL,
  FLAGid = FALSE,
  verbose = TRUE
)
}
\arguments{
\item{input}{An IQRnlmeProject or a character string with the path
to an IQRnlmeProject folder.}

\item{Nsamples}{Number of samples to generate. If NULL number of samples is set equal
set to number of rows of covariates.}

\item{FLAG_SAMPLE}{Flag indicating the type of sampling:
\tabular{ll}{
FLAG_SAMPLE       \tab Meaning \cr
===========       \tab =================================================== \cr
0                 \tab Use point estimates of population parameters (do not consider uncertainty) and sample Nsample
individual patients based on these. Covariates considered if defined by user and used in model.
Please note: population parameters do not take covariates into account!\cr
1                 \tab Sample single set of population parameters from uncertainty distribution and sample Nsample
individual patient parameters based on these. Covariates considered if defined by user and used in model.
Please note: population parameters do not take covariates into account!\cr
2                 \tab Sample Nsample sets of population parameters from uncertainty distribution.
Do not sample from variability distribution and do not take into account covariates (even if user specified).\cr
3                 \tab Use point estimates of population parameters (do not consider uncertainty)
Return Nsamples sets of population parameters with covariates taken into account.\cr
4                 \tab Sample single set of population parameters from uncertainty distribution
Return Nsamples sets of population parameters with covariates taken into account.\cr
5                 \tab Use point estimates of population parameters (do not consider uncertainty) and sample Nsample
individual patients based on these. Covariates considered if defined by user and used in model.
Population parameters, typical individual parameters (no IIV, but considering covariates),
and individual parameters are returned.\cr
6                 \tab Sample single set of population parameters from uncertainty distribution and sample Nsample
individual patient parameters based on these. Covariates considered if defined by user and used in model.
Sampled population parameters, typical individual parameters (no IIV, but considering covariates),
and individual parameters are returned.\cr
7                 \tab Same as FLAG_SAMPLE=0 but obtaining the empirical random effect covariance matrix from the post-hoc ETAs.
Only used for IQRsysProject. If IQRnlmeProject then fallback to flag 0.\cr
8                 \tab Same as FLAG_SAMPLE=1 but obtaining the empirical random effect covariance matrix from the post-hoc ETAs.\cr
Only used for IQRsysProject. If IQRnlmeProject then fallback to flag 1.\cr
}}

\item{covariates}{Data frame or matrix. Column names need to contain names of the covariates.
If Nsamples is set (not NULL) then there are 3 cases: if covariates is a data.frame
wirh nrows as Nsamples then this is used as is. If nrows>Nsamples, sampling without replacement
from the covariates is done and if nrows<Nsamples then sampling from covariates with replacement
is done. Not all covariates that are used in the model
need to be present.}

\item{FLAGid}{If TRUE ID column is added to individual parameters (SAMPLE_FLAG = 0, 1, 5, or 6) or population parameters
(SAMPLE_FLAG = 2, 3, 4, 5, or 6). Otherwise only data frames with parameters only are returned (default).}

\item{verbose}{If TRUE then warnings are shown. If FALSE no warnings are shown but only errors.}
}
\value{
a named list with the following elements:
\describe{
\item{\verb{$FLAG_SAMPLE} : }{ Same as the argument }
\item{\verb{$Nsamples} : }{ Same as the argument }
\item{\verb{$covariatesSampled}: }{ A data.frame having \code{Nsample} rows representing sampled records from the provided covariates. }
\item{\verb{$popParamValues}: }{ A data.frame with columns for all population/typical individual parameter values, depending on the FLAG_SAMPLE settings (Values 2,3,4). }
\item{\verb{$typicalIndParamValues} : }{ A data.frame of \code{Nsample} rows corresponding to the typical individual parameter values, basedo on \code{popParamValues}
with taking into account the corresponding covariate values in \verb{$covariatesSampled} but no variability. Only populated for FLAG_SAMPLE 5 and 6. }
\item{\verb{$indParamValues} : }{ A data.frame with \code{Nsamples} rows containing the sampled individual parameter values in FLAG_SAMPLE cases for 0,1,7,8. }
}
}
\description{
Samples sets of population and / or individual parameters from an IQRnlmeProject.
Different sampling types can be specified (see below).
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{compareModels_IQRnlmeProjectMulti}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{scm_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}
}
\concept{IQRnlmeProject}
