% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_tools_scm.R
\name{scm_IQRnlmeProject}
\alias{scm_IQRnlmeProject}
\title{Perform a stepwise covariate modeling (SCM)}
\usage{
scm_IQRnlmeProject(
  projectPath,
  out_dir,
  relations,
  p_lev = 0.01,
  pp_fun = NULL,
  verbose = TRUE,
  clean = TRUE,
  gof = FALSE,
  Nparallel = 1,
  nlme = TRUE,
  ...
)
}
\arguments{
\item{projectPath}{The directory of the IQR model to be used for the reference}

\item{out_dir}{The directory to be used for the SCM outputs}

\item{relations}{A tibble with the following mandatory columns: \code{cov} for the
covariate name, \code{prm} for the parameter name, \code{cont} a TRUE/FALSE flag to
indicate wether the covariate is continuous.An optional column \code{value} can
be provided to set the intial estimate for the covariate effect, if not
provided 0.01 will be used instead.
OFV.}

\item{p_lev}{The significance level to use for the covariate selection.
Should be a number between 0 and 1.}

\item{pp_fun}{A post processing function for the model repository. This
function should only have a single argument. The input to this function
will be the the path to a model directory.}

\item{verbose}{A logical flag indicating wether informative messages should
be printed to the console}

\item{clean}{A logical flag indicating wether the scm process cleanup the
provided \code{dir} upon start.}

\item{gof}{Logical flag indicating whether GOF plots should be produced or not (default is \code{FALSE}).}

\item{Nparallel}{The number of models run in parallel (default is 1).}

\item{nlme}{TRUE for NONMEM/MONOLIX, or FALSE for SYSFIT.}

\item{...}{Options to be passed to the IQRnlmeProject function (e.g. K1, K2). Currently only the tool,
the toolversion, and the estimation method are automatically applied from the original run. If specific
settings were used in the original run it is best to re-redefine them here.}
}
\description{
Perform a stepwise covariate modeling (SCM). Note currently only
the forward inclusion is implemented (i.e. no backward deletion)
}
\examples{
\dontrun{
# Creating the relation object
relations <- tidyr::crossing(
  cov = c("AGE", "WTKG", "RACE", "SEXF"),
  prm = c("CL", "VC")
) \%>\%
  arrange(prm, cov) \%>\%
  mutate(cont = ifelse(cov \%in\% c("AGE", "WTKG"), TRUE, FALSE))

# Running the SCM
scm_IQRnlmeProject(
  projectPath = "../Models/01_base_model/",
  out_dir = "../Models/02_covariate_selection",
  relations = relations,
  p_lev = 0.05,
  nlme = "NONMEM"
)
}
}
\seealso{
Other IQRnlmeProject: 
\code{\link{IQRnlmeEst}()},
\code{\link{IQRnlmeProject}()},
\code{\link{addCovariateToModelSpec_IQRest}()},
\code{\link{addPar_modelSpec}()},
\code{\link{as_IQRnlmeProjectMulti}()},
\code{\link{as_IQRnlmeProject}()},
\code{\link{bootstrap_IQRnlmeProject}()},
\code{\link{compareModels_IQRnlmeProjectMulti}()},
\code{\link{convertETAINDIVPRED_IQRnlmeProject}()},
\code{\link{covariateEffect_IQRnlmeProject}()},
\code{\link{data_IQRest}()},
\code{\link{dosing_IQRest}()},
\code{\link{duplicate_IQRnlmeProject}()},
\code{\link{eigenvalues_IQRnlmeProject}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{getData_IQRnlmeProject}()},
\code{\link{getETAs_IQRnlmeProject}()},
\code{\link{getEst_IQRnlmeProject}()},
\code{\link{getHeader_IQRnlmeProject}()},
\code{\link{getIndivParameters_IQRnlmeProject}()},
\code{\link{getIndivPredictions_IQRnlmeProject}()},
\code{\link{getModel_IQRnlmeProject}()},
\code{\link{getObsPred_IQRnlmeProject}()},
\code{\link{getPopParameters_IQRnlmeProject}()},
\code{\link{getResults_IQRnlmeProjectMulti}()},
\code{\link{getResults_IQRnlmeProject}()},
\code{\link{hasrun_IQRnlmeProjectMulti}()},
\code{\link{hasrun_IQRnlmeProject}()},
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{is_IQRnlmeEst}()},
\code{\link{is_IQRnlmeProjectMulti}()},
\code{\link{is_IQRnlmeProject}()},
\code{\link{is_MONOLIX_IQRnlmeProject}()},
\code{\link{is_NLMIXR_IQRnlmeProject}()},
\code{\link{is_NONMEM_IQRnlmeProject}()},
\code{\link{modelSpec_IQRest}()},
\code{\link{outlier_IQRnlmeProject}()},
\code{\link{plot.IQRnlmeProjectMulti}()},
\code{\link{plot.IQRnlmeProject}()},
\code{\link{plotBLQVPC_IQRdataVPC}()},
\code{\link{plotConvergence_IQRnlmeProject}()},
\code{\link{plotETACOV_IQRnlmeProject}()},
\code{\link{plotETA_IQRnlmeProject}()},
\code{\link{plotGOF_IQRnlmeProject}()},
\code{\link{plotINDIVSIM_IQRnlmeProject}()},
\code{\link{plotINDIV_IQRnlmeProject}()},
\code{\link{plotVPC_IQRdataVPC}()},
\code{\link{pred_IQRnlmeProject}()},
\code{\link{print.IQRnlmeEst}()},
\code{\link{print.IQRnlmeProjectMulti}()},
\code{\link{print.IQRnlmeProject}()},
\code{\link{print_modelSpec}()},
\code{\link{run_IQRnlmeProjectMulti}()},
\code{\link{run_IQRnlmeProject}()},
\code{\link{sample_IQRnlmeProject}()},
\code{\link{summary.IQRnlmeProjectMulti}()},
\code{\link{summary.IQRnlmeProject}()},
\code{\link{summaryComments_IQRnlmeProjectMulti}()},
\code{\link{summaryCorrelations_IQRnlmeProjectMulti}()},
\code{\link{summaryCovariates_IQRnlmeProjectMulti}()},
\code{\link{summaryParameters_IQRnlmeProjectMulti}()},
\code{\link{vpc_IQRnlmeProject}()}
}
\author{
Benjamin Guiastrennec, IntiQuan GmbH
}
\concept{IQRnlmeProject}
