% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_param_sampling.R
\name{select_FromGPF}
\alias{select_FromGPF}
\title{Select and, optionally, rename parameters and covariates in a GPF}
\usage{
select_FromGPF(
  obj,
  parameters = NULL,
  covariates = NULL,
  FLAGdropErrParameters = TRUE,
  filename = NULL
)
}
\arguments{
\item{obj}{a \link{GPF} object, or a filepath, or a IQRnlmeProject directory, from which a GPF object can be loaded or generated.
If not a GPF object, the constructor \link{GPF} will be called.}

\item{parameters}{a (possibly named) character vector denoting model parameters to be selected. If NULL (default),
all model parameters are selected.}

\item{covariates}{a (possibly named) character vector.}

\item{FLAGdropErrParameters}{Logical (default TRUE), indicating whether to drop error parameters such as "error_PROP1"}

\item{filename}{Character filename (default NULL) where the resulting GPF object can (optionally) be saved.}
}
\value{
A \link{GPF} object.
}
\description{
Select and, optionally, rename parameters and covariates in a GPF
}
\examples{
\dontrun{
GPF_A_PD <- select_FromGPF(
  "../03-Models/A/PD/GPF_A_PD.xlsx",
  parameters = c("EC50xA"="EC50",
                 "EMAXxA"="EMAX",
                 "hillxA"="hill")
)
}
}
\seealso{
\href{https://iqrtools.intiquan.com/doc/book/GPF.html}{General Parameter Format}

Other Parameter sampling: 
\code{\link{calcIndParamValues}()},
\code{\link{calcTypicalIndParamValues}()},
\code{\link{combineGPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{generate_GPFFromProjectInfo}()},
\code{\link{getCorMatrixUncertainty}()},
\code{\link{getCovMatrixIIV}()},
\code{\link{getCovMatrixUncertainty}()},
\code{\link{getNamesAllParameters}()},
\code{\link{getNamesCovariateParameters}()},
\code{\link{getNamesCovariates}()},
\code{\link{getNamesErrorParameters}()},
\code{\link{getNamesIIVCorrParameters}()},
\code{\link{getNamesIIVParameters}()},
\code{\link{getNamesModelParameters}()},
\code{\link{getParamEstimates}()},
\code{\link{getParamTransformationTypes}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{is_GPF}()},
\code{\link{is_IQRnlmeParamSpec}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sampleIDs}()},
\code{\link{sampleIndParamValues}()},
\code{\link{sampleParamFromUncertainty}()},
\code{\link{sampleRandomEffects}()},
\code{\link{sample_GPF}()},
\code{\link{specifyParamSampling}()},
\code{\link{transformParamToNormal}()},
\code{\link{untransformParamFromNormal}()}

Other GPF: 
\code{\link{GPF}()},
\code{\link{addIIVCov_toGPF}()},
\code{\link{combineGPF}()},
\code{\link{export_GPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{generate_GPFFromProjectInfo}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{load_GPF}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sample_GPF}()}
}
\author{
Venelin Mitov (IntiQuan)
}
\concept{GPF}
\concept{Parameter sampling}
