% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qsp_functions_IQRmodel.R
\name{sensitivity_IQRmodel}
\alias{sensitivity_IQRmodel}
\title{Local parameter sensitivity analysis}
\usage{
sensitivity_IQRmodel(
  model,
  simtime,
  dosingTable = NULL,
  sensparams = NULL,
  sensoutput = NULL,
  sensmetricFct = NULL,
  sensopt.abspert = NULL,
  sensopt.relpert = 0.01,
  title = NULL,
  orderAlpha = FALSE,
  plotTrajectories = FALSE
)
}
\arguments{
\item{model}{IQRmodel to perform the sensitivity analysis for}

\item{simtime}{Simulation time vector to use for the analysis.It can also be provided as a list
of simulation time vectors. In the latter case the same number as list entries of dosingTable elements
need to be provided. The different simtime vectors will then be used for the different dosingTable elements
in the order as defined.}

\item{dosingTable}{Single IQRdosing object defining the dosing to apply to the model during sensitivity analysis.
dosingTable can also be a list of IQRdosing objects that all will be simulated and results concatenated.}

\item{sensparams}{Vector of parameter names in the IQRmodel to perform the sensitivity analysis for. Default:
all parameters in the model.}

\item{sensoutput}{Vector of element names (states, variables, reactions) in the IQRmodel to consider during
the sensitivity analysis. Default: all OUTPUT variables in the model. If no OUTPUT elements present then
an error is produced.}

\item{sensmetricFct}{Function defining a custom sensitivity metric according to the syntax define in Details.}

\item{sensopt.abspert}{Default relative perturbation work well for non-zero nominal parameters. To allow to also
determine sensitivity to parameters with 0 nominal value this argument takes a named vector. Names should be parameter
names in the model and the value is the desired perturbation in absolute terms. Absolute perturbations can also
be used on non-zero parameters and if done the absolute perturbation and the relative perturbation both will be done.}

\item{sensopt.relpert}{All parameters are perturbed using relative perturbations of 0.01 times the nominal value.}

\item{title}{Character string defining a custom title for the returned sensitivity analysis results plot.}

\item{orderAlpha}{Logical. If TRUE the parameters in the results are ordered alphabetically. Otherwise by
decreasing sensitivity value.}

\item{plotTrajectories}{Logical, defining if trajectories to be plotted for visual inspection of results.}
}
\value{
List with elements "plot" and "sensitivity". Plot is a ggplot2 object containing the plot itself. sensitivity
is a data.frame containing parameter names and sensitivity values.
}
\description{
This function allows to assess the local sensitivity of model outputs with respect to
changes in parameters and represents the results graphically and returns a data.frame
with the calculate sensitivity metric values. A default sensitivity metric is implemented
but the user can provide own sensitivity metrics to assess specific things (example:
time to maximum value, maximum value, steady-state/baseline value, oscillation frequency, ... whatever.)
Local here means based on the parameterization within the IQRmodel.
}
\details{
A custom sensitivity metric can be provided through definition of a function with the following
input arguments: p_nom,p_pert,y_nom,y_pert. Where p_nom is the nominal parameter value,
p_pert the perturbed one. y_nom is a data.frame the following columns: TIME, DOSING, NAME, VALUE.
NAME contains the name of the simulated output, VALUE contains the simulated value under
nominal parameter conditions, TIME contains the TIME of the simulated point. y_pert contains
the same information as y_nom but for perturbed parammeter conditions. The output of the custom
sensitivity metric function needs to be a scalar numeric value that defines the sensitivity
metric to be used. This sensitivity metric function is called by sensitivity_IQRmodel for
all parameters in sensparams.

The default sensitivity metric calculates normalized sensitivities for each observed timepoint across
all observed outputs. Since this results in signed vectors, the mean of the absolute values of the
normalized sensitivities is used as a metric, resulting in an always positive metric that can only
be used to assess sensitivity of all outputs together to a parameter but not be used to assess
directionality of the sensitivity.
}
\seealso{
Other IQRmodel: 
\code{\link{IQRmodel}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{exportSBML_IQRmodel}()},
\code{\link{exportVariant_IQRmodel}()},
\code{\link{export_IQRmodel}()},
\code{\link{getPars_IQRmodel}()},
\code{\link{hasCcodeFunctions_IQRmodel}()},
\code{\link{hasInitialAssignments_IQRmodel}()},
\code{\link{importSBML_IQRmodel}()},
\code{\link{importVariant_IQRmodel}()},
\code{\link{is_IQRmodel}()},
\code{\link{new_IQRmodel}()},
\code{\link{print.IQRmodel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{regenerate_IQRmodel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{setParameters_IQRmodel}()},
\code{\link{setPars_IQRmodel}()},
\code{\link{sim_IQRmodel}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{simbio_updateParamIC_IQRmodel}()},
\code{\link{stoichiometry_IQRmodel}()},
\code{\link{strReplace_IQRmodel}()}

Other QSP: 
\code{\link{IQRsysEst}()},
\code{\link{IQRsysModel}()},
\code{\link{IQRsysProject}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{as_IQRsysEst}()},
\code{\link{as_IQRsysProjectMulti}()},
\code{\link{as_IQRsysProject}()},
\code{\link{comparePars_IQRsysModel}()},
\code{\link{duplicate_IQRsysProject}()},
\code{\link{exportVariant_IQRmodel}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{export_IQRsysData}()},
\code{\link{getDosing_IQRsysModel}()},
\code{\link{getEmpiricalETACovarianceMatrix_IQRsysProject}()},
\code{\link{getOptTrace_IQRsysProject}()},
\code{\link{getPars_IQRoptTrace}()},
\code{\link{getPars_IQRsysModel}()},
\code{\link{getPrediction_IQRsysModel}()},
\code{\link{hasrun_IQRsysProject}()},
\code{\link{importVariant_IQRmodel}()},
\code{\link{import_IQRsysData}()},
\code{\link{is_IQRsysEst}()},
\code{\link{is_IQRsysModel}()},
\code{\link{is_IQRsysProjectMulti}()},
\code{\link{is_IQRsysProject}()},
\code{\link{load_IQRsysProject}()},
\code{\link{modelSpec_IQRsysEst}()},
\code{\link{model_IQRsysModel}()},
\code{\link{offsetTIME_IQRsysData}()},
\code{\link{plotDVPRED_IQRsysModel}()},
\code{\link{plotFit_IQRsysModel}()},
\code{\link{plotPars_IQRsysModel}()},
\code{\link{plotPred_IQRsysModel}()},
\code{\link{plotProfile_IQRsysModel}()},
\code{\link{plotWRES_IQRsysModel}()},
\code{\link{plotWaterfall_IQRsysModel}()},
\code{\link{plot_IQRoptTrace}()},
\code{\link{plot_IQRsysModel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{print.IQRsysProject}()},
\code{\link{profile_IQRsysModel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{run_IQRsysProjectMulti}()},
\code{\link{run_IQRsysProject}()},
\code{\link{sample_IQRsysModel}()},
\code{\link{setPars_IQRsysModel}()},
\code{\link{sim_IQRsysModel}()},
\code{\link{sim_IQRvirtualSubjects}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{simbio_updateParamIC_IQRmodel}()},
\code{\link{spmIIV_IQRsysProject}()},
\code{\link{spm_IQRsysProject}()},
\code{\link{switchOpt_IQRsysModel}()},
\code{\link{tablePars_IQRsysModel}()}

Other Sensitivity Analysis: 
\code{\link{informationContent_IQRnlmeProject}()},
\code{\link{print.IQRsensitivity}()}
}
\author{
Henning Schmidt, IntiQuan
}
\concept{IQRmodel}
\concept{QSP}
\concept{Sensitivity Analysis}
