% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dMod_classes_IQRsysModel.R
\name{sim_IQRsysModel}
\alias{sim_IQRsysModel}
\title{Simulate IQRsysModel}
\usage{
sim_IQRsysModel(
  sysModel,
  simtime = NULL,
  parameters = NULL,
  FLAGoutputsOnly = TRUE,
  FLAGverbose = FALSE,
  SIMOPT.method = NULL,
  SIMOPT.atol = NULL,
  SIMOPT.rtol = NULL,
  SIMOPT.hmin = NULL,
  SIMOPT.hmax = NULL,
  SIMOPT.hini = NULL,
  SIMOPT.maxsteps = NULL,
  SIMOPT.nauxtimes = NULL
)
}
\arguments{
\item{sysModel}{\link{IQRsysModel} object.}

\item{simtime}{numeric vector of desired simulation times.}

\item{parameters}{named vector of parameter values. Any parameter which is not explicitly
provided is set according to the model parameters (see output of \link{getPars_IQRsysModel}).}

\item{FLAGoutputsOnly}{by default, only outputs are returned. If \code{FALSE}, ODE states
and outputs are returned.}

\item{FLAGverbose}{Logical. Print parameters table to console?}

\item{SIMOPT.method}{character denoting the integration method, e.g. "lsodes" (default), "lsoda"
See the deSolve package for a list of available integrators}

\item{SIMOPT.atol}{numeric, absolute error tolerance}

\item{SIMOPT.rtol}{numeric, relative error tolerance}

\item{SIMOPT.hmin}{numeric, minimal integration step size}

\item{SIMOPT.hmax}{numeric, maximal integration step size}

\item{SIMOPT.hini}{numeric, initial integration step size}

\item{SIMOPT.maxsteps}{numeric, maximum number of integration steps}

\item{SIMOPT.nauxtimes}{additional times to simulate the prediction function}
}
\value{
The simulation is added to sysModel as list entry \code{prediction} and sysModel is returned.
}
\description{
Allow the simulation of an IQRsysModel for user defined settings. Note that the IQRsysModel
object is optimized for parameter estimation purposes. As such it is not intended to simulate
user desired dosing schedules - but only the dosing schedules that are defined in the dataset
to be used for estimation. As such the main model settings that can be accessed in sim_IQRsysModel()
are the model parameters to allow the user to play with parameter values - for a sensitivity analysis
or to manually modify parameters in the search for reasonable initial guesses.
The output of sim_IQRsysModel() is an IQRsysModel with updated parameters (if changed) and
updated predictions list field that contains the simulations. Results can be displayed using
plot_IQRsysModel().
}
\seealso{
Other QSP: 
\code{\link{IQRsysEst}()},
\code{\link{IQRsysModel}()},
\code{\link{IQRsysProject}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{as_IQRsysEst}()},
\code{\link{as_IQRsysProjectMulti}()},
\code{\link{as_IQRsysProject}()},
\code{\link{comparePars_IQRsysModel}()},
\code{\link{duplicate_IQRsysProject}()},
\code{\link{exportVariant_IQRmodel}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{export_IQRsysData}()},
\code{\link{getDosing_IQRsysModel}()},
\code{\link{getEmpiricalETACovarianceMatrix_IQRsysProject}()},
\code{\link{getOptTrace_IQRsysProject}()},
\code{\link{getPars_IQRoptTrace}()},
\code{\link{getPars_IQRsysModel}()},
\code{\link{getPrediction_IQRsysModel}()},
\code{\link{hasrun_IQRsysProject}()},
\code{\link{importVariant_IQRmodel}()},
\code{\link{import_IQRsysData}()},
\code{\link{is_IQRsysEst}()},
\code{\link{is_IQRsysModel}()},
\code{\link{is_IQRsysProjectMulti}()},
\code{\link{is_IQRsysProject}()},
\code{\link{load_IQRsysProject}()},
\code{\link{modelSpec_IQRsysEst}()},
\code{\link{model_IQRsysModel}()},
\code{\link{offsetTIME_IQRsysData}()},
\code{\link{plotDVPRED_IQRsysModel}()},
\code{\link{plotFit_IQRsysModel}()},
\code{\link{plotPars_IQRsysModel}()},
\code{\link{plotPred_IQRsysModel}()},
\code{\link{plotProfile_IQRsysModel}()},
\code{\link{plotWRES_IQRsysModel}()},
\code{\link{plotWaterfall_IQRsysModel}()},
\code{\link{plot_IQRoptTrace}()},
\code{\link{plot_IQRsysModel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{print.IQRsysProject}()},
\code{\link{profile_IQRsysModel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{run_IQRsysProjectMulti}()},
\code{\link{run_IQRsysProject}()},
\code{\link{sample_IQRsysModel}()},
\code{\link{sensitivity_IQRmodel}()},
\code{\link{setPars_IQRsysModel}()},
\code{\link{sim_IQRvirtualSubjects}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{simbio_updateParamIC_IQRmodel}()},
\code{\link{spmIIV_IQRsysProject}()},
\code{\link{spm_IQRsysProject}()},
\code{\link{switchOpt_IQRsysModel}()},
\code{\link{tablePars_IQRsysModel}()}
}
\author{
Daniel Kaschek, IntiQuan GmbH
}
\concept{QSP}
