% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qsp_simbio.R
\name{simbio_updateParamIC_IQRmodel}
\alias{simbio_updateParamIC_IQRmodel}
\title{Return model with updated parameters and initial conditions defined in a CSV file}
\usage{
simbio_updateParamIC_IQRmodel(model, filename)
}
\arguments{
\item{model}{IQRmodel to update}

\item{filename}{Path to a CSV file that contains at least 2 "columns".
The first contains the name of an element, the second contains the value
of the element.}
}
\value{
Updated IQRmodel based on information in the CSV file
}
\description{
This function loads a CSV file that should have at least 2 columns. The first
column contains element names, the second element values. These elements can be
pretty much anything but ideally they contain names of states or parameters in the
provided model. If a match can be made, for states the initial condition and for
parameters the value is set to the value defined in the second column. An updated
model is returned.
}
\details{
For handling the weird Simbiology syntax "compartmentName."
this "compartmentName." is removed before attempting the matching.
}
\seealso{
Other IQRmodel: 
\code{\link{IQRmodel}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{exportSBML_IQRmodel}()},
\code{\link{exportVariant_IQRmodel}()},
\code{\link{export_IQRmodel}()},
\code{\link{getPars_IQRmodel}()},
\code{\link{hasCcodeFunctions_IQRmodel}()},
\code{\link{hasInitialAssignments_IQRmodel}()},
\code{\link{importSBML_IQRmodel}()},
\code{\link{importVariant_IQRmodel}()},
\code{\link{is_IQRmodel}()},
\code{\link{new_IQRmodel}()},
\code{\link{print.IQRmodel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{regenerate_IQRmodel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{sensitivity_IQRmodel}()},
\code{\link{setParameters_IQRmodel}()},
\code{\link{setPars_IQRmodel}()},
\code{\link{sim_IQRmodel}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{stoichiometry_IQRmodel}()},
\code{\link{strReplace_IQRmodel}()}

Other QSP: 
\code{\link{IQRsysEst}()},
\code{\link{IQRsysModel}()},
\code{\link{IQRsysProject}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{as_IQRsysEst}()},
\code{\link{as_IQRsysProjectMulti}()},
\code{\link{as_IQRsysProject}()},
\code{\link{comparePars_IQRsysModel}()},
\code{\link{duplicate_IQRsysProject}()},
\code{\link{exportVariant_IQRmodel}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{export_IQRsysData}()},
\code{\link{getDosing_IQRsysModel}()},
\code{\link{getEmpiricalETACovarianceMatrix_IQRsysProject}()},
\code{\link{getOptTrace_IQRsysProject}()},
\code{\link{getPars_IQRoptTrace}()},
\code{\link{getPars_IQRsysModel}()},
\code{\link{getPrediction_IQRsysModel}()},
\code{\link{hasrun_IQRsysProject}()},
\code{\link{importVariant_IQRmodel}()},
\code{\link{import_IQRsysData}()},
\code{\link{is_IQRsysEst}()},
\code{\link{is_IQRsysModel}()},
\code{\link{is_IQRsysProjectMulti}()},
\code{\link{is_IQRsysProject}()},
\code{\link{load_IQRsysProject}()},
\code{\link{modelSpec_IQRsysEst}()},
\code{\link{model_IQRsysModel}()},
\code{\link{offsetTIME_IQRsysData}()},
\code{\link{plotDVPRED_IQRsysModel}()},
\code{\link{plotFit_IQRsysModel}()},
\code{\link{plotPars_IQRsysModel}()},
\code{\link{plotPred_IQRsysModel}()},
\code{\link{plotProfile_IQRsysModel}()},
\code{\link{plotWRES_IQRsysModel}()},
\code{\link{plotWaterfall_IQRsysModel}()},
\code{\link{plot_IQRoptTrace}()},
\code{\link{plot_IQRsysModel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{print.IQRsysProject}()},
\code{\link{profile_IQRsysModel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{run_IQRsysProjectMulti}()},
\code{\link{run_IQRsysProject}()},
\code{\link{sample_IQRsysModel}()},
\code{\link{sensitivity_IQRmodel}()},
\code{\link{setPars_IQRsysModel}()},
\code{\link{sim_IQRsysModel}()},
\code{\link{sim_IQRvirtualSubjects}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{spmIIV_IQRsysProject}()},
\code{\link{spm_IQRsysProject}()},
\code{\link{switchOpt_IQRsysModel}()},
\code{\link{tablePars_IQRsysModel}()}
}
\concept{IQRmodel}
\concept{QSP}
