% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nlme_param_sampling.R
\name{specifyParamSampling}
\alias{specifyParamSampling}
\title{Create an IQRnlmeParamSpec object}
\usage{
specifyParamSampling(
  obj,
  Nsamples = if (is_IQRnlmeParamSpec(obj)) obj$Nsamples else 1L,
  Npop = if (is_IQRnlmeParamSpec(obj)) obj$Npop else if (FLAG_SAMPLE == 2) Nsamples else
    1L,
  FLAG_SAMPLE = 0,
  data = NULL
)
}
\arguments{
\item{obj}{a filename (character string) denoting the path to a GPF
file, or a GPF object, or an IQRnlmeParamSpec object. If an
IQRnlmeParamSpec object, a copy of this object is returned with updated values of the
arguments.}

\item{Nsamples}{an integer specifying the number of sampled individuals
(individual parameter sets) per one sampled set of population parameter values.
Default: \code{if(is_IQRnlmeParamSpec(obj)) obj$Nsamples else 1L}.}

\item{Npop}{an integer specifying the number of sampled sets of population parameter
values. Default:
\code{if(is_IQRnlmeParamSpec(obj)) obj$Npop else if(FLAG_SAMPLE==2) Nsamples else 1L}.}

\item{FLAG_SAMPLE}{an integer flag used for setting default values for \code{Npop} and \code{Nsamples}.
See \code{\link{sampleIndParamValues}} for possible values. Note that the value passed
here will be overwritten by the default or user-specified value passed in
\code{\link{sampleIndParamValues}}. Default: \code{0}.}

\item{data}{a data.frame with covariate data. Default: \code{NULL}.}
}
\value{
an object of S3 class IQRnlmeParamSpec.
}
\description{
An IQRnlmeParamSpec represents a named list with
elements describing the model parameter estimates, the uncertainty distribution,
the inter-individual variability distribution the covariate information, and the
residual error. Objects of this class are should not be created, read or manipulated
"by hand"; their only meaningful purpose is to be passed an argument
spec of sampleParam* functions.
}
\examples{
\dontrun{
#See the examples for sampleIndParamValues:
?sampleIndParamValues
}#'

}
\seealso{
\href{https://iqrtools.intiquan.com/doc/book/paramsampling.html}{Random sampling of NLME model parameters}

\href{https://iqrtools.intiquan.com/doc/book/GPF.html}{General Parameter Format}

Other Parameter sampling: 
\code{\link{calcIndParamValues}()},
\code{\link{calcTypicalIndParamValues}()},
\code{\link{combineGPF}()},
\code{\link{generate_GPFFromIQRnlmeEst}()},
\code{\link{generate_GPFFromIQRnlmeProject}()},
\code{\link{generate_GPFFromProjectInfoList}()},
\code{\link{generate_GPFFromProjectInfo}()},
\code{\link{getCorMatrixUncertainty}()},
\code{\link{getCovMatrixIIV}()},
\code{\link{getCovMatrixUncertainty}()},
\code{\link{getNamesAllParameters}()},
\code{\link{getNamesCovariateParameters}()},
\code{\link{getNamesCovariates}()},
\code{\link{getNamesErrorParameters}()},
\code{\link{getNamesIIVCorrParameters}()},
\code{\link{getNamesIIVParameters}()},
\code{\link{getNamesModelParameters}()},
\code{\link{getParamEstimates}()},
\code{\link{getParamTransformationTypes}()},
\code{\link{imputeTYPEcol_GPF}()},
\code{\link{is_GPF}()},
\code{\link{is_IQRnlmeParamSpec}()},
\code{\link{read_GPFFromCSV}()},
\code{\link{read_GPFFromXLS}()},
\code{\link{sampleIDs}()},
\code{\link{sampleIndParamValues}()},
\code{\link{sampleParamFromUncertainty}()},
\code{\link{sampleRandomEffects}()},
\code{\link{sample_GPF}()},
\code{\link{select_FromGPF}()},
\code{\link{transformParamToNormal}()},
\code{\link{untransformParamFromNormal}()}
}
\author{
Venelin Mitov (IntiQuan)
}
\concept{Parameter sampling}
\keyword{internal}
