% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qsp_tools_SPM.R
\name{spm_IQRsysProject}
\alias{spm_IQRsysProject}
\title{Stepwise Parameter Modeling for QSP - fixed effects}
\usage{
spm_IQRsysProject(
  path,
  model,
  dosing,
  data,
  SPM_POPvalues0,
  POPvalues0 = NULL,
  errorModel = NULL,
  ncores = 1,
  Nparallel = 1,
  RSEmax = 50,
  RSEmaxRemove = 100,
  FLAGclean = TRUE,
  SIMOPT.nauxtimes = 0,
  SIMOPT.hmax = NULL,
  SIMOPT.atol = 1e-06,
  SIMOPT.rtol = 1e-06
)
}
\arguments{
\item{path}{Path to where to store all the models in all the iterations}

\item{model}{IQRmodel object to use}

\item{dosing}{See dosing_IQRest}

\item{data}{See data_IQRest}

\item{SPM_POPvalues0}{Named vector with parameter names and values to test}

\item{POPvalues0}{Named vector with parameter names and values to always have in the model}

\item{errorModel}{See modelSpec_IQRsysEst}

\item{ncores}{Number of cores for a single model run}

\item{Nparallel}{Number of models to run in parallel}

\item{RSEmax}{If all RSEs in an iteration above this value, the algorithm stops}

\item{RSEmaxRemove}{If RSE for parameter above this value, the parameter is not considered further in the next iteration}

\item{FLAGclean}{If TRUE then all models are removed, keeping only the table result files - saves a
lot of diskspace!}

\item{SIMOPT.nauxtimes}{Number of additional auxiliary times for integrator}

\item{SIMOPT.hmax}{Maximum stepsize of the integrator. Passed to IQRsysProject. Set if
experiencing numerical issues with TIME offsets in the dataset.}

\item{SIMOPT.atol}{Absolute error tolerance for integrator}

\item{SIMOPT.rtol}{Relative error tolerance for integrator}
}
\value{
Results are displayed in the console and a list is returned with a table and a
vector with parameters and values identified. In addition in the path and in each
iteration folder a table with information is exported.
}
\description{
Supports identification of fixed effects to consider in the estimation.
The algorithm is based on identifiability of a parameter, given the available data.
Parameters of interest are defined and included one by one. Estimation is performed
and parameters to be kept in the next iteration are selected by the smallest RSE.
If RSE for a parameter in an iteration is > RSEmaxRemove then it is not considered
further in the next iteration. If all remaining parameters have RSE>RSEmax then
the algorithm stops. No IIV in this approach! Currently limited to positive
parameters only.
}
\seealso{
Other QSP: 
\code{\link{IQRsysEst}()},
\code{\link{IQRsysModel}()},
\code{\link{IQRsysProject}()},
\code{\link{addOutputs_IQRmodel}()},
\code{\link{addRelations_IQRmodel}()},
\code{\link{as_IQRsysEst}()},
\code{\link{as_IQRsysProjectMulti}()},
\code{\link{as_IQRsysProject}()},
\code{\link{comparePars_IQRsysModel}()},
\code{\link{duplicate_IQRsysProject}()},
\code{\link{exportVariant_IQRmodel}()},
\code{\link{exportVirtualSubjects_IQRnlmeProject}()},
\code{\link{export_IQRsysData}()},
\code{\link{getDosing_IQRsysModel}()},
\code{\link{getEmpiricalETACovarianceMatrix_IQRsysProject}()},
\code{\link{getOptTrace_IQRsysProject}()},
\code{\link{getPars_IQRoptTrace}()},
\code{\link{getPars_IQRsysModel}()},
\code{\link{getPrediction_IQRsysModel}()},
\code{\link{hasrun_IQRsysProject}()},
\code{\link{importVariant_IQRmodel}()},
\code{\link{import_IQRsysData}()},
\code{\link{is_IQRsysEst}()},
\code{\link{is_IQRsysModel}()},
\code{\link{is_IQRsysProjectMulti}()},
\code{\link{is_IQRsysProject}()},
\code{\link{load_IQRsysProject}()},
\code{\link{modelSpec_IQRsysEst}()},
\code{\link{model_IQRsysModel}()},
\code{\link{offsetTIME_IQRsysData}()},
\code{\link{plotDVPRED_IQRsysModel}()},
\code{\link{plotFit_IQRsysModel}()},
\code{\link{plotPars_IQRsysModel}()},
\code{\link{plotPred_IQRsysModel}()},
\code{\link{plotProfile_IQRsysModel}()},
\code{\link{plotWRES_IQRsysModel}()},
\code{\link{plotWaterfall_IQRsysModel}()},
\code{\link{plot_IQRoptTrace}()},
\code{\link{plot_IQRsysModel}()},
\code{\link{print.IQRsensitivity}()},
\code{\link{print.IQRsysProject}()},
\code{\link{profile_IQRsysModel}()},
\code{\link{replaceTerms_IQRmodel}()},
\code{\link{run_IQRsysProjectMulti}()},
\code{\link{run_IQRsysProject}()},
\code{\link{sample_IQRsysModel}()},
\code{\link{sensitivity_IQRmodel}()},
\code{\link{setPars_IQRsysModel}()},
\code{\link{sim_IQRsysModel}()},
\code{\link{sim_IQRvirtualSubjects}()},
\code{\link{simbio_CSV2namedVector}()},
\code{\link{simbio_updateParamIC_IQRmodel}()},
\code{\link{spmIIV_IQRsysProject}()},
\code{\link{switchOpt_IQRsysModel}()},
\code{\link{tablePars_IQRsysModel}()}
}
\concept{QSP}
