% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tables_tools_IQRtable.R
\name{statCI}
\alias{statCI}
\title{Return key statistical quantities generated from value, lower and upper confidence bounds}
\usage{
statCI(value, lower, upper, CL = 0.95, digits = NA)
}
\arguments{
\item{value}{numeric values.}

\item{lower}{the lower confidence bound of the value.}

\item{upper}{the upper confidence bound of the value.}

\item{CL}{confidence level to which the provided lower and upper bounds correspond.}

\item{digits}{number of significant digits (if NA (default),
format_GUM is used to determine number of significant digits,
otherwise, signif function is used instead of format_GUM)}
}
\value{
Function \code{outfn(char)} that can be called with the key words
\itemize{
\item \code{value} (value rounded to significant digits according to standard error)
\item \code{se} (standard error rounded to two significant digits)
\item \code{rse} (relative standard error rounded to significant digits according to standard error)
\item \code{rse\%} (relative standard error as percentage)
\item \code{lower.x} where \code{x} is between 1 and 99 (lower confidence bound rounded to significant digits according to standard error)
\item \code{upper.x} where \code{x} is between 1 and 99 (upper confidence bound rounded to significant digits according to standard error)
}
}
\description{
A function is generated that can be called with a number of keywords to
return the requested quantity of interest, accordingly. The function is
typically used in \link{IQRtable}.
}
\details{
The function uses \link{format_GUM} to round to significant digits and format the output.

Interpolation between different requested output confidence levels is based on approximation by
a left- and right-handed standard error. From the (possibly) asymmetric confidence intervals, left/right-handed standard
errors are determined such that the lower/upper confidence bound corresponding to the procided \code{CL} matches the provided
lower/upper bounds. Extrapolation to other confidence levels is performed separately for upper and lower bounds using the
right and left standard error, respectively.

The reported standard error is the mean of left and right standard error. In case, either of the standard errors is
not defined, the reported standard error is NA.

The standard error of \code{rse} is assumed
to be \code{rse^2} which is derived by Gaussian error propagation and the assumption that \code{se} is known without uncertainty.

\link{format_GUM} returns values rounded to significant digits according to the provided standard error. For asymmetric
confidence intervals we use the smaller value of the approximated left and right standard errors for rounding of values.
}
\author{
Daniel Kaschek, IntiQuan
}
\concept{stat functions}
