% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_classes_IQRdataGeneral_tables.R
\name{summaryCat_IQRdataGENERAL}
\alias{summaryCat_IQRdataGENERAL}
\title{Generates a demographic summary table for categorical covariates}
\usage{
summaryCat_IQRdataGENERAL(
  data,
  catNames = NULL,
  stratifyColumns = "STUDY",
  stratifyOrder = NULL,
  FLAGtotal = NULL,
  SIGNIF = 3,
  tableTitle = NULL,
  footerAddText = NULL,
  filename = NULL,
  FLAGpatients = FALSE
)
}
\arguments{
\item{data}{IQRdataGENERAL object}

\item{catNames}{Names of the categorical covariates, as defined as columns in the dataset for which
information should be displayed in the table. If argument is not provided, information will be
generated for all categorical covariates in the data object.}

\item{stratifyColumns}{A vector with names of columns that should be used for stratification of the
table. Already available columns in the data object can be used or the user can add additional stratification
columns that fit the intended purpose. NA entries in such columns will be ignored in the table generation.}

\item{stratifyOrder}{A list with vector entries. For each entry in stratifyColumns there should be one
list entry. Each list entry should be a vector of the elements in the corresponding stratification column and
specifying the order of appearance in the table. If not provided, the stratification will be done in
order of appearance of the elements in the dataset.}

\item{FLAGtotal}{A vector of same length as stratifyColumns. An element TRUE means that for the corresponding strata also
a TOTAL column will be generated. FALSE means that no TOTAL column will be generated.}

\item{SIGNIF}{Defines the number of significant digits for the percentage generation.}

\item{tableTitle}{String with the title for the generated table}

\item{footerAddText}{String with additional text to add to a tables footer. Use "\<br\>" to allow generation of line
breaks in Word reporting.}

\item{filename}{String with path/filename for export of table as text file.}

\item{FLAGpatients}{In the table it is possible to write "Subjects" or "Patients". If this
flag is TRUE then "patients" will be used.}
}
\description{
The table is generated in a report-ready format (when IQReport is used).
The function allows a high level of customization and stratification of the
table. Input data needs to be provided as an IQRdataGENERAL object.
Important: only first occurrence of a covariate value in a subject will be
considered for the generation of the table. This is also the case for potentially
time varying covariates.
}
\seealso{
Other IQRdataGeneral: 
\code{\link{+.IQRdataGENERAL}()},
\code{\link{IQRcalcTAD}()},
\code{\link{IQRdataGENERAL}()},
\code{\link{IQRexpandADDLII}()},
\code{\link{IQRloadCSVdata}()},
\code{\link{IQRsaveCSVdata}()},
\code{\link{addIndivRegressors_IQRdataGENERAL}()},
\code{\link{addLabel_IQRdataGENERAL}()},
\code{\link{attributes0}()},
\code{\link{blloqInfo_IQRdataGENERAL}()},
\code{\link{blloq_IQRdataGENERAL}()},
\code{\link{check_IQRdataGENERAL}()},
\code{\link{clean_IQRdataGENERAL}()},
\code{\link{combine_IQRdataGENERAL}()},
\code{\link{convertCat2Text}()},
\code{\link{covImpute_IQRdataGENERAL}()},
\code{\link{date2dateday_IQRdataProgramming}()},
\code{\link{date2datetime_IQRdataProgramming}()},
\code{\link{date2time_IQRdataProgramming}()},
\code{\link{exportDEFINE_IQRaedataER}()},
\code{\link{exportDEFINE_IQRdataGENERAL}()},
\code{\link{exportDEFINEpdf_IQRdataGENERAL}()},
\code{\link{exportSYS_IQRdataGENERAL}()},
\code{\link{export_IQRdataGENERAL}()},
\code{\link{getLabels_dataframe}()},
\code{\link{getNAcolNLME_IQRdataGENERAL}()},
\code{\link{handleSameTimeObs_IQRdataGENERAL}()},
\code{\link{is_IQRdataGENERAL}()},
\code{\link{loadATRinfo_csvData}()},
\code{\link{loadAttributeFile}()},
\code{\link{load_IQRdataGENERAL}()},
\code{\link{mapCategoricalCovariate_IQRnlmeProject}()},
\code{\link{mapCategoricalCovariate_csvData}()},
\code{\link{mapContinuousCovariate_IQRnlmeProject}()},
\code{\link{mapContinuousCovariate_csvData}()},
\code{\link{mutateCov_IQRdataGENERAL}()},
\code{\link{obfuscate_IQRdataGENERAL}()},
\code{\link{plot.IQRdataGENERAL}()},
\code{\link{plotCorCat_IQRdataGENERAL}()},
\code{\link{plotCorCovCat_IQRdataGENERAL}()},
\code{\link{plotCorCov_IQRdataGENERAL}()},
\code{\link{plotCovDistribution_IQRdataGENERAL}()},
\code{\link{plotDoseSchedule_IQRdataGENERAL}()},
\code{\link{plotIndiv_IQRdataGENERAL}()},
\code{\link{plotRange_IQRdataGENERAL}()},
\code{\link{plotSampleSchedule_IQRdataGENERAL}()},
\code{\link{plotSpaghetti_IQRdataGENERAL}()},
\code{\link{print.IQRdataGENERAL}()},
\code{\link{removeCommata_dataframe}()},
\code{\link{rmAMT0_IQRdataGENERAL}()},
\code{\link{rmDosePostLastObs_IQRdataGENERAL}()},
\code{\link{rmIGNOREd_IQRdataGENERAL}()},
\code{\link{rmMissingTIMEobsRecords_IQRdataGENERAL}()},
\code{\link{rmNOobsSUB_IQRdataGENERAL}()},
\code{\link{rmNonTask_IQRdataGENERAL}()},
\code{\link{rmPLACEBO_IQRdataGENERAL}()},
\code{\link{rmSubjects_IQRdataGENERAL}()},
\code{\link{setIGNORErecords_IQRdataGENERAL}()},
\code{\link{setMissingDVobsRecordsIGNORE_IQRdataGENERAL}()},
\code{\link{subset.IQRdataGENERAL}()},
\code{\link{summary.IQRdataGENERAL}()},
\code{\link{summaryCov_IQRdataGENERAL}()},
\code{\link{summaryObservations_IQRdataGENERAL}()},
\code{\link{transformObs_IQRdataGENERAL}()},
\code{\link{unlabel_dataframe}()}

Other IQRdataGeneral: 
\code{\link{+.IQRdataGENERAL}()},
\code{\link{IQRcalcTAD}()},
\code{\link{IQRdataGENERAL}()},
\code{\link{IQRexpandADDLII}()},
\code{\link{IQRloadCSVdata}()},
\code{\link{IQRsaveCSVdata}()},
\code{\link{addIndivRegressors_IQRdataGENERAL}()},
\code{\link{addLabel_IQRdataGENERAL}()},
\code{\link{attributes0}()},
\code{\link{blloqInfo_IQRdataGENERAL}()},
\code{\link{blloq_IQRdataGENERAL}()},
\code{\link{check_IQRdataGENERAL}()},
\code{\link{clean_IQRdataGENERAL}()},
\code{\link{combine_IQRdataGENERAL}()},
\code{\link{convertCat2Text}()},
\code{\link{covImpute_IQRdataGENERAL}()},
\code{\link{date2dateday_IQRdataProgramming}()},
\code{\link{date2datetime_IQRdataProgramming}()},
\code{\link{date2time_IQRdataProgramming}()},
\code{\link{exportDEFINE_IQRaedataER}()},
\code{\link{exportDEFINE_IQRdataGENERAL}()},
\code{\link{exportDEFINEpdf_IQRdataGENERAL}()},
\code{\link{exportSYS_IQRdataGENERAL}()},
\code{\link{export_IQRdataGENERAL}()},
\code{\link{getLabels_dataframe}()},
\code{\link{getNAcolNLME_IQRdataGENERAL}()},
\code{\link{handleSameTimeObs_IQRdataGENERAL}()},
\code{\link{is_IQRdataGENERAL}()},
\code{\link{loadATRinfo_csvData}()},
\code{\link{loadAttributeFile}()},
\code{\link{load_IQRdataGENERAL}()},
\code{\link{mapCategoricalCovariate_IQRnlmeProject}()},
\code{\link{mapCategoricalCovariate_csvData}()},
\code{\link{mapContinuousCovariate_IQRnlmeProject}()},
\code{\link{mapContinuousCovariate_csvData}()},
\code{\link{mutateCov_IQRdataGENERAL}()},
\code{\link{obfuscate_IQRdataGENERAL}()},
\code{\link{plot.IQRdataGENERAL}()},
\code{\link{plotCorCat_IQRdataGENERAL}()},
\code{\link{plotCorCovCat_IQRdataGENERAL}()},
\code{\link{plotCorCov_IQRdataGENERAL}()},
\code{\link{plotCovDistribution_IQRdataGENERAL}()},
\code{\link{plotDoseSchedule_IQRdataGENERAL}()},
\code{\link{plotIndiv_IQRdataGENERAL}()},
\code{\link{plotRange_IQRdataGENERAL}()},
\code{\link{plotSampleSchedule_IQRdataGENERAL}()},
\code{\link{plotSpaghetti_IQRdataGENERAL}()},
\code{\link{print.IQRdataGENERAL}()},
\code{\link{removeCommata_dataframe}()},
\code{\link{rmAMT0_IQRdataGENERAL}()},
\code{\link{rmDosePostLastObs_IQRdataGENERAL}()},
\code{\link{rmIGNOREd_IQRdataGENERAL}()},
\code{\link{rmMissingTIMEobsRecords_IQRdataGENERAL}()},
\code{\link{rmNOobsSUB_IQRdataGENERAL}()},
\code{\link{rmNonTask_IQRdataGENERAL}()},
\code{\link{rmPLACEBO_IQRdataGENERAL}()},
\code{\link{rmSubjects_IQRdataGENERAL}()},
\code{\link{setIGNORErecords_IQRdataGENERAL}()},
\code{\link{setMissingDVobsRecordsIGNORE_IQRdataGENERAL}()},
\code{\link{subset.IQRdataGENERAL}()},
\code{\link{summary.IQRdataGENERAL}()},
\code{\link{summaryCov_IQRdataGENERAL}()},
\code{\link{summaryObservations_IQRdataGENERAL}()},
\code{\link{transformObs_IQRdataGENERAL}()},
\code{\link{unlabel_dataframe}()}
}
\concept{IQRdataGeneral}
