% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_classes_IQRdataGeneral_tables.R
\name{summaryObservations_IQRdataGENERAL}
\alias{summaryObservations_IQRdataGENERAL}
\title{Generates a summary of observations in an IQRdataGENERAL object}
\usage{
summaryObservations_IQRdataGENERAL(
  data,
  obsNames = NULL,
  stratifyColumn = "STUDY",
  SIGNIF = 3,
  tableTitle = NULL,
  footerAddText = NULL,
  filename = NULL,
  FLAGpk = TRUE,
  FLAGpatients = FALSE,
  FLAGsimple = FALSE
)
}
\arguments{
\item{data}{IQRdataGENERAL object}

\item{obsNames}{Vector with names of observations (NAME column in dataset) to consider in the table. If undefined,
all available obsNames in the general dataset will be used.}

\item{stratifyColumn}{A vector with name of a column that should be used for stratification of the
table. Already available columns in the data object can be used or the user can add an additional stratification
column that fits the intended purpose. NA entries in such columns will be ignored in the table generation.
NAME should not be used as stratification column. If NAME is desired then it is suggested to extract a specific
readout in a separate data.frame and run the function on that.}

\item{SIGNIF}{Defines the number of significant digits for the percentage generation.}

\item{tableTitle}{String with the title for the generated table}

\item{footerAddText}{String with additional text to add to a tables footer. Use "\<br\>" to allow generation of line
breaks in Word reporting.}

\item{filename}{String with path/filename for export of table as text file.}

\item{FLAGpk}{If TRUE then BLOQ samples post first dose are reported. If FALSE, these are not reported.}

\item{FLAGpatients}{In the table it is possible to write "Subjects" or "Patients". If this
flag is TRUE then "patients" will be used.}

\item{FLAGsimple}{If TRUE then all columns except "Data", N Subjects", "N samples included in analysis" are removed.
Footer is empty in this case as well.}
}
\description{
The table is generated in a report-ready format (when IQReport is used).
The function allows a high level of customization and stratification of the
table. Input data needs to be provided as an IQRdataGENERAL object. PK data
can be handled differently from PD data. For instance, when FLAGpk=TRUE then
BLOQ samples post first dose and non-zero observations pre-first dose are reported.
For FLAGpk=FALSE these are not reported as they do not play a role and typically
are OK in the data.
}
\seealso{
Other IQRdataGeneral: 
\code{\link{+.IQRdataGENERAL}()},
\code{\link{IQRcalcTAD}()},
\code{\link{IQRdataGENERAL}()},
\code{\link{IQRexpandADDLII}()},
\code{\link{IQRloadCSVdata}()},
\code{\link{IQRsaveCSVdata}()},
\code{\link{addIndivRegressors_IQRdataGENERAL}()},
\code{\link{addLabel_IQRdataGENERAL}()},
\code{\link{attributes0}()},
\code{\link{blloqInfo_IQRdataGENERAL}()},
\code{\link{blloq_IQRdataGENERAL}()},
\code{\link{check_IQRdataGENERAL}()},
\code{\link{clean_IQRdataGENERAL}()},
\code{\link{combine_IQRdataGENERAL}()},
\code{\link{convertCat2Text}()},
\code{\link{covImpute_IQRdataGENERAL}()},
\code{\link{date2dateday_IQRdataProgramming}()},
\code{\link{date2datetime_IQRdataProgramming}()},
\code{\link{date2time_IQRdataProgramming}()},
\code{\link{exportDEFINE_IQRaedataER}()},
\code{\link{exportDEFINE_IQRdataGENERAL}()},
\code{\link{exportDEFINEpdf_IQRdataGENERAL}()},
\code{\link{exportSYS_IQRdataGENERAL}()},
\code{\link{export_IQRdataGENERAL}()},
\code{\link{getLabels_dataframe}()},
\code{\link{getNAcolNLME_IQRdataGENERAL}()},
\code{\link{handleSameTimeObs_IQRdataGENERAL}()},
\code{\link{is_IQRdataGENERAL}()},
\code{\link{loadATRinfo_csvData}()},
\code{\link{loadAttributeFile}()},
\code{\link{load_IQRdataGENERAL}()},
\code{\link{mapCategoricalCovariate_IQRnlmeProject}()},
\code{\link{mapCategoricalCovariate_csvData}()},
\code{\link{mapContinuousCovariate_IQRnlmeProject}()},
\code{\link{mapContinuousCovariate_csvData}()},
\code{\link{mutateCov_IQRdataGENERAL}()},
\code{\link{obfuscate_IQRdataGENERAL}()},
\code{\link{plot.IQRdataGENERAL}()},
\code{\link{plotCorCat_IQRdataGENERAL}()},
\code{\link{plotCorCovCat_IQRdataGENERAL}()},
\code{\link{plotCorCov_IQRdataGENERAL}()},
\code{\link{plotCovDistribution_IQRdataGENERAL}()},
\code{\link{plotDoseSchedule_IQRdataGENERAL}()},
\code{\link{plotIndiv_IQRdataGENERAL}()},
\code{\link{plotRange_IQRdataGENERAL}()},
\code{\link{plotSampleSchedule_IQRdataGENERAL}()},
\code{\link{plotSpaghetti_IQRdataGENERAL}()},
\code{\link{print.IQRdataGENERAL}()},
\code{\link{removeCommata_dataframe}()},
\code{\link{rmAMT0_IQRdataGENERAL}()},
\code{\link{rmDosePostLastObs_IQRdataGENERAL}()},
\code{\link{rmIGNOREd_IQRdataGENERAL}()},
\code{\link{rmMissingTIMEobsRecords_IQRdataGENERAL}()},
\code{\link{rmNOobsSUB_IQRdataGENERAL}()},
\code{\link{rmNonTask_IQRdataGENERAL}()},
\code{\link{rmPLACEBO_IQRdataGENERAL}()},
\code{\link{rmSubjects_IQRdataGENERAL}()},
\code{\link{setIGNORErecords_IQRdataGENERAL}()},
\code{\link{setMissingDVobsRecordsIGNORE_IQRdataGENERAL}()},
\code{\link{subset.IQRdataGENERAL}()},
\code{\link{summary.IQRdataGENERAL}()},
\code{\link{summaryCat_IQRdataGENERAL}()},
\code{\link{summaryCov_IQRdataGENERAL}()},
\code{\link{transformObs_IQRdataGENERAL}()},
\code{\link{unlabel_dataframe}()}

Other IQRdataGeneral: 
\code{\link{+.IQRdataGENERAL}()},
\code{\link{IQRcalcTAD}()},
\code{\link{IQRdataGENERAL}()},
\code{\link{IQRexpandADDLII}()},
\code{\link{IQRloadCSVdata}()},
\code{\link{IQRsaveCSVdata}()},
\code{\link{addIndivRegressors_IQRdataGENERAL}()},
\code{\link{addLabel_IQRdataGENERAL}()},
\code{\link{attributes0}()},
\code{\link{blloqInfo_IQRdataGENERAL}()},
\code{\link{blloq_IQRdataGENERAL}()},
\code{\link{check_IQRdataGENERAL}()},
\code{\link{clean_IQRdataGENERAL}()},
\code{\link{combine_IQRdataGENERAL}()},
\code{\link{convertCat2Text}()},
\code{\link{covImpute_IQRdataGENERAL}()},
\code{\link{date2dateday_IQRdataProgramming}()},
\code{\link{date2datetime_IQRdataProgramming}()},
\code{\link{date2time_IQRdataProgramming}()},
\code{\link{exportDEFINE_IQRaedataER}()},
\code{\link{exportDEFINE_IQRdataGENERAL}()},
\code{\link{exportDEFINEpdf_IQRdataGENERAL}()},
\code{\link{exportSYS_IQRdataGENERAL}()},
\code{\link{export_IQRdataGENERAL}()},
\code{\link{getLabels_dataframe}()},
\code{\link{getNAcolNLME_IQRdataGENERAL}()},
\code{\link{handleSameTimeObs_IQRdataGENERAL}()},
\code{\link{is_IQRdataGENERAL}()},
\code{\link{loadATRinfo_csvData}()},
\code{\link{loadAttributeFile}()},
\code{\link{load_IQRdataGENERAL}()},
\code{\link{mapCategoricalCovariate_IQRnlmeProject}()},
\code{\link{mapCategoricalCovariate_csvData}()},
\code{\link{mapContinuousCovariate_IQRnlmeProject}()},
\code{\link{mapContinuousCovariate_csvData}()},
\code{\link{mutateCov_IQRdataGENERAL}()},
\code{\link{obfuscate_IQRdataGENERAL}()},
\code{\link{plot.IQRdataGENERAL}()},
\code{\link{plotCorCat_IQRdataGENERAL}()},
\code{\link{plotCorCovCat_IQRdataGENERAL}()},
\code{\link{plotCorCov_IQRdataGENERAL}()},
\code{\link{plotCovDistribution_IQRdataGENERAL}()},
\code{\link{plotDoseSchedule_IQRdataGENERAL}()},
\code{\link{plotIndiv_IQRdataGENERAL}()},
\code{\link{plotRange_IQRdataGENERAL}()},
\code{\link{plotSampleSchedule_IQRdataGENERAL}()},
\code{\link{plotSpaghetti_IQRdataGENERAL}()},
\code{\link{print.IQRdataGENERAL}()},
\code{\link{removeCommata_dataframe}()},
\code{\link{rmAMT0_IQRdataGENERAL}()},
\code{\link{rmDosePostLastObs_IQRdataGENERAL}()},
\code{\link{rmIGNOREd_IQRdataGENERAL}()},
\code{\link{rmMissingTIMEobsRecords_IQRdataGENERAL}()},
\code{\link{rmNOobsSUB_IQRdataGENERAL}()},
\code{\link{rmNonTask_IQRdataGENERAL}()},
\code{\link{rmPLACEBO_IQRdataGENERAL}()},
\code{\link{rmSubjects_IQRdataGENERAL}()},
\code{\link{setIGNORErecords_IQRdataGENERAL}()},
\code{\link{setMissingDVobsRecordsIGNORE_IQRdataGENERAL}()},
\code{\link{subset.IQRdataGENERAL}()},
\code{\link{summary.IQRdataGENERAL}()},
\code{\link{summaryCat_IQRdataGENERAL}()},
\code{\link{summaryCov_IQRdataGENERAL}()},
\code{\link{transformObs_IQRdataGENERAL}()},
\code{\link{unlabel_dataframe}()}
}
\concept{IQRdataGeneral}
